(define-module (glicid packages crates-imported)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system cargo)
  #:use-module ((guix licenses)
                #:prefix license:)
  #:use-module (gnu packages tls)
  #:use-module (gnu packages crates-io)
  #:use-module (gnu packages crates-apple)
  #:use-module (gnu packages crates-windows)
  #:use-module (gnu packages crates-crypto)
  #:use-module (gnu packages crates-compression)
  #:use-module (gnu packages crates-web)
  #:use-module (gnu packages crates-check)
  #:use-module (gnu packages crates-database)
  #:use-module (gnu packages crates-tls)
  #:use-module (gnu packages crypto)
  #:use-module (gnu packages crates-graphics)
  #:use-module (gnu packages crates-io)
  #:use-module (gnu packages pkg-config)
  #:use-module (guix-science packages typst) ;YD ;; for rust mysql src ;; should be moved
  #:use-module (gnu packages compression))

(define-public rust-ecow-0.2
  (package
    (name "rust-ecow")
    (version "0.2.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ecow" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1fhrh7lsx82bqdsl57p4zdds4d8nmwgdcncyp5c0rclj76lw0bz4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-loom" ,rust-loom-0.7)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/typst/ecow")
    (synopsis "Compact, clone-on-write vector and string")
    (description
     "This package provides Compact, clone-on-write vector and string.")
    (license (list license:expat license:asl2.0))))

(define-public rust-self-replace-1
  (package
    (name "rust-self-replace")
    (version "1.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "self-replace" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1drganasvf5b0x6c9g60jkfhzjc9in3r6cznjfw0lhmbbrdq3v03"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-fastrand" ,rust-fastrand-2)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/mitsuhiko/self-replace")
    (synopsis
     "Utility crate that allows executables to replace or uninstall themselves")
    (description
     "This package provides Utility crate that allows executables to replace or uninstall themselves.")
    (license license:asl2.0)))

(define-public rust-unicode-script-0.5
  (package
    (name "rust-unicode-script")
    (version "0.5.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "unicode-script" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "07vwr9iddw5xwrj57hc6ig0mwmlzjdajj9lyfxqz9by9a2rj3d4z"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-compiler-builtins" ,rust-compiler-builtins-0.1)
                       ("rust-rustc-std-workspace-core" ,rust-rustc-std-workspace-core-1)
                       ("rust-rustc-std-workspace-std" ,rust-rustc-std-workspace-std-1))))
    (home-page "https://github.com/unicode-rs/unicode-script")
    (synopsis
     "This crate exposes the Unicode `Script` and `Script_Extension` properties from [UAX #24](http://www.unicode.org/reports/tr24/)")
    (description
     "This crate exposes the Unicode `Script` and `Script_Extension` properties from
                   [UAX #24](http://www.unicode.org/reports/tr24/).")
    (license (list license:expat license:asl2.0))))

(define-public rust-rustic-testing-0.3
  (package
    (name "rust-rustic-testing")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rustic_testing" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "15vmsr0v2dx8w3r787iilxz23czczg73fbyhwfgpx98w5z2j1rnn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aho-corasick" ,rust-aho-corasick-1)
                       ("rust-anyhow" ,rust-anyhow-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-enum-map" ,rust-enum-map-2)
                       ("rust-rustic-core" ,rust-rustic-core-0.7)
                       ("rust-tempfile" ,rust-tempfile-3))))
    (home-page "")
    (synopsis "rustic_testuing - library for test support in rustic-rs")
    (description
     "This package provides rustic_testuing - library for test support in rustic-rs.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-libz-rs-sys-0.4
  (package
    (name "rust-libz-rs-sys")
    (version "0.4.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "libz-rs-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1pwwjxpd9inw1lf1x72m0gjg5jzsaqpfrpkczbqr6b0vdw81j3m9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-zlib-rs" ,rust-zlib-rs-0.4))))
    (home-page "https://github.com/trifectatechfoundation/zlib-rs")
    (synopsis "memory-safe zlib implementation written in rust")
    (description
     "This package provides a memory-safe zlib implementation written in rust.")
    (license license:zlib)))

(define-public rust-flate2-1
  (package
    (name "rust-flate2")
    (version "1.0.35")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "flate2" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0z6h0wa095wncpfngx75wyhyjnqwld7wax401gsvnzjhzgdbydn9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cloudflare-zlib-sys" ,rust-cloudflare-zlib-sys-0.3)
                       ("rust-crc32fast" ,rust-crc32fast-1)
                       ("rust-libz-ng-sys" ,rust-libz-ng-sys-1)
                       ("rust-libz-rs-sys" ,rust-libz-rs-sys-0.4)
                       ("rust-libz-sys" ,rust-libz-sys-1)
                       ("rust-miniz-oxide" ,rust-miniz-oxide-0.8))))
    (home-page "https://github.com/rust-lang/flate2-rs")
    (synopsis
     "DEFLATE compression and decompression exposed as Read/BufRead/Write streams.
                   Supports miniz_oxide and multiple zlib implementations. Supports zlib, gzip,
                   and raw deflate streams.")
    (description
     "This package provides DEFLATE compression and decompression exposed as Read/@code{BufRead/Write}
                     streams. Supports miniz_oxide and multiple zlib implementations. Supports
                     zlib, gzip, and raw deflate streams.")
    (license (list license:expat license:asl2.0))))

(define-public rust-dircmp-0.2
  (package
    (name "rust-dircmp")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dircmp" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "03qgd04fgfzhivv3yygifaivgpdc2bs7krkhf1jq0y9rpaipzjn3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-regex" ,rust-regex-1)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-walkdir" ,rust-walkdir-2))))
    (home-page "https://github.com/jondot/dircmp")
    (synopsis "Compare folders and return a diff for assertion")
    (description
     "This package provides Compare folders and return a diff for assertion.")
    (license license:asl2.0)))

(define-public rust-tui-textarea-0.7
  (package
    (name "rust-tui-textarea")
    (version "0.7.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tui-textarea" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1bnb3andd8gcqkf5rdvz530zykkj8s8d2yj1m593rmwyc7fihlqa"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-crossterm" ,rust-crossterm-0.25)
                       ("rust-crossterm" ,rust-crossterm-0.28)
                       ("rust-ratatui" ,rust-ratatui-0.29)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-termion" ,rust-termion-4)
                       ("rust-termion" ,rust-termion-1)
                       ("rust-termwiz" ,rust-termwiz-0.22)
                       ("rust-tui" ,rust-tui-0.19)
                       ("rust-unicode-width" ,rust-unicode-width-0.2))))
    (home-page "https://github.com/rhysd/tui-textarea#readme")
    (synopsis
     "tui-textarea is a simple yet powerful text editor widget for ratatui and tui-rs. Multi-line
                   text editor can be easily put as part of your TUI application.")
    (description
     "This package provides tui-textarea is a simple yet powerful text editor widget for ratatui and tui-rs.
                     Multi-line text editor can be easily put as part of your TUI application.")
    (license license:expat)))

(define-public rust-zipsign-api-0.1
  (package
    (name "rust-zipsign-api")
    (version "0.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "zipsign-api" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0z30vzhhhd1va9z7ksdw8x8f6y8jb200h2ryk85wvnx9mm3aa4v4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-ed25519-dalek" ,rust-ed25519-dalek-2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-zip" ,rust-zip-2))))
    (home-page "https://github.com/Kijewski/zipsign")
    (synopsis
     "Sign and verify `.zip` and `.tar.gz` files with an ed25519 signing key")
    (description
     "This package provides Sign and verify `.zip` and `.tar.gz` files with an ed25519 signing key.")
    (license (list license:asl2.0))))

(define-public rust-quick-xml-0.23
  (package
    (name "rust-quick-xml")
    (version "0.23.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "quick-xml" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1slry2g2wrj38fnzj9ybzq9wjyknrfg25x5vzfpzn5b8kj2zrfhi"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-encoding-rs" ,rust-encoding-rs-0.8)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/tafia/quick-xml")
    (synopsis "High performance xml reader and writer")
    (description
     "This package provides High performance xml reader and writer.")
    (license license:expat)))

(define-public rust-self-update-0.39
  (package
    (name "rust-self-update")
    (version "0.39.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "self_update" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1d1psjdblr8mzs63381qzbjwzg9s6klr11lv5ss4m2469a7asd0s"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-either" ,rust-either-1)
                       ("rust-flate2" ,rust-flate2-1)
                       ("rust-hyper" ,rust-hyper-0.14)
                       ("rust-indicatif" ,rust-indicatif-0.17)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-quick-xml" ,rust-quick-xml-0.23)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-reqwest" ,rust-reqwest-0.11)
                       ("rust-self-replace" ,rust-self-replace-1)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-tar" ,rust-tar-0.4)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-urlencoding" ,rust-urlencoding-2)
                       ("rust-zip" ,rust-zip-0.6)
                       ("rust-zipsign-api" ,rust-zipsign-api-0.1))))
    (home-page "https://github.com/jaemk/self_update")
    (synopsis "Self updates for standalone executables")
    (description
     "This package provides Self updates for standalone executables.")
    (license license:expat)))

(define-public rust-typed-path-0.9
  (package
    (name "rust-typed-path")
    (version "0.9.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "typed-path" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "01v6ljly0rckmag91dqbaiqrh3ri8ym92m0lzhs7wsd98kymy842"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/chipsenkbeil/typed-path")
    (synopsis
     "Provides typed variants of Path and PathBuf for Unix and Windows")
    (description
     "This package provides typed variants of Path and @code{PathBuf} for Unix and
                   Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-with-macros-3
  (package
    (name "rust-serde-with-macros")
    (version "3.12.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_with_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "13hznly0qq1rngsdh8gpnajab2knkrmvwwrbmii86g1s36jwl04d"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-darling" ,rust-darling-0.20)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/jonasbb/serde_with/")
    (synopsis "proc-macro library for serde_with")
    (description "This package provides proc-macro library for serde_with.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-with-macros-3.11.0
  (package
    (name "rust-serde-with-macros")
    (version "3.11.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_with_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "17d7viab3z0ypf4jzpn73xydxn22c911n5nsycjgfkl5m4a6514x"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-darling" ,rust-darling-0.20)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/jonasbb/serde_with/")
    (synopsis "proc-macro library for serde_with")
    (description "This package provides proc-macro library for serde_with.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-with-3
  (package
    (name "rust-serde-with")
    (version "3.12.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_with" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ai9c3cbdgrsvmlc4qpg9z73y80yplk3k7zp45wp97xnzkrggdnn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-doc-comment" ,rust-doc-comment-0.3)
                       ("rust-document-features" ,rust-document-features-0.2)
                       ("rust-hashbrown" ,rust-hashbrown-0.15)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-indexmap" ,rust-indexmap-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-schemars" ,rust-schemars-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-with-macros" ,rust-serde-with-macros-3)
                       ("rust-time" ,rust-time-0.3))))
    (home-page "https://github.com/jonasbb/serde_with/")
    (synopsis "Custom de/serialization functions for Rust's serde")
    (description
     "This package provides Custom de/serialization functions for Rust's serde.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-with-3.11.0
  (package
    (name "rust-serde-with")
    (version "3.11.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_with" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "05z83zkx9q8k4yw3z7isb3l95c5k43q0hwcz8h739f5jdnnvsa4f"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-doc-comment" ,rust-doc-comment-0.3)
                       ("rust-document-features" ,rust-document-features-0.2)
                       ("rust-hashbrown" ,rust-hashbrown-0.15)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-indexmap" ,rust-indexmap-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-schemars" ,rust-schemars-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-with-macros" ,rust-serde-with-macros-3.11.0)
                       ("rust-time" ,rust-time-0.3))))
    (home-page "https://github.com/jonasbb/serde_with/")
    (synopsis "Custom de/serialization functions for Rust's serde")
    (description
     "This package provides Custom de/serialization functions for Rust's serde.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-aux-4
  (package
    (name "rust-serde-aux")
    (version "4.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde-aux" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "158w68035kzy0h202bdlln3s792is3a12cqyw496bl39lkxqnbhd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-chrono" ,rust-chrono-0.4)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/iddm/serde-aux")
    (synopsis "serde crate's auxiliary library")
    (description "This package provides a serde crate's auxiliary library.")
    (license license:expat)))

(define-public rust-rustic-cdc-0.3
  (package
    (name "rust-rustic-cdc")
    (version "0.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rustic_cdc" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1qknp0r0wshk9c0lrzidr83czaj3ry2gskdm3jvc8yw250ibzkpv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/rustic-rs/cdc")
    (synopsis
     "library for performing Content-Defined Chunking (CDC) on data streams.")
    (description
     "This package provides a library for performing Content-Defined Chunking (CDC) on
                   data streams.")
    (license license:expat)))

(define-public rust-runtime-format-0.1
  (package
    (name "rust-runtime-format")
    (version "0.1.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "runtime-format" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "154c7jq7kbpc5acn2ysa2ilab2x0i5y7d34jwznni9xw71dqv589"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-tinyvec" ,rust-tinyvec-1))))
    (home-page "https://github.com/conradludgate/strfmt")
    (synopsis "rust library for formatting dynamic strings")
    (description
     "This package provides rust library for formatting dynamic strings.")
    (license license:expat)))

(define-public rust-path-dedot-3
  (package
    (name "rust-path-dedot")
    (version "3.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "path-dedot" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "15wkx8q3vra34fslzlg1lkq7liyxwqrpbxiz44a28wa7w3bhmfh7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-once-cell" ,rust-once-cell-1))))
    (home-page "https://magiclen.org/path-dedot")
    (synopsis
     "library for extending `Path` and `PathBuf` in order to parse the path which contains dots.")
    (description
     "This package provides a library for extending `Path` and `@code{PathBuf`} in
                   order to parse the path which contains dots.")
    (license license:expat)))

(define-public rust-pariter-0.5
  (package
    (name "rust-pariter")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "pariter" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ng34zrn8y0sy5lc1yarz51vd2q2z1020an9mk071wmmwywn4jij"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-crossbeam" ,rust-crossbeam-0.8)
                       ("rust-crossbeam-channel" ,rust-crossbeam-channel-0.5)
                       ("rust-num-cpus" ,rust-num-cpus-1))))
    (home-page "https://github.com/dpc/pariter")
    (synopsis "Parallel iterator processing")
    (description "This package provides Parallel iterator processing.")
    (license (list license:mpl2.0 license:expat license:asl2.0))))

(define-public rust-integer-sqrt-0.1
  (package
    (name "rust-integer-sqrt")
    (version "0.1.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "integer-sqrt" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0w6pzmgvs1mldkhafbwg9x7wzr0af3ngkimyb1gy97jarcdw6vi7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-num-traits" ,rust-num-traits-0.2))))
    (home-page "https://github.com/derekdreery/integer-sqrt-rs")
    (synopsis
     "An implementation of integer square root algorithm for primitive rust types")
    (description
     "This package provides An implementation of integer square root algorithm for primitive rust types.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-enum-map-derive-0.17
  (package
    (name "rust-enum-map-derive")
    (version "0.17.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "enum-map-derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1sv4mb343rsz4lc3rh7cyn0pdhf7fk18k1dgq8kfn5i5x7gwz0pj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://codeberg.org/xfix/enum-map")
    (synopsis "Macros 1.1 implementation of #[derive(Enum)]")
    (description
     "This package provides Macros 1.1 implementation of #[derive(Enum)].")
    (license (list license:expat license:asl2.0))))

(define-public rust-enum-map-2
  (package
    (name "rust-enum-map")
    (version "2.7.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "enum-map" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1sgjgl4mmz93jdkfdsmapc3dmaq8gddagw9s0fd501w2vyzz6rk8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-enum-map-derive" ,rust-enum-map-derive-0.17)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://codeberg.org/xfix/enum-map")
    (synopsis "map with C-like enum keys represented internally as an array")
    (description
     "This package provides a map with C-like enum keys represented internally as an
                   array.")
    (license (list license:expat license:asl2.0))))

(define-public rust-binrw-derive-0.14
  (package
    (name "rust-binrw-derive")
    (version "0.14.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "binrw_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0g7zxw23vpg8im9i01akvcmjvipjxsbmx8dz8lkfvg75dj345fnq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-either" ,rust-either-1)
                       ("rust-owo-colors" ,rust-owo-colors-3)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://binrw.rs")
    (synopsis "Derive macro for binrw")
    (description "This package provides Derive macro for binrw.")
    (license license:expat)))

(define-public rust-binrw-0.14
  (package
    (name "rust-binrw")
    (version "0.14.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "binrw" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "16whq880zw3bxapgggb1dw4qk2vq3szay0h8rk140vqdq9cwljvx"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-array-init" ,rust-array-init-2)
                       ("rust-binrw-derive" ,rust-binrw-derive-0.14)
                       ("rust-bytemuck" ,rust-bytemuck-1))))
    (home-page "https://binrw.rs")
    (synopsis
     "Rust crate for helping read structs from binary data using â¨macro magicâ¨")
    (description
     "This package provides a Rust crate for helping read structs from binary data
                   using â¨macro magicâ¨.")
    (license license:expat)))

(define-public rust-aes256ctr-poly1305aes-0.2
  (package
    (name "rust-aes256ctr-poly1305aes")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "aes256ctr_poly1305aes" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1i63wvrcwxl56rqlmyd5c76pjxr7hsx5rh4cw5bx9vsbc7wfcb61"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aead" ,rust-aead-0.5)
                       ("rust-aes" ,rust-aes-0.8)
                       ("rust-cipher" ,rust-cipher-0.4)
                       ("rust-ctr" ,rust-ctr-0.9)
                       ("rust-poly1305" ,rust-poly1305-0.8)
                       ("rust-subtle" ,rust-subtle-2)
                       ("rust-zeroize" ,rust-zeroize-1))))
    (home-page "https://github.com/rustic-rs/aes256ctr_poly1305aes")
    (synopsis
     "Pure Rust implementation of the AES256CTR-Poly1305AES Authenticated Encryption
                   with optional architecture-specific hardware acceleration.")
    (description
     "This package provides Pure Rust implementation of the AES256CTR-Poly1305AES Authenticated Encryption
                     with optional architecture-specific hardware acceleration.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-rustic-core-0.7
  (package
    (name "rust-rustic-core")
    (version "0.7.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rustic_core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1hipgh4z1nvifyib7ix0cyiyg5liq8ikanfynj2423gwhrz1j4j1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aes256ctr-poly1305aes" ,rust-aes256ctr-poly1305aes-0.2)
                       ("rust-binrw" ,rust-binrw-0.14)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-bytesize" ,rust-bytesize-1)
                       ("rust-cached" ,rust-cached-0.54)
                       ("rust-cachedir" ,rust-cachedir-0.3)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-clap" ,rust-clap-4)
                       ("rust-conflate" ,rust-conflate-0.3)
                       ("rust-crossbeam-channel" ,rust-crossbeam-channel-0.5)
                       ("rust-derive-more" ,rust-derive-more-1)
                       ("rust-derive-setters" ,rust-derive-setters-0.1)
                       ("rust-dirs" ,rust-dirs-5)
                       ("rust-displaydoc" ,rust-displaydoc-0.2)
                       ("rust-dunce" ,rust-dunce-1)
                       ("rust-ecow" ,rust-ecow-0.2)
                       ("rust-enum-map" ,rust-enum-map-2)
                       ("rust-enum-map-derive" ,rust-enum-map-derive-0.17)
                       ("rust-enumset" ,rust-enumset-1)
                       ("rust-filetime" ,rust-filetime-0.2)
                       ("rust-gethostname" ,rust-gethostname-0.5)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-humantime" ,rust-humantime-2)
                       ("rust-ignore" ,rust-ignore-0.4)
                       ("rust-integer-sqrt" ,rust-integer-sqrt-0.1)
                       ("rust-itertools" ,rust-itertools-0.13)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-nix" ,rust-nix-0.29)
                       ("rust-pariter" ,rust-pariter-0.5)
                       ("rust-path-dedot" ,rust-path-dedot-3)
                       ("rust-quick-cache" ,rust-quick-cache-0.6)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-runtime-format" ,rust-runtime-format-0.1)
                       ("rust-rustic-cdc" ,rust-rustic-cdc-0.3)
                       ("rust-scrypt" ,rust-scrypt-0.11)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-aux" ,rust-serde-aux-4)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-with" ,rust-serde-with-3.11.0)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-shell-words" ,rust-shell-words-1)
                       ("rust-strum" ,rust-strum-0.26)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-walkdir" ,rust-walkdir-2)
                       ("rust-xattr" ,rust-xattr-1)
                       ("rust-zstd" ,rust-zstd-0.13))))
    (home-page "https://rustic.cli.rs/")
    (synopsis
     "rustic_core - library for fast, encrypted, deduplicated backups that powers rustic-rs")
    (description
     "This package provides rustic_core - library for fast, encrypted, deduplicated backups that powers
                   rustic-rs.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-tikv-client-0.3
  (package
    (name "rust-tikv-client")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tikv-client" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h2rs16dax08d9znfi7s0vi5lsscj4cwqw376irb8kfhwgj6i284"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-recursion" ,rust-async-recursion-0.3)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-derive-new" ,rust-derive-new-0.5)
                       ("rust-either" ,rust-either-1)
                       ("rust-fail" ,rust-fail-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-prometheus" ,rust-prometheus-0.13)
                       ("rust-prost" ,rust-prost-0.12)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tonic" ,rust-tonic-0.10))))
    (home-page "https://github.com/tikv/client-rust")
    (synopsis "The Rust language implementation of TiKV client")
    (description
     "This package provides The Rust language implementation of @code{TiKV} client.")
    (license license:asl2.0)))

(define-public rust-async-io-stream-0.3
  (package
    (name "rust-async-io-stream")
    (version "0.3.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async_io_stream" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0k5rv51935p3il74q59hwaaid6sy9kv05vz3lw48jpgkrpgbkmxn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures" ,rust-futures-0.3)
                       ("rust-pharos" ,rust-pharos-0.5)
                       ("rust-rustc-version" ,rust-rustc-version-0.4)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/najamelan/async_io_stream")
    (synopsis "IntoAsyncRead on steriods")
    (description "This package provides @code{IntoAsyncRead} on steriods.")
    (license license:unlicense)))

(define-public rust-ws-stream-wasm-0.7
  (package
    (name "rust-ws-stream-wasm")
    (version "0.7.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ws_stream_wasm" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1x9p0zjmk89z0nnpc1qrzm7yfwaz8yj5fqmn4s3q3qvz47sgb6br"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-io-stream" ,rust-async-io-stream-0.3)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-pharos" ,rust-pharos-0.5)
                       ("rust-rustc-version" ,rust-rustc-version-0.4)
                       ("rust-send-wrapper" ,rust-send-wrapper-0.6)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-wasm-bindgen-futures" ,rust-wasm-bindgen-futures-0.4)
                       ("rust-web-sys" ,rust-web-sys-0.3))))
    (home-page "https://github.com/najamelan/ws_stream_wasm")
    (synopsis "convenience library for using websockets in WASM")
    (description
     "This package provides a convenience library for using websockets in WASM.")
    (license license:unlicense)))

(define-public rust-wasmtimer-0.2
  (package
    (name "rust-wasmtimer")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "wasmtimer" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1vl0dxzr7xbnycrak4yd6f9h5lpkfsibbd5zf96mkyy72n5rvvf7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures" ,rust-futures-0.3)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-pin-utils" ,rust-pin-utils-0.1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-slab" ,rust-slab-0.4)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2))))
    (home-page "https://github.com/whizsid/wasmtimer-rs")
    (synopsis
     "Time utils from std::time, tokio::time and tokio_util::time on WASM targets")
    (description
     "This package provides Time utils from std::time, tokio::time and tokio_util::time on WASM targets.")
    (license license:expat)))

(define-public rust-trice-0.4
  (package
    (name "rust-trice")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "trice" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0njibc87nlz8674zwdwhyd2hilhgdzsjnxcjyc80pb4zmq8apank"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-web-sys" ,rust-web-sys-0.3))))
    (home-page "https://github.com/surrealdb/trice")
    (synopsis
     "minimal replacement for std::time::Instant that works in WASM for the web and Node.js.")
    (description
     "This package provides a minimal replacement for std::time::Instant that works in
                   WASM for the web and Node.js.")
    (license license:asl2.0)))

(define-public rust-ort-1
  (package
    (name "rust-ort")
    (version "1.16.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ort" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "17fp5229v0qz6lcbd4pl23cj0jgx8kg2pnsdlldip8pgk16cm7c8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-flate2" ,rust-flate2-1)
                       ("rust-half" ,rust-half-2)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-libloading" ,rust-libloading-0.7)
                       ("rust-ndarray" ,rust-ndarray-0.15)
                       ("rust-tar" ,rust-tar-0.4)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-ureq" ,rust-ureq-2)
                       ("rust-ureq" ,rust-ureq-2)
                       ("rust-vswhom" ,rust-vswhom-0.1)
                       ("rust-widestring" ,rust-widestring-1)
                       ("rust-winapi" ,rust-winapi-0.3)
                       ("rust-zip" ,rust-zip-0.6))))
    (home-page "https://ort.pyke.io/")
    (synopsis
     "safe Rust wrapper for ONNX Runtime 1.20 - Optimize and accelerate machine learning inference & training")
    (description
     "This package provides a safe Rust wrapper for ONNX Runtime 1.20 - Optimize and
                   accelerate machine learning inference & training.")
    (license (list license:expat license:asl2.0))))

(define-public rust-surrealml-core-0.1
  (package
    (name "rust-surrealml-core")
    (version "0.1.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealml-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1wh3bar25037hzgvvyizmxhcdl97qfvf3b38k3qidcm50aakdnfl"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-actix-web" ,rust-actix-web-4)
                       ("rust-axum" ,rust-axum-0.7)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-ndarray" ,rust-ndarray-0.15)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-ort" ,rust-ort-1)
                       ("rust-ort" ,rust-ort-1)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "")
    (synopsis
     "The core machine learning library for SurrealML that enables SurrealDB to store and load ML models")
    (description
     "This package provides The core machine learning library for @code{SurrealML} that enables
                   @code{SurrealDB} to store and load ML models.")
    (license license:asl2.0)))
 ;;; YD unknown

(define-public rust-vart-0.7
  (package
    (name "rust-vart")
    (version "0.7.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "vart" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1lxjr72248p4732jgxw51fv6wya6ybbxzvnxmyalkfay6xfik4hw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/surrealdb/vart")
    (synopsis "An immutable versioned adaptive radix trie")
    (description
     "This package provides An immutable versioned adaptive radix trie.")
    (license license:asl2.0)))

(define-public rust-quick-cache-0.6
  (package
    (name "rust-quick-cache")
    (version "0.6.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "quick_cache" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1x6vhn9kjszpn8ivv51zcix4kpqfqy98a3iqnrmzk7asjgw98z3x"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-equivalent" ,rust-equivalent-1)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-shuttle" ,rust-shuttle-0.7))))
    (home-page "https://github.com/arthurprs/quick-cache")
    (synopsis "Lightweight and high performance concurrent cache")
    (description
     "This package provides Lightweight and high performance concurrent cache.")
    (license license:expat)))

(define-public rust-surrealkv-0.6
  (package
    (name "rust-surrealkv")
    (version "0.6.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealkv" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0yir10xz1y6c2mlj5dkiayfmgsg15xxfpra53amrh5r77vf3rc7b"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-async-channel" ,rust-async-channel-2)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-crc32fast" ,rust-crc32fast-1)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-getrandom" ,rust-getrandom-0.2)
                       ("rust-lru" ,rust-lru-0.12)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-quick-cache" ,rust-quick-cache-0.6)
                       ("rust-revision" ,rust-revision-0.10)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-vart" ,rust-vart-0.7)
                       ("rust-wasm-bindgen-futures" ,rust-wasm-bindgen-futures-0.4))))
    (home-page "https://github.com/surrealdb/surrealkv")
    (synopsis
     "low-level, versioned, embedded, ACID-compliant, key-value database for Rust")
    (description
     "This package provides a low-level, versioned, embedded, ACID-compliant,
                   key-value database for Rust.")
    (license license:asl2.0)))

(define-public rust-fail-0.4
  (package
    (name "rust-fail")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fail" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "19l1s48d9ial0rbbwn3h0n0cw8iicbl1x8rypifizjgxb4fcdqrv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-rand" ,rust-rand-0.7))))
    (home-page "https://github.com/tikv/fail-rs")
    (synopsis "Fail points for rust")
    (description "This package provides Fail points for rust.")
    (license license:asl2.0)))

(define-public rust-async-recursion-0.3
  (package
    (name "rust-async-recursion")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-recursion" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "18npixkwglnpvjgp89fpcyzf820ngx3a1hxp4hqbkw81p9b8dmyp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://github.com/dcchut/async-recursion")
    (synopsis "Recursion for async functions")
    (description "This package provides Recursion for async functions.")
    (license (list license:expat license:asl2.0))))

(define-public rust-surrealdb-tikv-client-0.3
  (package
    (name "rust-surrealdb-tikv-client")
    (version "0.3.0-surreal.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealdb-tikv-client" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "050agvxlb14m4pifx6cml2x6j3y2ba7viayzla5lwdrr8bl09qpr"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-recursion" ,rust-async-recursion-0.3)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-derive-new" ,rust-derive-new-0.5)
                       ("rust-either" ,rust-either-1)
                       ("rust-fail" ,rust-fail-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-prometheus" ,rust-prometheus-0.13)
                       ("rust-prost" ,rust-prost-0.12)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-take-mut" ,rust-take-mut-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tonic" ,rust-tonic-0.10))))
    (home-page "https://github.com/tikv/client-rust")
    (synopsis "The Rust language implementation of TiKV client")
    (description
     "This package provides The Rust language implementation of @code{TiKV} client.")
    (license license:asl2.0)))

(define-public rust-surrealdb-derive-0.12
  (package
    (name "rust-surrealdb-derive")
    (version "0.12.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealdb-derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1x6x3mpipijjb5wg6qfk21bdh4h0mxiwvbqh2clz1glyig2v9kda"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://github.com/surrealdb/surrealdb-derive")
    (synopsis "Private implementation of procedural macros for surrealdb")
    (description
     "This package provides Private implementation of procedural macros for surrealdb.")
    (license license:expat)))

(define-public rust-tokio-util-0.7
  (package
    (name "rust-tokio-util")
    (version "0.7.13")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tokio-util" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0y0h10a52c7hrldmr3410bp7j3fadq0jn9nf7awddgd2an6smz6p"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-sink" ,rust-futures-sink-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-slab" ,rust-slab-0.4)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://tokio.rs")
    (synopsis "Additional utilities for working with Tokio.")
    (description
     "This package provides Additional utilities for working with Tokio.")
    (license license:expat)))

(define-public rust-surrealcs-kernel-0.4
  (package
    (name "rust-surrealcs-kernel")
    (version "0.4.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealcs-kernel" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1d90m5qd1fwfg1ynqll81c2xs6kjnmfwmg1c3n0av1cly6qngdnd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bincode" ,rust-bincode-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-nanoservices-utils" ,rust-nanoservices-utils-0.1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-revision" ,rust-revision-0.10)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-tempdir" ,rust-tempdir-0.3)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/surrealdb/surrealcs")
    (synopsis "The SurrealCS kernel code for SurrealDB")
    (description
     "This package provides The @code{SurrealCS} kernel code for @code{SurrealDB}.")
    (license license:asl2.0)))
 ;; YD

(define-public rust-nan-serve-publish-event-0.1
  (package
    (name "rust-nan-serve-publish-event")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "nan-serve-publish-event" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1f5qjpr8pa880jmf3bgf55din8cx88kkn25pxy1sjh1w433kdi9c"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "")
    (synopsis "Tokio event publisher for nanoservices")
    (description
     "This package provides Tokio event publisher for nanoservices.")
    (license license:expat)))

(define-public rust-nan-serve-event-subscriber-0.1
  (package
    (name "rust-nan-serve-event-subscriber")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "nan-serve-event-subscriber" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0p8bb2q43iwkazsjav2zlzy87v07j8f504xd719akg5pwd1z65ah"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "")
    (synopsis "Tokio event subscriber for nanoservices")
    (description
     "This package provides Tokio event subscriber for nanoservices.")
    (license license:expat)))

(define-public rust-syn-2
  (package
    (name "rust-syn")
    (version "2.0.96")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "syn" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "102wk3cgawimi3i0q3r3xw3i858zkyingg6y7gsxfy733amsvl6m"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-unicode-ident" ,rust-unicode-ident-1))))
    (home-page "https://github.com/dtolnay/syn")
    (synopsis "Parser for Rust source code")
    (description "This package provides Parser for Rust source code.")
    (license (list license:expat license:asl2.0))))

(define-public rust-nan-serve-dal-tx-impl-0.1
  (package
    (name "rust-nan-serve-dal-tx-impl")
    (version "0.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "nan-serve-dal-tx-impl" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0fl26ralxzm8xm1qhsq47n8cq6zk6vsmlnd15hlyns32fgv94hwf"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "")
    (synopsis "collection of utilities for nanoservices")
    (description
     "This package provides a collection of utilities for nanoservices.")
    (license license:expat)))

(define-public rust-ctor-0.2
  (package
    (name "rust-ctor")
    (version "0.2.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ctor" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "00b5vprqi4a2cr29xhqijg800b4dwkhrr5wj2kf3s7vnambpi8ij"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/mmastrac/rust-ctor")
    (synopsis "__attribute__((constructor)) for Rust")
    (description
     "This package provides __attribute__((constructor)) for Rust.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-bitcode-derive-0.6
  (package
    (name "rust-bitcode-derive")
    (version "0.6.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bitcode_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1giy4ndl3lsws8ij42v6dlqfnbf1vvkpmd528p9jq2dg2fd3hfd5"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/SoftbearStudios/bitcode/")
    (synopsis "Implementation of #[derive(Encode, Decode)] for bitcode")
    (description
     "This package provides Implementation of #[derive(Encode, Decode)] for bitcode.")
    (license (list license:expat license:asl2.0))))

(define-public rust-bitcode-0.6
  (package
    (name "rust-bitcode")
    (version "0.6.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bitcode" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1167gz68iay84ibi1wjzxjyfc4xz1lnjd94n0azx832n11vcw6zf"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arrayvec" ,rust-arrayvec-0.7)
                       ("rust-bitcode-derive" ,rust-bitcode-derive-0.6)
                       ("rust-bytemuck" ,rust-bytemuck-1)
                       ("rust-glam" ,rust-glam-0.24)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/SoftbearStudios/bitcode")
    (synopsis "bitcode is a bitwise binary serializer")
    (description
     "This package provides bitcode is a bitwise binary serializer.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tungstenite-0.26
  (package
    (name "rust-tungstenite")
    (version "0.26.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tungstenite" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "094cch8z5238q9n5bglmwjmdqm2y4llhw4q8c1jr75apkjlq6c21"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-byteorder" ,rust-byteorder-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-data-encoding" ,rust-data-encoding-2)
                       ("rust-http" ,rust-http-1)
                       ("rust-httparse" ,rust-httparse-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.8)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-url" ,rust-url-2)
                       ("rust-utf-8" ,rust-utf-8-0.7)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26))))
    (home-page "https://github.com/snapview/tungstenite-rs")
    (synopsis "Lightweight stream-based WebSocket implementation")
    (description
     "This package provides Lightweight stream-based @code{WebSocket} implementation.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tokio-tungstenite-0.26
  (package
    (name "rust-tokio-tungstenite")
    (version "0.26.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tokio-tungstenite" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0nh2nzin00cgfp9p7g76kn7riaydfksam0661vgdxz39rpzgcjxy"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.8)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.26)
                       ("rust-tungstenite" ,rust-tungstenite-0.26)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26))))
    (home-page "https://github.com/snapview/tokio-tungstenite")
    (synopsis
     "Tokio binding for Tungstenite, the Lightweight stream-based WebSocket implementation")
    (description
     "This package provides Tokio binding for Tungstenite, the Lightweight stream-based @code{WebSocket}
                   implementation.")
    (license license:expat)))

(define-public rust-matchit-0.8
  (package
    (name "rust-matchit")
    (version "0.8.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "matchit" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1hzl48fwq1cn5dvshfly6vzkzqhfihya65zpj7nz7lfx82mgzqa7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/ibraheemdev/matchit")
    (synopsis "high performance, zero-copy URL router.")
    (description
     "This package provides a high performance, zero-copy URL router.")
    (license (list license:expat license:bsd-3))))

(define-public rust-axum-macros-0.5
  (package
    (name "rust-axum-macros")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "axum-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0p6011ld0izk22fmdxsps58cigilq2yhnmyqw4f8bslg09gdwkv0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/tokio-rs/axum")
    (synopsis "Macros for axum")
    (description "This package provides Macros for axum.")
    (license license:expat)))

(define-public rust-axum-core-0.5
  (package
    (name "rust-axum-core")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "axum-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0cxpk0vbqd77zq49hjzrbszn35lgx469ghcrw55045pxcbrn44yz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-http" ,rust-http-1)
                       ("rust-http-body" ,rust-http-body-1)
                       ("rust-http-body-util" ,rust-http-body-util-0.1)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-rustversion" ,rust-rustversion-1)
                       ("rust-sync-wrapper" ,rust-sync-wrapper-1)
                       ("rust-tower-http" ,rust-tower-http-0.6)
                       ("rust-tower-layer" ,rust-tower-layer-0.3)
                       ("rust-tower-service" ,rust-tower-service-0.3)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/tokio-rs/axum")
    (synopsis "Core types and traits for axum")
    (description "This package provides Core types and traits for axum.")
    (license license:expat)))

(define-public rust-axum-0.8
  (package
    (name "rust-axum")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "axum" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1f78gc3sp2vx2dll147fm9yl697y38mz9jmrqssb662yqwjdcvvd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-axum-core" ,rust-axum-core-0.5)
                       ("rust-axum-macros" ,rust-axum-macros-0.5)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-form-urlencoded" ,rust-form-urlencoded-1)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-http" ,rust-http-1)
                       ("rust-http-body" ,rust-http-body-1)
                       ("rust-http-body-util" ,rust-http-body-util-0.1)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-hyper-util" ,rust-hyper-util-0.1)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-matchit" ,rust-matchit-0.8)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-multer" ,rust-multer-3)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-rustversion" ,rust-rustversion-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-path-to-error" ,rust-serde-path-to-error-0.1)
                       ("rust-serde-urlencoded" ,rust-serde-urlencoded-0.7)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-sync-wrapper" ,rust-sync-wrapper-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-tungstenite" ,rust-tokio-tungstenite-0.26)
                       ("rust-tower" ,rust-tower-0.5)
                       ("rust-tower-http" ,rust-tower-http-0.6)
                       ("rust-tower-layer" ,rust-tower-layer-0.3)
                       ("rust-tower-service" ,rust-tower-service-0.3)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/tokio-rs/axum")
    (synopsis "Web framework that focuses on ergonomics and modularity")
    (description
     "This package provides Web framework that focuses on ergonomics and modularity.")
    (license license:expat)))

(define-public rust-nanoservices-utils-0.1
  (package
    (name "rust-nanoservices-utils")
    (version "0.1.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "nanoservices-utils" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "10d0gn8r7402yc8dg3wgw9y112rak9p43dqn3z5k6s1a4k7yxy8h"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-actix-web" ,rust-actix-web-4)
                       ("rust-axum" ,rust-axum-0.8)
                       ("rust-bincode" ,rust-bincode-1)
                       ("rust-bitcode" ,rust-bitcode-0.6)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-ctor" ,rust-ctor-0.2)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-http-body-util" ,rust-http-body-util-0.1)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-jsonwebtoken" ,rust-jsonwebtoken-9)
                       ("rust-nan-serve-dal-tx-impl" ,rust-nan-serve-dal-tx-impl-0.1)
                       ("rust-nan-serve-event-subscriber" ,rust-nan-serve-event-subscriber-0.1)
                       ("rust-nan-serve-publish-event" ,rust-nan-serve-publish-event-0.1)
                       ("rust-paste" ,rust-paste-1)
                       ("rust-revision" ,rust-revision-0.10)
                       ("rust-rocket" ,rust-rocket-0.5)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sqlx" ,rust-sqlx-0.8)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-util" ,rust-tokio-util-0.7))))
    (home-page "")
    (synopsis "collection of utilities for nanoservices")
    (description
     "This package provides a collection of utilities for nanoservices.")
    (license license:expat)))

(define-public rust-surrealcs-0.4
  (package
    (name "rust-surrealcs")
    (version "0.4.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealcs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1rksqf3snj4n9lbw5bnn9mwcqcrpxa4n7ydn6zqmqvjg4xnzk411"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-nanoservices-utils" ,rust-nanoservices-utils-0.1)
                       ("rust-num-cpus" ,rust-num-cpus-1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-surrealcs-kernel" ,rust-surrealcs-kernel-0.4)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-tracing-subscriber" ,rust-tracing-subscriber-0.3))))
    (home-page "https://github.com/surrealdb/surrealcs")
    (synopsis "The SurrealCS client code for SurrealDB")
    (description
     "This package provides The @code{SurrealCS} client code for @code{SurrealDB}.")
    (license license:asl2.0)))
 ;YD

(define-public rust-storekey-0.5
  (package
    (name "rust-storekey")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "storekey" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1cl5xwm7n3mmyhw2ki55cr3rkj8c9q8qf7gp8jrj6paahcrjii23"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-byteorder" ,rust-byteorder-1)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/surrealdb/storekey")
    (synopsis
     "Lexicographic sort-order preserving binary encoding format for key-value stores")
    (description
     "This package provides Lexicographic sort-order preserving binary encoding format for key-value stores.")
    (license license:asl2.0)))

(define-public rust-rust-stemmers-1
  (package
    (name "rust-rust-stemmers")
    (version "1.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rust-stemmers" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0m6acgdflrrcm17dj7lp7x4sfqqhga24qynv660qinwz04v20sp4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1))))
    (home-page "https://github.com/CurrySoftware/rust-stemmers")
    (synopsis
     "rust implementation of some popular snowball stemming algorithms")
    (description
     "This package provides a rust implementation of some popular snowball stemming
                   algorithms.")
    (license (list license:expat license:bsd-3))))

(define-public rust-rquickjs-macro-0.8
  (package
    (name "rust-rquickjs-macro")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rquickjs-macro" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1wx2a9q4nhi59y99scpgmfifixa64igf0sh26vczq6f0611i0hb0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-convert-case" ,rust-convert-case-0.6)
                       ("rust-fnv" ,rust-fnv-1)
                       ("rust-ident-case" ,rust-ident-case-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-phf-generator" ,rust-phf-generator-0.11)
                       ("rust-phf-shared" ,rust-phf-shared-0.11)
                       ("rust-proc-macro-crate" ,rust-proc-macro-crate-1)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-rquickjs-core" ,rust-rquickjs-core-0.8)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/DelSkayn/rquickjs.git")
    (synopsis "Procedural macros for rquickjs")
    (description "This package provides Procedural macros for rquickjs.")
    (license license:expat)))

(define-public rust-rquickjs-sys-0.8
  (package
    (name "rust-rquickjs-sys")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rquickjs-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "02krz512lkvdvn2s4df11fsz8wf2qvy0q03c30y4qq33nv355hsb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.69)
                       ("rust-cc" ,rust-cc-1)
                       ("rust-pretty-env-logger" ,rust-pretty-env-logger-0.5))))
    (home-page "https://github.com/DelSkayn/rquickjs.git")
    (synopsis "QuickJS bindings for rquickjs")
    (description "This package provides @code{QuickJS} bindings for rquickjs.")
    (license license:expat)))

(define-public rust-dlopen-derive-0.1
  (package
    (name "rust-dlopen-derive")
    (version "0.1.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dlopen_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "10f58rcw1xnm5b5xg735ws0cvsz8qzfcigcw1zm1rn7vn7hxjdpj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-quote" ,rust-quote-0.6)
                       ("rust-syn" ,rust-syn-0.15))))
    (home-page "")
    (synopsis "Derive macros for the dlopen crate")
    (description "This package provides Derive macros for the dlopen crate.")
    (license license:expat)))

(define-public rust-dlopen-0.1
  (package
    (name "rust-dlopen")
    (version "0.1.8")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dlopen" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0dq9m3fqf194vaw1ldn3c5ssdj255l5dag2qd2z9ljl1kz9hms3i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-dlopen-derive" ,rust-dlopen-derive-0.1)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-winapi" ,rust-winapi-0.3))))
    (home-page "https://github.com/szymonwieloch/rust-dlopen")
    (synopsis
     "Library for opening and operating on dynamic link libraries (also known as shared objects or shared libraries). This is a modern and more flexible alternative to the already existing libraries like libloading or sharedlib")
    (description
     "This package provides Library for opening and operating on dynamic link libraries (also known as
                   shared objects or shared libraries). This is a modern and more flexible
                 alternative to the already existing libraries like libloading or sharedlib.")
    (license license:expat)))

(define-public rust-rquickjs-core-0.8
  (package
    (name "rust-rquickjs-core")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rquickjs-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0yq895ldp9hl1nh6inq1hxldgr73qdy0xs8i116ghki0kqvvd3bc"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-lock" ,rust-async-lock-3)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-dlopen" ,rust-dlopen-0.1)
                       ("rust-either" ,rust-either-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-phf" ,rust-phf-0.11)
                       ("rust-relative-path" ,rust-relative-path-1)
                       ("rust-rquickjs-sys" ,rust-rquickjs-sys-0.8))))
    (home-page "https://github.com/DelSkayn/rquickjs.git")
    (synopsis "High level bindings to the QuickJS JavaScript engine")
    (description
     "This package provides High level bindings to the @code{QuickJS} @code{JavaScript} engine.")
    (license license:expat)))

(define-public rust-rquickjs-0.8
  (package
    (name "rust-rquickjs")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rquickjs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0364lxxps0jlxn95prddjc3fqifycfs8i8cl23hdi7lyy2zn2rni"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-either" ,rust-either-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-rquickjs-core" ,rust-rquickjs-core-0.8)
                       ("rust-rquickjs-macro" ,rust-rquickjs-macro-0.8))))
    (home-page "https://github.com/DelSkayn/rquickjs.git")
    (synopsis "High level bindings to the QuickJS JavaScript engine")
    (description
     "This package provides High level bindings to the @code{QuickJS} @code{JavaScript} engine.")
    (license license:expat)))

(define-public rust-librocksdb-sys-0.16
  (package
    (name "rust-librocksdb-sys")
    (version "0.16.0+8.10.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "librocksdb-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "131l7rlcrnb44wkj5gx7qmjxnx9z21fb8gwhhcfdqccq0ny60gff"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.69)
                       ("rust-bzip2-sys" ,rust-bzip2-sys-0.1)
                       ("rust-cc" ,rust-cc-1)
                       ("rust-glob" ,rust-glob-0.3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-libz-sys" ,rust-libz-sys-1)
                       ("rust-lz4-sys" ,rust-lz4-sys-1)
                       ("rust-pkg-config" ,rust-pkg-config-0.3)
                       ("rust-tikv-jemalloc-sys" ,rust-tikv-jemalloc-sys-0.5)
                       ("rust-zstd-sys" ,rust-zstd-sys-2))))
    (home-page "https://github.com/rust-rocksdb/rust-rocksdb")
    (synopsis "Native bindings to librocksdb")
    (description "This package provides Native bindings to librocksdb.")
    (license (list license:expat license:asl2.0 license:bsd-3))))

(define-public rust-rocksdb-0.22
  (package
    (name "rust-rocksdb")
    (version "0.22.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rocksdb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "19x7c2m7j0lsfwplgx4rdikqgmbwaqki25k9ll7cvf6psrakxlbb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-librocksdb-sys" ,rust-librocksdb-sys-0.16)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/rust-rocksdb/rust-rocksdb")
    (synopsis "Rust wrapper for Facebook's RocksDB embeddable database")
    (description
     "This package provides Rust wrapper for Facebook's @code{RocksDB} embeddable database.")
    (license license:asl2.0)))

(define-public rust-assoc-0.1
  (package
    (name "rust-assoc")
    (version "0.1.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "assoc" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1a2rk2fcazrhv8bszxiibf8pdj4hbzqk7dm4gwldgfdd7lcp1p5z"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/mingyli/assoc")
    (synopsis "Treat vectors like associative arrays")
    (description
     "This package provides Treat vectors like associative arrays.")
    (license license:expat)))

(define-public rust-shuttle-0.7
  (package
    (name "rust-shuttle")
    (version "0.7.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "shuttle" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "164wgf788qhmjla1w09jp8ibvg49lw385839y5ivdqj43av8v6id"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-assoc" ,rust-assoc-0.1)
                       ("rust-bitvec" ,rust-bitvec-1)
                       ("rust-generator" ,rust-generator-0.8)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-owo-colors" ,rust-owo-colors-3)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rand-core" ,rust-rand-core-0.6)
                       ("rust-rand-pcg" ,rust-rand-pcg-0.3)
                       ("rust-scoped-tls" ,rust-scoped-tls-1)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/awslabs/shuttle")
    (synopsis "library for testing concurrent Rust code")
    (description
     "This package provides a library for testing concurrent Rust code.")
    (license license:asl2.0)))

(define-public rust-quick-cache-0.5
  (package
    (name "rust-quick-cache")
    (version "0.5.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "quick_cache" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1p6knq8ljm8jj75bqlv5hsxh63z6vyf4xk9676wnnrv8fsma2mgb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-equivalent" ,rust-equivalent-1)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-shuttle" ,rust-shuttle-0.7))))
    (home-page "https://github.com/arthurprs/quick-cache")
    (synopsis "Lightweight and high performance concurrent cache")
    (description
     "This package provides Lightweight and high performance concurrent cache.")
    (license license:expat)))

(define-public rust-object-store-0.10
  (package
    (name "rust-object-store")
    (version "0.10.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "object_store" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1wz3m20hqs3v93dyxcqy7qpsbd4rqp6050hy49wcw5f740l4bnp6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-humantime" ,rust-humantime-2)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-itertools" ,rust-itertools-0.13)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-quick-xml" ,rust-quick-xml-0.36)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-ring" ,rust-ring-0.17)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-snafu" ,rust-snafu-0.7)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-walkdir" ,rust-walkdir-2))))
    (home-page "https://github.com/apache/arrow-rs/tree/main/object_store")
    (synopsis
     "generic object store interface for uniformly interacting with AWS S3, Google Cloud Storage, Azure Blob Storage and local files.")
    (description
     "This package provides a generic object store interface for uniformly interacting
                   with AWS S3, Google Cloud Storage, Azure Blob Storage and local files.")
    (license (list license:expat license:asl2.0))))

(define-public rust-noisy-float-0.2
  (package
    (name "rust-noisy-float")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "noisy_float" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1bqkl82pfp98i98s3van73hkvqcx5p55dm1wagg57gy0xgkfd3wp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-approx" ,rust-approx-0.4)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/SergiusIW/noisy_float-rs")
    (synopsis
     "Contains floating point types that panic if they are set to an illegal value, such as NaN")
    (description
     "This package contains floating point types that panic if they are set to an
                   illegal value, such as @code{NaN}.")
    (license license:asl2.0)))

(define-public rust-ndarray-stats-0.5
  (package
    (name "rust-ndarray-stats")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ndarray-stats" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "007lr2q3dq17n69dlkm2md1jkh9nhz1f0rzxs5dpp1wnmivq8nmg"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-indexmap" ,rust-indexmap-1)
                       ("rust-itertools" ,rust-itertools-0.10)
                       ("rust-ndarray" ,rust-ndarray-0.15)
                       ("rust-noisy-float" ,rust-noisy-float-0.2)
                       ("rust-num-integer" ,rust-num-integer-0.1)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-rand" ,rust-rand-0.8))))
    (home-page "https://github.com/rust-ndarray/ndarray-stats")
    (synopsis
     "Statistical routines for ArrayBase, the n-dimensional array data structure provided by ndarray")
    (description
     "This package provides Statistical routines for @code{ArrayBase}, the n-dimensional array data
                   structure provided by ndarray.")
    (license (list license:expat license:asl2.0))))

(define-public rust-nanoid-0.4
  (package
    (name "rust-nanoid")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "nanoid" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1n5l5xig5zcinh41bb4p0rzam8gxic02qpngnylb3d8pq3g01yiz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-rand" ,rust-rand-0.8))))
    (home-page "https://github.com/nikolay-govorov/nanoid")
    (synopsis
     "tiny, secure, URL-friendly, unique string ID generator for Rust.")
    (description
     "This package provides a tiny, secure, URL-friendly, unique string ID generator
                   for Rust.")
    (license license:expat)))

(define-public rust-linfa-linalg-0.1
  (package
    (name "rust-linfa-linalg")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "linfa-linalg" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "10mcfr8k0syjxj9g14v8iv3lr25j7c0nfw49cwrnv1y884mmdrsn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ndarray" ,rust-ndarray-0.15)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/rust-ml/linfa-linalg")
    (synopsis
     "Pure-Rust implementation of linear algebra routines for ndarray")
    (description
     "This package provides Pure-Rust implementation of linear algebra routines for ndarray.")
    (license (list license:expat license:asl2.0))))

(define-public rust-lexicmp-0.1
  (package
    (name "rust-lexicmp")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "lexicmp" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0pgad083sqsdb9ip0qlhng240c8qimk92zmx5jrn6h7jvlqx2y3k"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-any-ascii" ,rust-any-ascii-0.3))))
    (home-page "https://github.com/surrealdb/lexicmp")
    (synopsis
     "Library for comparing and sorting strings lexicographically and naturally")
    (description
     "This package provides Library for comparing and sorting strings lexicographically and naturally.")
    (license (list license:expat license:asl2.0))))

(define-public rust-console-error-panic-hook-0.1
  (package
    (name "rust-console-error-panic-hook")
    (version "0.1.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "console_error_panic_hook" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1g5v8s0ndycc10mdn6igy914k645pgpcl8vjpz6nvxkhyirynsm0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2))))
    (home-page "https://github.com/rustwasm/console_error_panic_hook")
    (synopsis
     "panic hook for `wasm32-unknown-unknown` that logs panics to `console.error`")
    (description
     "This package provides a panic hook for `wasm32-unknown-unknown` that logs panics
                   to `console.error`.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-rexie-0.4
  (package
    (name "rust-rexie")
    (version "0.4.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rexie" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1caiydc4pm3xk3l6wpmp9yavy5vm2gmwsa2fjgf6q56zkkzp5wgy"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-console-error-panic-hook" ,rust-console-error-panic-hook-0.1)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-web-sys" ,rust-web-sys-0.3)
                       ("rust-wee-alloc" ,rust-wee-alloc-0.4))))
    (home-page "https://github.com/devashishdxt/rexie")
    (synopsis
     "Rexie is an easy-to-use, futures based wrapper around IndexedDB that compiles to webassembly")
    (description
     "This package provides Rexie is an easy-to-use, futures based wrapper around @code{IndexedDB} that
                   compiles to webassembly.")
    (license (list license:expat license:asl2.0))))

(define-public rust-indxdb-0.5
  (package
    (name "rust-indxdb")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "indxdb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1bsn382vf52fw1mqpxxjgm9j38p6p7gymx36gsz7aqa6wgmjhzl1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-rexie" ,rust-rexie-0.4)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2))))
    (home-page "https://github.com/surrealdb/indxdb")
    (synopsis
     "key-value database engine abstraction layer for IndexedDB running in WASM")
    (description
     "This package provides a key-value database engine abstraction layer for
                   @code{IndexedDB} running in WASM.")
    (license license:asl2.0)))

(define-public rust-slotmap-0.4
  (package
    (name "rust-slotmap")
    (version "0.4.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "slotmap" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1cga58417vz6m0bazvicprb01mm1x690wy8rj7g8fyvnqn24dwvb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/orlp/slotmap")
    (synopsis "Slotmap data structure")
    (description "This package provides Slotmap data structure.")
    (license license:zlib)))

(define-public rust-deepsize-derive-0.1
  (package
    (name "rust-deepsize-derive")
    (version "0.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "deepsize_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "15i7qybxhdp2y2h3xksyiqrwqki8xrvl60j1asjc3j1v3za020cr"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://github.com/Aeledfyr/deepsize/")
    (synopsis
     "crate for measuring the total size of object on the stack and heap")
    (description
     "This package provides a crate for measuring the total size of object on the
                   stack and heap.")
    (license license:expat)))

(define-public rust-deepsize-0.2
  (package
    (name "rust-deepsize")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "deepsize" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0v5rn98i6j4jfpcm93mg8by3ddwhanvjiyd3pszzfsvgqdz9inqw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arrayvec" ,rust-arrayvec-0.5)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-deepsize-derive" ,rust-deepsize-derive-0.1)
                       ("rust-hashbrown" ,rust-hashbrown-0.9)
                       ("rust-indexmap" ,rust-indexmap-1)
                       ("rust-slab" ,rust-slab-0.4)
                       ("rust-slotmap" ,rust-slotmap-0.4)
                       ("rust-smallvec" ,rust-smallvec-1))))
    (home-page "https://github.com/Aeledfyr/deepsize/")
    (synopsis
     "crate for measuring the total size of object on the stack and heap")
    (description
     "This package provides a crate for measuring the total size of object on the
                   stack and heap.")
    (license license:expat)))

(define-public rust-ext-sort-0.1
  (package
    (name "rust-ext-sort")
    (version "0.1.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ext-sort" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "04qa7lf3wmqzz13n8fwxc8wg2k0r392394m3xcdm1avyc523xxzw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytesize" ,rust-bytesize-1)
                       ("rust-clap" ,rust-clap-3)
                       ("rust-deepsize" ,rust-deepsize-0.2)
                       ("rust-env-logger" ,rust-env-logger-0.9)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-rmp-serde" ,rust-rmp-serde-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-tempfile" ,rust-tempfile-3))))
    (home-page "https://github.com/dapper91/ext-sort-rs")
    (synopsis "rust external sort algorithm implementation")
    (description
     "This package provides rust external sort algorithm implementation.")
    (license license:unlicense)))

(define-public rust-mintex-0.1
  (package
    (name "rust-mintex")
    (version "0.1.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "mintex" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "01ydy8pvyy96cjvjh4hgfqmjalr6hnbyc6c8a9xwq4yvznc4bv4v"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/garypen/mintex")
    (synopsis "minimal mutex")
    (description "This package provides minimal mutex.")
    (license license:asl2.0)))

(define-public rust-dhat-0.3
  (package
    (name "rust-dhat")
    (version "0.3.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dhat" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "09xq763lpf0kdv4fzbdgxkd4sgv3p08dwrz41kg37qi88vc13kcq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-mintex" ,rust-mintex-0.1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-rustc-hash" ,rust-rustc-hash-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-thousands" ,rust-thousands-0.2))))
    (home-page "https://github.com/nnethercote/dhat-rs")
    (synopsis "library for heap profiling and ad hoc profiling with DHAT.")
    (description
     "This package provides a library for heap profiling and ad hoc profiling with
                   DHAT.")
    (license (list license:expat license:asl2.0))))

(define-public rust-unicode-security-0.1
  (package
    (name "rust-unicode-security")
    (version "0.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "unicode-security" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0l2yidnwc7g791pyqz44p3jg9msmf5miclhwnvc5xlsxafhxnk9f"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compiler-builtins" ,rust-compiler-builtins-0.1)
                       ("rust-rustc-std-workspace-core" ,rust-rustc-std-workspace-core-1)
                       ("rust-rustc-std-workspace-std" ,rust-rustc-std-workspace-std-1)
                       ("rust-unicode-normalization" ,rust-unicode-normalization-0.1)
                       ("rust-unicode-script" ,rust-unicode-script-0.5))))
    (home-page "https://github.com/unicode-rs/unicode-security")
    (synopsis
     "Detect possible security problems with Unicode usage
                           according to Unicode Technical Standard #39 rules.")
    (description
     "This package provides Detect possible security problems with Unicode usage according to Unicode
                             Technical Standard #39 rules.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-with-macros-3
  (package
    (name "rust-serde-with-macros")
    (version "3.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_with_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1277nm0ry2bs52zd5kkddgkzk5s2mhi80x74dnqj68ssyyslwqwk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-darling" ,rust-darling-0.20)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/jonasbb/serde_with/")
    (synopsis "proc-macro library for serde_with")
    (description "This package provides proc-macro library for serde_with.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-with-3
  (package
    (name "rust-serde-with")
    (version "3.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_with" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "08sw83b6hfwzylr0waf4mc29h6fxnb02g7vkwbkjjyhvrin27kb4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-doc-comment" ,rust-doc-comment-0.3)
                       ("rust-document-features" ,rust-document-features-0.2)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-indexmap" ,rust-indexmap-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-with-macros" ,rust-serde-with-macros-3)
                       ("rust-time" ,rust-time-0.3))))
    (home-page "https://github.com/jonasbb/serde_with/")
    (synopsis "Custom de/serialization functions for Rust's serde")
    (description
     "This package provides Custom de/serialization functions for Rust's serde.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-json-1
  (package
    (name "rust-serde-json")
    (version "1.0.108")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_json" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ssj59s7lpzqh1m50kfzlnrip0p0jg9lmhn4098i33a0mhz7w71x"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-indexmap" ,rust-indexmap-2)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-ryu" ,rust-ryu-1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/serde-rs/json")
    (synopsis "JSON serialization file format")
    (description "This package provides a JSON serialization file format.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-derive-1
  (package
    (name "rust-serde-derive")
    (version "1.0.193")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1lwlx2k7wxr1v160kpyqjfabs37gm1yxqg65383rnyrm06jnqms3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://serde.rs")
    (synopsis "Macros 1.1 implementation of #[derive(Serialize, Deserialize)]")
    (description
     "This package provides Macros 1.1 implementation of #[derive(Serialize, Deserialize)].")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-1
  (package
    (name "rust-serde")
    (version "1.0.193")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "129b0j67594f8qg5cbyi3nyk31y97wrqihi026mba34dwrsrkp95"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-derive" ,rust-serde-derive-1))))
    (home-page "https://serde.rs")
    (synopsis "generic serialization/deserialization framework")
    (description
     "This package provides a generic serialization/deserialization framework.")
    (license (list license:expat license:asl2.0))))

(define-public rust-cedar-policy-validator-2
  (package
    (name "rust-cedar-policy-validator")
    (version "2.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cedar-policy-validator" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "07m02w83cagw3xm4cn6ajgb13ji9si5m2nbwsa35xla7d4nbf4v8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-cedar-policy-core" ,rust-cedar-policy-core-2)
                       ("rust-itertools" ,rust-itertools-0.10)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-with" ,rust-serde-with-3)
                       ("rust-smol-str" ,rust-smol-str-0.2)
                       ("rust-stacker" ,rust-stacker-0.1)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-unicode-security" ,rust-unicode-security-0.1))))
    (home-page "https://cedarpolicy.com")
    (synopsis "Validator for the Cedar Policy language")
    (description
     "This package provides Validator for the Cedar Policy language.")
    (license license:asl2.0)))

(define-public rust-rustc-lexer-0.1
  (package
    (name "rust-rustc-lexer")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rustc_lexer" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "198n5pg94jgzj76s783cvkbqjwp7l4v1mvh52g00hq8nfw6awsn8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-unicode-xid" ,rust-unicode-xid-0.2))))
    (home-page "https://github.com/rust-lang/rust/")
    (synopsis
     "Rust lexer used by rustc. No stability guarantees are provided.")
    (description
     "This package provides Rust lexer used by rustc. No stability guarantees are provided.")
    (license (list license:expat license:asl2.0))))

(define-public rust-cedar-policy-core-2
  (package
    (name "rust-cedar-policy-core")
    (version "2.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cedar-policy-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "08v6yixq6h2qcgx0v6rqj6a463fyva583j2jwmnkzpm9zcmnzrmm"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-either" ,rust-either-1)
                       ("rust-ipnet" ,rust-ipnet-2)
                       ("rust-itertools" ,rust-itertools-0.10)
                       ("rust-lalrpop" ,rust-lalrpop-0.20)
                       ("rust-lalrpop-util" ,rust-lalrpop-util-0.20)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-miette" ,rust-miette-5)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-rustc-lexer" ,rust-rustc-lexer-0.1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-with" ,rust-serde-with-3)
                       ("rust-smol-str" ,rust-smol-str-0.2)
                       ("rust-stacker" ,rust-stacker-0.1)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://cedarpolicy.com")
    (synopsis "Core implementation of the Cedar policy language")
    (description
     "This package provides Core implementation of the Cedar policy language.")
    (license license:asl2.0)))

(define-public rust-cedar-policy-2
  (package
    (name "rust-cedar-policy")
    (version "2.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cedar-policy" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1pha7gsa8lzc3a89390261iz3m437y6mfaldd2z0pm0nf9p5q5px"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cedar-policy-core" ,rust-cedar-policy-core-2)
                       ("rust-cedar-policy-validator" ,rust-cedar-policy-validator-2)
                       ("rust-dhat" ,rust-dhat-0.3)
                       ("rust-itertools" ,rust-itertools-0.10)
                       ("rust-lalrpop-util" ,rust-lalrpop-util-0.20)
                       ("rust-ref-cast" ,rust-ref-cast-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-smol-str" ,rust-smol-str-0.2)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://cedarpolicy.com")
    (synopsis
     "Cedar is a language for defining permissions as policies, which describe who should have access to what")
    (description
     "This package provides Cedar is a language for defining permissions as policies, which describe who
                   should have access to what.")
    (license license:asl2.0)))

(define-public rust-bcrypt-0.15
  (package
    (name "rust-bcrypt")
    (version "0.15.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bcrypt" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1iv2fvy5yywkx4kijqyy59bq92gldv3nqd4bry97vx4f0pnkhng6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-blowfish" ,rust-blowfish-0.9)
                       ("rust-getrandom" ,rust-getrandom-0.2)
                       ("rust-subtle" ,rust-subtle-2)
                       ("rust-zeroize" ,rust-zeroize-1))))
    (home-page "https://github.com/Keats/rust-bcrypt")
    (synopsis "Easily hash and verify passwords using bcrypt")
    (description
     "This package provides Easily hash and verify passwords using bcrypt.")
    (license license:expat)))

(define-public rust-zxcvbn-2
  (package
    (name "rust-zxcvbn")
    (version "2.2.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "zxcvbn" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1r4l1i76sdk51syp032kbjngmxwgqhjprs40yfda43ppzx8shgqh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-derive-builder" ,rust-derive-builder-0.12)
                       ("rust-fancy-regex" ,rust-fancy-regex-0.11)
                       ("rust-itertools" ,rust-itertools-0.10)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-quick-error" ,rust-quick-error-2)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-time" ,rust-time-0.3))))
    (home-page "https://github.com/shssoichiro/zxcvbn-rs")
    (synopsis
     "An entropy-based password strength estimator, originally for Javascript by Dropbox")
    (description
     "This package provides An entropy-based password strength estimator, originally for Javascript by
                   Dropbox.")
    (license license:expat)))

(define-public rust-proc-static-assertions-next-0.0.1
  (package
    (name "rust-proc-static-assertions-next")
    (version "0.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "proc_static_assertions_next" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0x8cvd5sw4c35p90lrw4rygpaw8lv8vg3isljv8r7amsh79bhm0r"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/scuffletv/static-assertions")
    (synopsis "Compile-time assertions via procedural macros")
    (description
     "This package provides Compile-time assertions via procedural macros.")
    (license (list license:expat license:asl2.0))))

(define-public rust-static-assertions-next-1
  (package
    (name "rust-static-assertions-next")
    (version "1.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "static_assertions_next" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0rn7c362606jj1lp3ff3vsicjmpr2x1qra9zd25rlpjrh98sxgnp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-static-assertions-next" ,rust-proc-static-assertions-next-0.0.1))))
    (home-page "https://github.com/scuffletv/static-assertions")
    (synopsis "Compile-time assertions to ensure that invariants are met")
    (description
     "This package provides Compile-time assertions to ensure that invariants are met.")
    (license (list license:expat license:asl2.0))))

(define-public rust-smol-str-0.3
  (package
    (name "rust-smol-str")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "smol_str" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "039mj6lc1vkljj17ndlzzkak8kvlmw8ppi6yjdxsh433snfbhxln"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-borsh" ,rust-borsh-1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/rust-analyzer/smol_str")
    (synopsis "small-string optimized string type with O(1) clone")
    (description
     "This package provides small-string optimized string type with O(1) clone.")
    (license (list license:expat license:asl2.0))))

(define-public rust-opentelemetry-0.27
  (package
    (name "rust-opentelemetry")
    (version "0.27.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "opentelemetry" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1mx6kc1479pkak49xxy98jzqnfilkm1bc56liryvjdzd52606w5b"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-sink" ,rust-futures-sink-0.3)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/open-telemetry/opentelemetry-rust")
    (synopsis "OpenTelemetry API for Rust")
    (description "This package provides @code{OpenTelemetry} API for Rust.")
    (license license:asl2.0)))

(define-public rust-async-graphql-value-7
  (package
    (name "rust-async-graphql-value")
    (version "7.0.14")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-graphql-value" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0fm616f9vdmnv87q4l3r48kpiqvxv7lf386a2rg5hhffndxflrk2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/async-graphql/async-graphql")
    (synopsis "GraphQL value for async-graphql")
    (description
     "This package provides @code{GraphQL} value for async-graphql.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-graphql-parser-7
  (package
    (name "rust-async-graphql-parser")
    (version "7.0.14")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-graphql-parser" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0wn7c7040rm8gzrs20smciyzx70vy6r2m3ll4sfjibgwaxz6k9bw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-graphql-value" ,rust-async-graphql-value-7)
                       ("rust-pest" ,rust-pest-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/async-graphql/async-graphql")
    (synopsis "GraphQL query parser for async-graphql")
    (description
     "This package provides @code{GraphQL} query parser for async-graphql.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-graphql-derive-7
  (package
    (name "rust-async-graphql-derive")
    (version "7.0.14")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-graphql-derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0i20r4371f6b92all9l49y19g41ymirpcagnmrs9jyrz56nz7ml8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-graphql-parser" ,rust-async-graphql-parser-7)
                       ("rust-darling" ,rust-darling-0.20)
                       ("rust-inflector" ,rust-inflector-0.11)
                       ("rust-proc-macro-crate" ,rust-proc-macro-crate-3)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-strum" ,rust-strum-0.26)
                       ("rust-syn" ,rust-syn-2)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/async-graphql/async-graphql")
    (synopsis "Macros for async-graphql")
    (description "This package provides Macros for async-graphql.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-graphql-7
  (package
    (name "rust-async-graphql")
    (version "7.0.14")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-graphql" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1w9i1cwlf4kf2jzg23xy9s1irbqb7b3v3f83ir1182p06iir3ag0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-graphql-derive" ,rust-async-graphql-derive-7)
                       ("rust-async-graphql-parser" ,rust-async-graphql-parser-7)
                       ("rust-async-graphql-value" ,rust-async-graphql-value-7)
                       ("rust-async-stream" ,rust-async-stream-0.3)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-blocking" ,rust-blocking-1)
                       ("rust-bson" ,rust-bson-2)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-chrono-tz" ,rust-chrono-tz-0.10)
                       ("rust-fast-chemail" ,rust-fast-chemail-0.9)
                       ("rust-fnv" ,rust-fnv-1)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-timer" ,rust-futures-timer-3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-handlebars" ,rust-handlebars-5)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-http" ,rust-http-1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-iso8601" ,rust-iso8601-0.6)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-lru" ,rust-lru-0.12)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-multer" ,rust-multer-3)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-opentelemetry" ,rust-opentelemetry-0.27)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-schemars" ,rust-schemars-0.8)
                       ("rust-secrecy" ,rust-secrecy-0.10)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-cbor" ,rust-serde-cbor-0.11)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-urlencoded" ,rust-serde-urlencoded-0.7)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-smol-str" ,rust-smol-str-0.3)
                       ("rust-static-assertions-next" ,rust-static-assertions-next-1)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-tracing-futures" ,rust-tracing-futures-0.2)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-zxcvbn" ,rust-zxcvbn-2))))
    (home-page "https://github.com/async-graphql/async-graphql")
    (synopsis "GraphQL server library implemented in Rust")
    (description
     "This package provides a @code{GraphQL} server library implemented in Rust.")
    (license (list license:expat license:asl2.0))))

(define-public rust-any-ascii-0.3
  (package
    (name "rust-any-ascii")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "any_ascii" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0b6c2vb3wlzcsd7s5l6s9fyq4r07a8yab9r7qvw474sbg95v2l7a"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://anyascii.com")
    (synopsis "Unicode to ASCII transliteration")
    (description "This package provides Unicode to ASCII transliteration.")
    (license license:isc)))

(define-public rust-addr-0.15
  (package
    (name "rust-addr")
    (version "0.15.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "addr" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1vrbnzv4r7sx65mmi011aiafc7b1866iywnchx8asc72vd0qlfx9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-no-std-net" ,rust-no-std-net-0.5)
                       ("rust-psl" ,rust-psl-2)
                       ("rust-psl-types" ,rust-psl-types-2)
                       ("rust-publicsuffix" ,rust-publicsuffix-2)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/addr-rs/addr")
    (synopsis "library for parsing domain names")
    (description "This package provides a library for parsing domain names.")
    (license (list license:expat license:asl2.0))))

(define-public rust-surrealdb-core-2
  (package
    (name "rust-surrealdb-core")
    (version "2.1.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealdb-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1skd2d5hfbg0by0skxm9psq08rlla19w48zr1jwqyb4c3pgn6ajq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-addr" ,rust-addr-0.15)
                       ("rust-ahash" ,rust-ahash-0.8)
                       ("rust-ammonia" ,rust-ammonia-4)
                       ("rust-any-ascii" ,rust-any-ascii-0.3)
                       ("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-argon2" ,rust-argon2-0.5)
                       ("rust-async-channel" ,rust-async-channel-2)
                       ("rust-async-executor" ,rust-async-executor-1)
                       ("rust-async-graphql" ,rust-async-graphql-7)
                       ("rust-base64" ,rust-base64-0.21)
                       ("rust-bcrypt" ,rust-bcrypt-0.15)
                       ("rust-bincode" ,rust-bincode-1)
                       ("rust-blake3" ,rust-blake3-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-castaway" ,rust-castaway-0.2)
                       ("rust-cedar-policy" ,rust-cedar-policy-2)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-ciborium" ,rust-ciborium-0.2)
                       ("rust-dashmap" ,rust-dashmap-5)
                       ("rust-deunicode" ,rust-deunicode-1)
                       ("rust-dmp" ,rust-dmp-0.2)
                       ("rust-ext-sort" ,rust-ext-sort-0.1)
                       ("rust-foundationdb" ,rust-foundationdb-0.9)
                       ("rust-fst" ,rust-fst-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-fuzzy-matcher" ,rust-fuzzy-matcher-0.3)
                       ("rust-geo" ,rust-geo-0.28)
                       ("rust-geo-types" ,rust-geo-types-0.7)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-indxdb" ,rust-indxdb-0.5)
                       ("rust-ipnet" ,rust-ipnet-2)
                       ("rust-jsonwebtoken" ,rust-jsonwebtoken-9)
                       ("rust-lexicmp" ,rust-lexicmp-0.1)
                       ("rust-linfa-linalg" ,rust-linfa-linalg-0.1)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-nanoid" ,rust-nanoid-0.4)
                       ("rust-ndarray" ,rust-ndarray-0.15)
                       ("rust-ndarray-stats" ,rust-ndarray-stats-0.5)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-num-cpus" ,rust-num-cpus-1)
                       ("rust-object-store" ,rust-object-store-0.10)
                       ("rust-pbkdf2" ,rust-pbkdf2-0.12)
                       ("rust-pharos" ,rust-pharos-0.5)
                       ("rust-phf" ,rust-phf-0.11)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-quick-cache" ,rust-quick-cache-0.5)
                       ("rust-radix-trie" ,rust-radix-trie-0.2)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-reblessive" ,rust-reblessive-0.4)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-regex-syntax" ,rust-regex-syntax-0.8)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-revision" ,rust-revision-0.10)
                       ("rust-ring" ,rust-ring-0.17)
                       ("rust-rmpv" ,rust-rmpv-1)
                       ("rust-roaring" ,rust-roaring-0.10)
                       ("rust-rocksdb" ,rust-rocksdb-0.22)
                       ("rust-rquickjs" ,rust-rquickjs-0.8)
                       ("rust-rust-stemmers" ,rust-rust-stemmers-1)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-scrypt" ,rust-scrypt-0.11)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-content" ,rust-serde-content-0.1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-snap" ,rust-snap-1)
                       ("rust-storekey" ,rust-storekey-0.5)
                       ("rust-strsim" ,rust-strsim-0.11)
                       ("rust-subtle" ,rust-subtle-2)
                       ("rust-surrealcs" ,rust-surrealcs-0.4)
                       ("rust-surrealdb-derive" ,rust-surrealdb-derive-0.12)
                       ("rust-surrealdb-tikv-client" ,rust-surrealdb-tikv-client-0.3)
                       ("rust-surrealkv" ,rust-surrealkv-0.6)
                       ("rust-surrealml-core" ,rust-surrealml-core-0.1)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-tungstenite" ,rust-tokio-tungstenite-0.21)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-trice" ,rust-trice-0.4)
                       ("rust-ulid" ,rust-ulid-1)
                       ("rust-unicase" ,rust-unicase-2)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-vart" ,rust-vart-0.7)
                       ("rust-wasm-bindgen-futures" ,rust-wasm-bindgen-futures-0.4)
                       ("rust-wasmtimer" ,rust-wasmtimer-0.2)
                       ("rust-ws-stream-wasm" ,rust-ws-stream-wasm-0.7))))
    (home-page "https://github.com/surrealdb/surrealdb")
    (synopsis
     "scalable, distributed, collaborative, document-graph database, for the realtime web")
    (description
     "This package provides a scalable, distributed, collaborative, document-graph
                   database, for the realtime web.")
    (license license:asl2.0)))
 ;; YD unknown

(define-public rust-serde-content-0.1
  (package
    (name "rust-serde-content")
    (version "0.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde-content" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ih9np0g2byfkgh12bpgr6457ib3bras6ik11g895yjhyc2cllrp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/rushmorem/serde-content")
    (synopsis "Rust data structures for the Serde data model")
    (description
     "This package provides Rust data structures for the Serde data model.")
    (license (list license:expat license:asl2.0))))

(define-public rust-bytemuck-1
  (package
    (name "rust-bytemuck")
    (version "1.21.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bytemuck" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "18wj81x9xhqcd6985r8qxmbik6szjfjfj62q3xklw8h2p3x7srgg"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytemuck-derive" ,rust-bytemuck-derive-1))))
    (home-page "https://github.com/Lokathor/bytemuck")
    (synopsis "crate for mucking around with piles of bytes.")
    (description
     "This package provides a crate for mucking around with piles of bytes.")
    (license (list license:zlib license:asl2.0 license:expat))))

(define-public rust-roaring-0.10
  (package
    (name "rust-roaring")
    (version "0.10.10")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "roaring" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1wlbmjycclsn4c46ihggi1lqdrpwjgfahdkaz6rz0gf5078fslm6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytemuck" ,rust-bytemuck-1)
                       ("rust-byteorder" ,rust-byteorder-1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/RoaringBitmap/roaring-rs")
    (synopsis "better compressed bitset - pure Rust implementation")
    (description
     "This package provides a better compressed bitset - pure Rust implementation.")
    (license (list license:expat license:asl2.0))))

(define-public rust-revision-derive-0.10
  (package
    (name "rust-revision-derive")
    (version "0.10.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "revision-derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0wshnzppchz1rabas9bmry85bvvvcxwii1xnbsbakp6qwmkc83jz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/surrealdb/revision")
    (synopsis
     "Implements procedural macros for automatic Revision trait implementation")
    (description
     "This package implements procedural macros for automatic Revision trait
                   implementation.")
    (license license:asl2.0)))

(define-public rust-revision-0.10
  (package
    (name "rust-revision")
    (version "0.10.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "revision" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0k0y3d6s7mvqs5l9r62v6alb9ilrqni5hkccmnnq3y1ml1wk3x92"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-chrono" ,rust-chrono-0.4)
                       ("rust-geo" ,rust-geo-0.28)
                       ("rust-ordered-float" ,rust-ordered-float-4)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-revision-derive" ,rust-revision-derive-0.10)
                       ("rust-roaring" ,rust-roaring-0.10)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/surrealdb/revision")
    (synopsis
     "serialization and deserialization implementation which allows for schema-evolution.")
    (description
     "This package provides a serialization and deserialization implementation which
                   allows for schema-evolution.")
    (license license:asl2.0)))

(define-public rust-reblessive-0.4
  (package
    (name "rust-reblessive")
    (version "0.4.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "reblessive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0y5720gnn0ba30n2ixy2s84kmmczfyql98k3q05kwpxll38dkspz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/DelSkayn/reblessive.git")
    (synopsis "small runtime for running deeply nested recursive functions")
    (description
     "This package provides a small runtime for running deeply nested recursive
                   functions.")
    (license license:expat)))

(define-public rust-pharos-0.5
  (package
    (name "rust-pharos")
    (version "0.5.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "pharos" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "055lg1dzrxnryfy34a9cyrg21b7cl6l2frfx2p7fdvkz864p6mp9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures" ,rust-futures-0.3)
                       ("rust-rustc-version" ,rust-rustc-version-0.4))))
    (home-page "https://github.com/najamelan/pharos")
    (synopsis
     "Observer pattern which generates a futures 0.3 stream of events")
    (description
     "This package provides Observer pattern which generates a futures 0.3 stream of events.")
    (license license:unlicense)))

(define-public rust-spade-2
  (package
    (name "rust-spade")
    (version "2.12.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "spade" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "12a8rcjjwwg0wmv52drwdnypjhhadb1wyz6sglfpvjishqgyzxck"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-mint" ,rust-mint-0.5)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-robust" ,rust-robust-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-smallvec" ,rust-smallvec-1))))
    (home-page "https://github.com/Stoeoef/spade")
    (synopsis "Delaunay triangulations for the rust ecosystem")
    (description
     "This package provides Delaunay triangulations for the rust ecosystem.")
    (license (list license:expat license:asl2.0))))

(define-public rust-robust-1
  (package
    (name "rust-robust")
    (version "1.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "robust" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0c5fhzk7dc1ci9dyjy0xrv6nlrkbmprlj1lqkvrqhs3dbymadx6b"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ieee754" ,rust-ieee754-0.2))))
    (home-page "https://github.com/georust/robust")
    (synopsis
     "Robust adaptive floating-point predicates for computational geometry")
    (description
     "This package provides Robust adaptive floating-point predicates for computational geometry.")
    (license (list license:expat license:asl2.0))))

(define-public rust-proj-sys-0.23
  (package
    (name "rust-proj-sys")
    (version "0.23.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "proj-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1v4gcf9wa4icdifsysrchbqrr5k5bknpngrhdnjy3z8p3vxg86v0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.66)
                       ("rust-cmake" ,rust-cmake-0.1)
                       ("rust-flate2" ,rust-flate2-1)
                       ("rust-pkg-config" ,rust-pkg-config-0.3)
                       ("rust-tar" ,rust-tar-0.4))))
    (home-page "https://github.com/georust/proj")
    (synopsis "Rust bindings for PROJ v9.4.x")
    (description "This package provides Rust bindings for PROJ v9.4.x.")
    (license (list license:expat license:asl2.0))))

(define-public rust-proj-0.27
  (package
    (name "rust-proj")
    (version "0.27.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "proj" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1aw5236mbv2x6ggyzhzmpq9dhyzhb0248y3fqwiblvlnv0587lbs"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-geo-types" ,rust-geo-types-0.7)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-proj-sys" ,rust-proj-sys-0.23)
                       ("rust-reqwest" ,rust-reqwest-0.11)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/georust/proj")
    (synopsis "High-level Rust bindings for the latest stable version of PROJ")
    (description
     "This package provides High-level Rust bindings for the latest stable version of PROJ.")
    (license (list license:expat license:asl2.0))))

(define-public rust-accurate-0.3
  (package
    (name "rust-accurate")
    (version "0.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "accurate" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0gn07dnxp3vcnccx001rdzxwpcqhzvcw0vmm1psnrvhqq85ry82g"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-ieee754" ,rust-ieee754-0.2)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-rayon" ,rust-rayon-1))))
    (home-page "https://github.com/bsteinb/accurate")
    (synopsis "(more or less) accurate floating point algorithms")
    (description
     "This package provides (more or less) accurate floating point algorithms.")
    (license (list license:expat license:asl2.0))))

(define-public rust-geographiclib-rs-0.2
  (package
    (name "rust-geographiclib-rs")
    (version "0.2.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "geographiclib-rs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0q0rg3wm4q06qqvhvp1dc5qkcwywnvnhm3ha9cip1708z22fvrg6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-accurate" ,rust-accurate-0.3)
                       ("rust-libm" ,rust-libm-0.2))))
    (home-page "https://github.com/georust/geographiclib-rs")
    (synopsis "port of geographiclib in Rust.")
    (description "This package provides a port of geographiclib in Rust.")
    (license license:expat)))

(define-public rust-rstar-0.10
  (package
    (name "rust-rstar")
    (version "0.10.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rstar" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "16imy7lrm3y3kpgh4xi9amfzqfwmyh3y1nf6g6pdiqx1amb4cf8z"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-heapless" ,rust-heapless-0.7)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-smallvec" ,rust-smallvec-1))))
    (home-page "https://github.com/georust/rstar")
    (synopsis "An R*-tree spatial index")
    (description "This package provides An R*-tree spatial index.")
    (license (list license:expat license:asl2.0))))

(define-public rust-rstar-0.12
  (package
    (name "rust-rstar")
    (version "0.12.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rstar" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1fsx2z2l6nq2fd95g9yvw1a9qvypllq9q6aqb3x6vlng7k8h0522"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-heapless" ,rust-heapless-0.8)
                       ("rust-mint" ,rust-mint-0.5)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-smallvec" ,rust-smallvec-1))))
    (home-page "https://github.com/georust/rstar")
    (synopsis "An R*-tree spatial index")
    (description "This package provides An R*-tree spatial index.")
    (license (list license:expat license:asl2.0))))

(define-public rust-rstar-0.11
  (package
    (name "rust-rstar")
    (version "0.11.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rstar" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1mlqq0mdcs8zxinsn5zhh3hxw7dm6pzh0v7h5798f8ksxc9164bk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-heapless" ,rust-heapless-0.7)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-smallvec" ,rust-smallvec-1))))
    (home-page "https://github.com/georust/rstar")
    (synopsis "An R*-tree spatial index")
    (description "This package provides An R*-tree spatial index.")
    (license (list license:expat license:asl2.0))))

(define-public rust-geo-types-0.7
  (package
    (name "rust-geo-types")
    (version "0.7.15")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "geo-types" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ngjzldim1nlf0mxcx2m55hgw6iigj7ixjfyd36z0swk1xzibl9v"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-approx" ,rust-approx-0.5)
                       ("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-rstar" ,rust-rstar-0.11)
                       ("rust-rstar" ,rust-rstar-0.12)
                       ("rust-rstar" ,rust-rstar-0.8)
                       ("rust-rstar" ,rust-rstar-0.9)
                       ("rust-rstar" ,rust-rstar-0.10)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/georust/geo")
    (synopsis "Geospatial primitive data types")
    (description "This package provides Geospatial primitive data types.")
    (license (list license:expat license:asl2.0))))

(define-public rust-float-next-after-1
  (package
    (name "rust-float-next-after")
    (version "1.0.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "float_next_after" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1s7ikn69b394frihag05b0qcw9i9y04qanlhp5c8sjrw70bcrxwb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://gitlab.com/bronsonbdevost/next_afterf")
    (synopsis "trait for native rust f64/f32 nextafter")
    (description
     "This package provides a trait for native rust f64/f32 nextafter.")
    (license license:expat)))

(define-public rust-earcutr-0.4
  (package
    (name "rust-earcutr")
    (version "0.4.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "earcutr" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "00dddrgzsrkbv8ifsmakcxwxrdzzgia7i6cy81y6imw5kbapw4kr"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-itertools" ,rust-itertools-0.11)
                       ("rust-num-traits" ,rust-num-traits-0.2))))
    (home-page "https://github.com/frewsxcv/earcutr/")
    (synopsis "port of MapBox's earcut triangulation code to Rust language")
    (description
     "This package provides port of @code{MapBox's} earcut triangulation code to Rust language.")
    (license license:isc)))

(define-public rust-geo-0.28
  (package
    (name "rust-geo")
    (version "0.28.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "geo" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "00a5113izs2276ra1n52km958wnv0nhd5p10lsgj8s9aj5izc4gq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-earcutr" ,rust-earcutr-0.4)
                       ("rust-float-next-after" ,rust-float-next-after-1)
                       ("rust-geo-types" ,rust-geo-types-0.7)
                       ("rust-geographiclib-rs" ,rust-geographiclib-rs-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-proj" ,rust-proj-0.27)
                       ("rust-robust" ,rust-robust-1)
                       ("rust-rstar" ,rust-rstar-0.12)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-spade" ,rust-spade-2))))
    (home-page "https://github.com/georust/geo")
    (synopsis "Geospatial primitives and algorithms")
    (description "This package provides Geospatial primitives and algorithms.")
    (license (list license:expat license:asl2.0))))

(define-public rust-dmp-0.2
  (package
    (name "rust-dmp")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dmp" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ndnpqi456ivqfbsflsn1brx91zqba9sh9s9bg6fa9jdlcsi3amz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-urlencoding" ,rust-urlencoding-2))))
    (home-page "https://github.com/surrealdb/dmp")
    (synopsis "high-performance library in that manipulates plain text")
    (description
     "This package provides a high-performance library in that manipulates plain text.")
    (license license:expat)))

(define-public rust-surrealdb-2
  (package
    (name "rust-surrealdb")
    (version "2.1.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "surrealdb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1izvm7ryb9adn7ykfihankz6d21c72m17y4rk1mdfcm102wb3i6n"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arrayvec" ,rust-arrayvec-0.7)
                       ("rust-async-channel" ,rust-async-channel-2)
                       ("rust-bincode" ,rust-bincode-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-dmp" ,rust-dmp-0.2)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-geo" ,rust-geo-0.28)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-path-clean" ,rust-path-clean-1)
                       ("rust-pharos" ,rust-pharos-0.5)
                       ("rust-reblessive" ,rust-reblessive-0.4)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-revision" ,rust-revision-0.10)
                       ("rust-ring" ,rust-ring-0.17)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-content" ,rust-serde-content-0.1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-surrealdb-core" ,rust-surrealdb-core-2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-tungstenite" ,rust-tokio-tungstenite-0.23)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-trice" ,rust-trice-0.4)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-wasm-bindgen-futures" ,rust-wasm-bindgen-futures-0.4)
                       ("rust-wasmtimer" ,rust-wasmtimer-0.2)
                       ("rust-ws-stream-wasm" ,rust-ws-stream-wasm-0.7))))
    (home-page "https://github.com/surrealdb/surrealdb")
    (synopsis
     "scalable, distributed, collaborative, document-graph database, for the realtime web")
    (description
     "This package provides a scalable, distributed, collaborative, document-graph
                   database, for the realtime web.")
    (license license:asl2.0)))
 ; YD

(define-public rust-suppaftp-6
  (package
    (name "rust-suppaftp")
    (version "6.0.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "suppaftp" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "11bqwn0k2bhskvm2j393kinvkddsqj6fgfkaasahpadmxv3445w2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-native-tls" ,rust-async-native-tls-0.5)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-tls" ,rust-async-tls-0.13)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-futures-lite" ,rust-futures-lite-2)
                       ("rust-lazy-regex" ,rust-lazy-regex-3)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-thiserror" ,rust-thiserror-2))))
    (home-page "https://github.com/veeso/suppaftp")
    (synopsis "super FTP/FTPS client library for Rust")
    (description
     "This package provides a super FTP/FTPS client library for Rust.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-sqlite-0.8
  (package
    (name "rust-sqlx-sqlite")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx-sqlite" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h05ca26g428h4337k4nm0ww75bcdkiqzp883m7fc92v78fsfp7q"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-atoi" ,rust-atoi-2)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-flume" ,rust-flume-0.11)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-executor" ,rust-futures-executor-0.3)
                       ("rust-futures-intrusive" ,rust-futures-intrusive-0.5)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-libsqlite3-sys" ,rust-libsqlite3-sys-0.30)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-urlencoded" ,rust-serde-urlencoded-0.7)
                       ("rust-sqlx-core" ,rust-sqlx-core-0.8)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "SQLite driver implementation for SQLx. Not for direct use; see the `sqlx` crate for details")
    (description
     "This package provides SQLite driver implementation for SQLx. Not for direct use; see the `sqlx` crate
                   for details.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-postgres-0.8
  (package
    (name "rust-sqlx-postgres")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx-postgres" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "04wnjl51kfx0qbfsfmhqdshpmw32vzz2p8dksmj6gvb3ydbqmff5"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-atoi" ,rust-atoi-2)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-bit-vec" ,rust-bit-vec-0.6)
                       ("rust-bitflags" ,rust-bitflags-2)
                       ("rust-byteorder" ,rust-byteorder-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-crc" ,rust-crc-3)
                       ("rust-dotenvy" ,rust-dotenvy-0.15)
                       ("rust-etcetera" ,rust-etcetera-0.8)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-hkdf" ,rust-hkdf-0.12)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-home" ,rust-home-0.5)
                       ("rust-ipnetwork" ,rust-ipnetwork-0.20)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-mac-address" ,rust-mac-address-1)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-sqlx-core" ,rust-sqlx-core-0.8)
                       ("rust-stringprep" ,rust-stringprep-0.1)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-whoami" ,rust-whoami-1))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "PostgreSQL driver implementation for SQLx. Not for direct use; see the `sqlx` crate for details")
    (description
     "This package provides @code{PostgreSQL} driver implementation for SQLx. Not for direct use; see the
                   `sqlx` crate for details.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-mysql-0.8
  (package
    (name "rust-sqlx-mysql")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx-mysql" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0czjzzjm2y6lkhxvvzrzwgp0pmlhymcnym20hn9n9kh01s7jfq25"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-atoi" ,rust-atoi-2)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-bitflags" ,rust-bitflags-2)
                       ("rust-byteorder" ,rust-byteorder-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-crc" ,rust-crc-3)
                       ("rust-digest" ,rust-digest-0.10)
                       ("rust-dotenvy" ,rust-dotenvy-0.15)
                       ("rust-either" ,rust-either-1)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-generic-array" ,rust-generic-array-0.14)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-hkdf" ,rust-hkdf-0.12)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rsa" ,rust-rsa-0.9)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-sqlx-core" ,rust-sqlx-core-0.8)
                       ("rust-stringprep" ,rust-stringprep-0.1)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-whoami" ,rust-whoami-1))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "MySQL driver implementation for SQLx. Not for direct use; see the `sqlx` crate for details")
    (description
     "This package provides @code{MySQL} driver implementation for SQLx. Not for direct use; see the `sqlx`
                   crate for details.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-macros-core-0.8
  (package
    (name "rust-sqlx-macros-core")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx-macros-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1bg7sn6l8dc4pzrqx2dwc3sp7dbn97msfqahpycnl55bqnn917sf"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-std" ,rust-async-std-1)
                       ("rust-dotenvy" ,rust-dotenvy-0.15)
                       ("rust-either" ,rust-either-1)
                       ("rust-heck" ,rust-heck-0.5)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-sqlx-core" ,rust-sqlx-core-0.8)
                       ("rust-sqlx-mysql" ,rust-sqlx-mysql-0.8)
                       ("rust-sqlx-postgres" ,rust-sqlx-postgres-0.8)
                       ("rust-sqlx-sqlite" ,rust-sqlx-sqlite-0.8)
                       ("rust-syn" ,rust-syn-2)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-url" ,rust-url-2))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "Macro support core for SQLx, the Rust SQL toolkit. Not intended to be used directly")
    (description
     "This package provides Macro support core for SQLx, the Rust SQL toolkit. Not intended to be used
                   directly.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-macros-0.8
  (package
    (name "rust-sqlx-macros")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "047k67sylscv0gdhwwqrn0s33jy1mvq8rmqq6s8fygv4g2ny44ii"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-sqlx-core" ,rust-sqlx-core-0.8)
                       ("rust-sqlx-macros-core" ,rust-sqlx-macros-core-0.8)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "Macros for SQLx, the rust SQL toolkit. Not intended to be used directly")
    (description
     "This package provides Macros for SQLx, the rust SQL toolkit. Not intended to be used directly.")
    (license (list license:expat license:asl2.0))))

(define-public rust-hashlink-0.10
  (package
    (name "rust-hashlink")
    (version "0.10.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hashlink" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1h8lzvnl9qxi3zyagivzz2p1hp6shgddfmccyf6jv7s1cdicz0kk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-hashbrown" ,rust-hashbrown-0.15)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/kyren/hashlink")
    (synopsis
     "HashMap-like containers that hold their key-value pairs in a user controllable order")
    (description
     "This package provides @code{HashMap-like} containers that hold their key-value pairs in a user
                   controllable order.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-core-0.8
  (package
    (name "rust-sqlx-core")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1q31dawr61wc6q2f12my4fw082mbv8sxwz1082msjsk76rlpn03a"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-io" ,rust-async-io-1)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-bit-vec" ,rust-bit-vec-0.6)
                       ("rust-bstr" ,rust-bstr-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-crc" ,rust-crc-3)
                       ("rust-crossbeam-queue" ,rust-crossbeam-queue-0.3)
                       ("rust-either" ,rust-either-1)
                       ("rust-event-listener" ,rust-event-listener-5)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-intrusive" ,rust-futures-intrusive-0.5)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hashbrown" ,rust-hashbrown-0.15)
                       ("rust-hashlink" ,rust-hashlink-0.10)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-ipnetwork" ,rust-ipnetwork-0.20)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-mac-address" ,rust-mac-address-1)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.8)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-stream" ,rust-tokio-stream-0.1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "Core of SQLx, the rust SQL toolkit. Not intended to be used directly")
    (description
     "This package provides Core of SQLx, the rust SQL toolkit. Not intended to be used directly.")
    (license (list license:expat license:asl2.0))))

(define-public rust-sqlx-0.8
  (package
    (name "rust-sqlx")
    (version "0.8.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sqlx" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0pvlpq0plgyxf5kikcv786pf0pjv8dx5shlvz72l510d7hxyf424"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-sqlx-core" ,rust-sqlx-core-0.8)
                       ("rust-sqlx-macros" ,rust-sqlx-macros-0.8)
                       ("rust-sqlx-mysql" ,rust-sqlx-mysql-0.8)
                       ("rust-sqlx-postgres" ,rust-sqlx-postgres-0.8)
                       ("rust-sqlx-sqlite" ,rust-sqlx-sqlite-0.8))))
    (home-page "https://github.com/launchbadge/sqlx")
    (synopsis
     "ð§° The Rust SQL Toolkit. An async, pure Rust SQL crate featuring compile-time checked queries without a DSL. Supports PostgreSQL, MySQL, and SQLite")
    (description
     "This package provides ð§° The Rust SQL Toolkit. An async, pure Rust SQL crate featuring compile-time
                   checked queries without a DSL. Supports @code{PostgreSQL}, @code{MySQL}, and
                   SQLite.")
    (license (list license:expat license:asl2.0))))

(define-public rust-snowflaked-1
  (package
    (name "rust-snowflaked")
    (version "1.0.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "snowflaked" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0l7q6aqf4pfjylaycskzlp3v9v50195v4f908nz9jhs59hn4d39r"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-loom" ,rust-loom-0.5))))
    (home-page "https://github.com/MrGunflame/snowflaked-rs")
    (synopsis "crate for creating and working with snowflake ids")
    (description
     "This package provides a crate for creating and working with snowflake ids.")
    (license (list license:expat license:asl2.0))))

(define-public rust-panic-message-0.3
  (package
    (name "rust-panic-message")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "panic-message" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ba75hapwknxljlcw2719l9zk8111hk1d0ky64ybwk5xizym4kiq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/guswynn/panic-message")
    (synopsis "Get a panic message from a panic payload")
    (description
     "This package provides Get a panic message from a panic payload.")
    (license (list license:expat license:asl2.0))))

(define-public rust-bufsize-1
  (package
    (name "rust-bufsize")
    (version "1.0.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bufsize" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h5h7gv5m6wnw58bj99ml1iz5k1qjpj4jzqmmnip05wimldpacjy"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1))))
    (home-page "https://github.com/dtolnay/bufsize")
    (synopsis "bytes::BufMut implementation to count buffer size")
    (description
     "This package provides bytes::@code{BufMut} implementation to count buffer size.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-timer-1
  (package
    (name "rust-async-timer")
    (version "1.0.0-beta.15")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-timer" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0w3gd4ak873ya8zkzh0qjjc2hrbxva7az48dl9c5wis2w3w0lhhx"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cc" ,rust-cc-1)
                       ("rust-error-code" ,rust-error-code-3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-web-time" ,rust-web-time-1))))
    (home-page "https://github.com/DoumanAsh/async-timer")
    (synopsis "Timers for Rust async story")
    (description "This package provides Timers for Rust async story.")
    (license license:boost1.0)))

(define-public rust-async-sleep-0.4
  (package
    (name "rust-async-sleep")
    (version "0.4.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-sleep" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0v3cq6ymz0njapw0r6fxjsik5hf7bzmb42xmhpc8mjrsxlraa9y3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-io" ,rust-async-io-1)
                       ("rust-async-timer" ,rust-async-timer-1)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/bk-rs/timer-rs")
    (synopsis "Async Sleep")
    (description "This package provides Async Sleep.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-rust-nebula-0.0.2
  (package
    (name "rust-rust-nebula")
    (version "0.0.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rust-nebula" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1sbsz024rlb6syn13iq7nvmir1l0a41vf4g93avhb2yaajklxa8i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-async-compat" ,rust-async-compat-0.2)
                       ("rust-async-sleep" ,rust-async-sleep-0.4)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.11)
                       ("rust-bb8" ,rust-bb8-0.8)
                       ("rust-bufsize" ,rust-bufsize-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-const-cstr" ,rust-const-cstr-0.3)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-ghost" ,rust-ghost-0.1)
                       ("rust-num-derive" ,rust-num-derive-0.3)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-ordered-float" ,rust-ordered-float-1)
                       ("rust-panic-message" ,rust-panic-message-0.3)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/nebula-contrib/rust-nebula")
    (synopsis "Rust client for NebulaGraph database.")
    (description
     "This package provides a Rust client for @code{NebulaGraph} database.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-tikv-jemalloc-sys-0.5
  (package
    (name "rust-tikv-jemalloc-sys")
    (version "0.5.4+5.3.0-patched")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tikv-jemalloc-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1lc5vm1p9dqdvd3mn3264zddnd7z6i95ch3y69prnjgxp0y480ll"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cc" ,rust-cc-1)
                       ("rust-libc" ,rust-libc-0.2))))
    (home-page "https://github.com/tikv/jemallocator")
    (synopsis "Rust FFI bindings to jemalloc")
    (description "This package provides Rust FFI bindings to jemalloc.")
    (license (list license:expat license:asl2.0))))

(define-public rust-librocksdb-sys-0.11
  (package
    (name "rust-librocksdb-sys")
    (version "0.11.0+8.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "librocksdb-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0gly8vx2x65jap1pid32bahn421vxi0zplp9v19d4jyb3c86yf6k"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.65)
                       ("rust-bzip2-sys" ,rust-bzip2-sys-0.1)
                       ("rust-cc" ,rust-cc-1)
                       ("rust-glob" ,rust-glob-0.3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-libz-sys" ,rust-libz-sys-1)
                       ("rust-lz4-sys" ,rust-lz4-sys-1)
                       ("rust-pkg-config" ,rust-pkg-config-0.3)
                       ("rust-tikv-jemalloc-sys" ,rust-tikv-jemalloc-sys-0.5)
                       ("rust-zstd-sys" ,rust-zstd-sys-2))))
    (home-page "https://github.com/rust-rocksdb/rust-rocksdb")
    (synopsis "Native bindings to librocksdb")
    (description "This package provides Native bindings to librocksdb.")
    (license (list license:expat license:asl2.0 license:bsd-3))))

(define-public rust-rocksdb-0.21
  (package
    (name "rust-rocksdb")
    (version "0.21.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rocksdb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1zlz55fkk55nln4jchifx9ishv3dj4a2w3abw060mma18051fvxv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-librocksdb-sys" ,rust-librocksdb-sys-0.11)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/rust-rocksdb/rust-rocksdb")
    (synopsis "Rust wrapper for Facebook's RocksDB embeddable database")
    (description
     "This package provides Rust wrapper for Facebook's @code{RocksDB} embeddable database.")
    (license license:asl2.0)))

(define-public rust-quick-xml-0.35
  (package
    (name "rust-quick-xml")
    (version "0.35.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "quick-xml" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0kiasy82aac18xym035raw79zsp4wahgvhkvhkzbpwffb3nldr46"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-document-features" ,rust-document-features-0.2)
                       ("rust-encoding-rs" ,rust-encoding-rs-0.8)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/tafia/quick-xml")
    (synopsis "High performance xml reader and writer")
    (description
     "This package provides High performance xml reader and writer.")
    (license license:expat)))

(define-public rust-reqsign-0.16
  (package
    (name "rust-reqsign")
    (version "0.16.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "reqsign" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ja1ysjr4kazp35hw9d97rdgbq92wxka3p3hig6g9ywbdjk7a07b"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-form-urlencoded" ,rust-form-urlencoded-1)
                       ("rust-getrandom" ,rust-getrandom-0.2)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-home" ,rust-home-0.5)
                       ("rust-http" ,rust-http-1)
                       ("rust-jsonwebtoken" ,rust-jsonwebtoken-9)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-quick-xml" ,rust-quick-xml-0.35)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-rsa" ,rust-rsa-0.9)
                       ("rust-rust-ini" ,rust-rust-ini-0.21)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-toml" ,rust-toml-0.8))))
    (home-page "https://github.com/Xuanwo/reqsign")
    (synopsis "Signing API requests without effort")
    (description "This package provides Signing API requests without effort.")
    (license license:asl2.0)))

(define-public rust-futures-rustls-0.26
  (package
    (name "rust-futures-rustls")
    (version "0.26.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "futures-rustls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1nvaqbblx1svlz0pjrm4rf1c9xd4kjzzlinp5sqnjb7r0wkg3wm8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1))))
    (home-page "https://github.com/quininer/futures-rustls")
    (synopsis "Asynchronous TLS/SSL streams for futures using Rustls")
    (description
     "This package provides Asynchronous TLS/SSL streams for futures using Rustls.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-native-tls-0.5
  (package
    (name "rust-async-native-tls")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-native-tls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1v2v82crqm4fgj1s32gik56m7cwx0ygqjdqc5pw9zrq7rxddqhwk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-url" ,rust-url-2))))
    (home-page "https://docs.rs/crate/async-native-tls/")
    (synopsis "Native TLS using futures")
    (description "This package provides Native TLS using futures.")
    (license (list license:expat license:asl2.0))))

(define-public rust-redis-0.27
  (package
    (name "rust-redis")
    (version "0.27.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "redis" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1g3mx0g34bj8smklhyw7ygxrpmpa074k6j59i729rj4h82dgkn09"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-arc-swap" ,rust-arc-swap-1)
                       ("rust-async-native-tls" ,rust-async-native-tls-0.5)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-backon" ,rust-backon-1)
                       ("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-combine" ,rust-combine-4)
                       ("rust-crc16" ,rust-crc16-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-futures-rustls" ,rust-futures-rustls-0.26)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hashbrown" ,rust-hashbrown-0.15)
                       ("rust-itertools" ,rust-itertools-0.13)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-r2d2" ,rust-r2d2-0.8)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.7)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-2)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-ryu" ,rust-ryu-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha1-smol" ,rust-sha1-smol-1)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.26)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26))))
    (home-page "https://github.com/redis-rs/redis-rs")
    (synopsis "Redis driver for Rust")
    (description "This package provides Redis driver for Rust.")
    (license license:bsd-3)))

(define-public rust-redb-2
  (package
    (name "rust-redb")
    (version "2.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "redb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ik3y8pdqrh4i378kv3qshh9r0dz7a43p0hqwg1rzpj0f76p42pa"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-pyo3" ,rust-pyo3-0.22)
                       ("rust-pyo3-build-config" ,rust-pyo3-build-config-0.22))))
    (home-page "https://www.redb.org")
    (synopsis "Rust Embedded DataBase")
    (description "This package provides Rust Embedded @code{DataBase}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-prost-build-0.11
  (package
    (name "rust-prost-build")
    (version "0.11.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "prost-build" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0w5jx97q96ydhkg67wx3lb11kfy8195c56g0476glzws5iak758i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-heck" ,rust-heck-0.4)
                       ("rust-itertools" ,rust-itertools-0.10)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-multimap" ,rust-multimap-0.8)
                       ("rust-petgraph" ,rust-petgraph-0.6)
                       ("rust-prettyplease" ,rust-prettyplease-0.1)
                       ("rust-prost" ,rust-prost-0.11)
                       ("rust-prost-types" ,rust-prost-types-0.11)
                       ("rust-pulldown-cmark" ,rust-pulldown-cmark-0.9)
                       ("rust-pulldown-cmark-to-cmark" ,rust-pulldown-cmark-to-cmark-10)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-syn" ,rust-syn-1)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-which" ,rust-which-4))))
    (home-page "https://github.com/tokio-rs/prost")
    (synopsis
     "Generate Prost annotated Rust types from Protocol Buffers files")
    (description
     "This package provides Generate Prost annotated Rust types from Protocol Buffers files.")
    (license license:asl2.0)))

(define-public rust-prometheus-client-derive-encode-0.4
  (package
    (name "rust-prometheus-client-derive-encode")
    (version "0.4.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "prometheus-client-derive-encode" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1f22ckswiqnjlh1xaxkh8pqlfsdhj851ns33bnvrcsczp97743s4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/prometheus/client_rust")
    (synopsis "Auxiliary crate to derive Encode trait from prometheus-client")
    (description
     "This package provides Auxiliary crate to derive Encode trait from prometheus-client.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-prometheus-client-0.22
  (package
    (name "rust-prometheus-client")
    (version "0.22.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "prometheus-client" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1jn3c2m4rnw7w61adsbjph7dqsdxh6s7x0n44w8qkpcsabzyjkjh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-dtoa" ,rust-dtoa-1)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-prometheus-client-derive-encode" ,rust-prometheus-client-derive-encode-0.4)
                       ("rust-prost" ,rust-prost-0.11)
                       ("rust-prost-build" ,rust-prost-build-0.11)
                       ("rust-prost-types" ,rust-prost-types-0.11))))
    (home-page "https://github.com/prometheus/client_rust")
    (synopsis
     "Open Metrics client library allowing users to natively instrument applications")
    (description
     "This package provides Open Metrics client library allowing users to natively instrument applications.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-prometheus-0.13
  (package
    (name "rust-prometheus")
    (version "0.13.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "prometheus" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1lbymqdsh9v4zk4fjdq2gq6lbxspp1w3z2b9vfb7y7vp625c4crx"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-fnv" ,rust-fnv-1)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-procfs" ,rust-procfs-0.16)
                       ("rust-protobuf" ,rust-protobuf-2)
                       ("rust-protobuf-codegen-pure" ,rust-protobuf-codegen-pure-2)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/tikv/rust-prometheus")
    (synopsis "Prometheus instrumentation library for Rust applications")
    (description
     "This package provides Prometheus instrumentation library for Rust applications.")
    (license license:asl2.0)))

(define-public rust-probe-0.5
  (package
    (name "rust-probe")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "probe" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "18z5lqcx2bhl4pabvy9d6jixfm0m3yg0zij4fc18y33k9d2d5qnq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/cuviper/probe-rs")
    (synopsis "Static instrumentation probes")
    (description "This package provides Static instrumentation probes.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-zigzag-0.1
  (package
    (name "rust-zigzag")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "zigzag" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1przksgh335b16mqf1clgi6yxnypdyw67f1hlcbcx1ldl80h9d3h"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-num-traits" ,rust-num-traits-0.2))))
    (home-page "https://github.com/That3Percent/zigzag")
    (synopsis "ZigZag encoding and decoding")
    (description "This package provides @code{ZigZag} encoding and decoding.")
    (license license:expat)))

(define-public rust-asynchronous-codec-0.7
  (package
    (name "rust-asynchronous-codec")
    (version "0.7.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "asynchronous-codec" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0cy2aqcq7km8ggpjmfvrbckvjgf1bpxh803kb4z90zqp48h0fq58"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-futures-sink" ,rust-futures-sink-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-cbor" ,rust-serde-cbor-0.11)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/mxinden/asynchronous-codec")
    (synopsis "Utilities for encoding and decoding frames using `async/await`")
    (description
     "This package provides Utilities for encoding and decoding frames using `async/await`.")
    (license license:expat)))

(define-public rust-unsigned-varint-0.8
  (package
    (name "rust-unsigned-varint")
    (version "0.8.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "unsigned-varint" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "01lwzxp0hf5p966fjq0lyz2x4l44b52py1fbffp9clabn9cnj1pb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-asynchronous-codec" ,rust-asynchronous-codec-0.7)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-nom" ,rust-nom-7)
                       ("rust-tokio-util" ,rust-tokio-util-0.7))))
    (home-page "https://github.com/paritytech/unsigned-varint")
    (synopsis "unsigned varint encoding")
    (description "This package provides unsigned varint encoding.")
    (license license:expat)))

(define-public rust-persy-1
  (package
    (name "rust-persy")
    (version "1.6.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "persy" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0hdi9v36j0yd7rpys2yki51061iwq2wawgs72wahp470b40pjsy2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-crc" ,rust-crc-3)
                       ("rust-data-encoding" ,rust-data-encoding-2)
                       ("rust-fs2" ,rust-fs2-0.4)
                       ("rust-linked-hash-map" ,rust-linked-hash-map-0.5)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-unsigned-varint" ,rust-unsigned-varint-0.8)
                       ("rust-zigzag" ,rust-zigzag-0.1))))
    (home-page "https://persy.rs")
    (synopsis "Transactional Persistence Engine")
    (description "This package provides Transactional Persistence Engine.")
    (license license:mpl2.0)))

(define-public rust-opentelemetry-0.26
  (package
    (name "rust-opentelemetry")
    (version "0.26.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "opentelemetry" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "05yd0ms1wqn28x8b1hshyr59lfmzsddnx5l080c5h6lxk767802p"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-sink" ,rust-futures-sink-0.3)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/open-telemetry/opentelemetry-rust")
    (synopsis "OpenTelemetry API for Rust")
    (description "This package provides @code{OpenTelemetry} API for Rust.")
    (license license:asl2.0)))

(define-public rust-openssh-sftp-protocol-0.24
  (package
    (name "rust-openssh-sftp-protocol")
    (version "0.24.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-sftp-protocol" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0l5k2pc50vlpws3y4vf40975bzqiijamazsh0rii8lv5qph65j59"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bitflags" ,rust-bitflags-2)
                       ("rust-num-derive" ,rust-num-derive-0.4)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-openssh-sftp-protocol-error" ,rust-openssh-sftp-protocol-error-0.1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-ssh-format" ,rust-ssh-format-0.14)
                       ("rust-vec-strings" ,rust-vec-strings-0.4))))
    (home-page "https://github.com/openssh-rust/openssh-sftp-client")
    (synopsis "Data format used to communicate with openssh mux server")
    (description
     "This package provides Data format used to communicate with openssh mux server.")
    (license license:expat)))

(define-public rust-vec-strings-0.4
  (package
    (name "rust-vec-strings")
    (version "0.4.8")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "vec-strings" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0nbnww23hi87dfn1bb0ii20cdgkhsdgx92i34aaj3vm7wa4r8l68"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1)
                       ("rust-thin-vec" ,rust-thin-vec-0.2))))
    (home-page "https://github.com/NobodyXu/vec-strings")
    (synopsis "Store any string efficiently in an immutable way")
    (description
     "This package provides Store any string efficiently in an immutable way.")
    (license license:expat)))

(define-public rust-openssh-sftp-protocol-error-0.1
  (package
    (name "rust-openssh-sftp-protocol-error")
    (version "0.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-sftp-protocol-error" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1lp8xmhgmp30jf1c1x7rg3j3ff198q6ddac3i9qagnfg5kv4vda2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-vec-strings" ,rust-vec-strings-0.4))))
    (home-page "https://github.com/openssh-rust/openssh-sftp-client")
    (synopsis "Data format used to communicate with openssh mux server")
    (description
     "This package provides Data format used to communicate with openssh mux server.")
    (license license:expat)))

(define-public rust-openssh-sftp-error-0.5
  (package
    (name "rust-openssh-sftp-error")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-sftp-error" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "06i5m3sydb4p4g5xsa4bi8lz8idaww515z91idbv9585izqh59qj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-awaitable-error" ,rust-awaitable-error-0.1)
                       ("rust-openssh" ,rust-openssh-0.11)
                       ("rust-openssh-sftp-protocol-error" ,rust-openssh-sftp-protocol-error-0.1)
                       ("rust-ssh-format-error" ,rust-ssh-format-error-0.1)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/openssh-rust/openssh-sftp-client")
    (synopsis "Error type used when communicating with openssh sftp server")
    (description
     "This package provides Error type used when communicating with openssh sftp server.")
    (license license:expat)))

(define-public rust-concurrent-arena-0.1
  (package
    (name "rust-concurrent-arena")
    (version "0.1.10")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "concurrent_arena" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "19lj6d0v5nhafy3wx4ycvabyx65whdp1mrlynf32mzdf4y6rmwaf"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arc-swap" ,rust-arc-swap-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-triomphe" ,rust-triomphe-0.1))))
    (home-page "https://github.com/NobodyXu/concurrent_arena")
    (synopsis "u32 concurrent insertion/removal arena that returns ArenaArc")
    (description
     "This package provides u32 concurrent insertion/removal arena that returns @code{ArenaArc}.")
    (license license:expat)))

(define-public rust-awaitable-error-0.1
  (package
    (name "rust-awaitable-error")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "awaitable-error" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "12kzgrgfn05s98vvhbz1xqv1yirllpy5w5xbrqy59y6d6sb4dcym"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/NobodyXu/awaitable")
    (synopsis
     "Awaitable type with input and output that can be stored in container")
    (description
     "This package provides Awaitable type with input and output that can be stored in container.")
    (license license:expat)))

(define-public rust-awaitable-0.4
  (package
    (name "rust-awaitable")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "awaitable" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0x879j2bwc0yiijr1zr410cng76r8a5k7rd1qravcg3nkaf49bvh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-awaitable-error" ,rust-awaitable-error-0.1)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12))))
    (home-page "https://github.com/NobodyXu/awaitable")
    (synopsis
     "Awaitable type with input and output that can be stored in container")
    (description
     "This package provides Awaitable type with input and output that can be stored in container.")
    (license license:expat)))

(define-public rust-openssh-sftp-client-lowlevel-0.7
  (package
    (name "rust-openssh-sftp-client-lowlevel")
    (version "0.7.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-sftp-client-lowlevel" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ni456qw71s9yqaddyck9hc45mng0sxs0yajy93b5k5ffb172s8f"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-awaitable" ,rust-awaitable-0.4)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-concurrent-arena" ,rust-concurrent-arena-0.1)
                       ("rust-derive-destructure2" ,rust-derive-destructure2-0.1)
                       ("rust-openssh-sftp-error" ,rust-openssh-sftp-error-0.5)
                       ("rust-openssh-sftp-protocol" ,rust-openssh-sftp-protocol-0.24)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-io-utility" ,rust-tokio-io-utility-0.7))))
    (home-page "https://github.com/openssh-rust/openssh-sftp-client")
    (synopsis "Lowlevel utilities to communicate with openssh sftp server")
    (description
     "This package provides Lowlevel utilities to communicate with openssh sftp server.")
    (license license:expat)))

(define-public rust-derive-destructure2-0.1
  (package
    (name "rust-derive-destructure2")
    (version "0.1.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "derive_destructure2" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "037w2cv2429vhwrgpqshzygzncdcqxhmmviiq07nyagzj2n9gdk4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/NobodyXu/derive_destructure2")
    (synopsis "Destructure structs that implement Drop")
    (description
     "This package provides Destructure structs that implement Drop.")
    (license (list license:expat license:asl2.0))))

(define-public rust-openssh-sftp-client-0.15
  (package
    (name "rust-openssh-sftp-client")
    (version "0.15.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-sftp-client" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0grdw7hkwyxw25rmncria5cy02zpjmria8sc7glm9rzilgn4xzcy"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-derive-destructure2" ,rust-derive-destructure2-0.1)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssh" ,rust-openssh-0.11)
                       ("rust-openssh-sftp-client-lowlevel" ,rust-openssh-sftp-client-lowlevel-0.7)
                       ("rust-openssh-sftp-error" ,rust-openssh-sftp-error-0.5)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-scopeguard" ,rust-scopeguard-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-io-utility" ,rust-tokio-io-utility-0.7)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/openssh-rust/openssh-sftp-client")
    (synopsis "Highlevel API used to communicate with openssh sftp server")
    (description
     "This package provides Highlevel API used to communicate with openssh sftp server.")
    (license license:expat)))

(define-public rust-typed-builder-macro-0.20
  (package
    (name "rust-typed-builder-macro")
    (version "0.20.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "typed-builder-macro" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1mgd7ix7lx02b6xffkrxmd9ijsy5cjxf0c5y7ba0jrahavb842sn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/idanarye/rust-typed-builder")
    (synopsis "Compile-time type-checked builder derive")
    (description
     "This package provides Compile-time type-checked builder derive.")
    (license (list license:expat license:asl2.0))))

(define-public rust-typed-builder-0.20
  (package
    (name "rust-typed-builder")
    (version "0.20.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "typed-builder" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0xayskbj3l9v5as8m2b3c209iw5ix39bm4iarg52cywbvicys53y"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-typed-builder-macro" ,rust-typed-builder-macro-0.20))))
    (home-page "https://github.com/idanarye/rust-typed-builder")
    (synopsis "Compile-time type-checked builder derive")
    (description
     "This package provides Compile-time type-checked builder derive.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tokio-io-utility-0.7
  (package
    (name "rust-tokio-io-utility")
    (version "0.7.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tokio-io-utility" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0qy2sx7fkla9j37fp9z2ah4kqay6fzn6l7y4qx90wwbms5a2crwd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/openssh-rust/tokio-io-utility.git")
    (synopsis "Some helper functions for tokio::io")
    (description "This package provides Some helper functions for tokio::io.")
    (license license:expat)))

(define-public rust-ssh-format-0.14
  (package
    (name "rust-ssh-format")
    (version "0.14.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ssh_format" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "011k3zq5b13j9ppw2rmqyr5gnpybb045a8zc4z1rg40w3l433ar4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-ssh-format-error" ,rust-ssh-format-error-0.1))))
    (home-page "https://github.com/openssh-rust/ssh_format")
    (synopsis "Data format used to communicate with openssh mux server")
    (description
     "This package provides Data format used to communicate with openssh mux server.")
    (license license:expat)))

(define-public rust-sendfd-0.4
  (package
    (name "rust-sendfd")
    (version "0.4.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "sendfd" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "160pf2dp5r8smjc6ssk6jf9k93vc280wk8i362xi6zi6zjw72jv0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/standard-ai/sendfd")
    (synopsis "Send file descriptors along with data over UNIX domain sockets")
    (description
     "This package provides Send file descriptors along with data over UNIX domain sockets.")
    (license (list license:asl2.0 license:bsd-3))))

(define-public rust-ssh-format-error-0.1
  (package
    (name "rust-ssh-format-error")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ssh_format_error" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0311divq777kl3844lnbzqcci8bsnmpabs7p3vvi39kwvqcnag5y"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/openssh-rust/ssh_format")
    (synopsis "Data format used to communicate with openssh mux server")
    (description
     "This package provides Data format used to communicate with openssh mux server.")
    (license license:expat)))

(define-public rust-openssh-mux-client-error-0.1
  (package
    (name "rust-openssh-mux-client-error")
    (version "0.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-mux-client-error" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0npr387iqp0l5zq1sqm8rml1a6dp43rkvn9h1qh3b8j8zf51cycq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ssh-format-error" ,rust-ssh-format-error-0.1)
                       ("rust-thiserror" ,rust-thiserror-2))))
    (home-page "https://github.com/openssh-rust/openssh-mux-client")
    (synopsis "openssh mux client")
    (description "This package provides openssh mux client.")
    (license license:expat)))

(define-public rust-non-zero-byte-slice-0.1
  (package
    (name "rust-non-zero-byte-slice")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "non-zero-byte-slice" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0940wdjqvdwfh04ppms465aghrl0dn9x1g4125fz178wl7da3nl9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/openssh-rust/openssh-mux-client")
    (synopsis "openssh mux client")
    (description "This package provides openssh mux client.")
    (license license:expat)))

(define-public rust-openssh-mux-client-0.17
  (package
    (name "rust-openssh-mux-client")
    (version "0.17.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh-mux-client" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1g69akjm9yqpwl259b0fwdj1wh5y59bw7y65rnikb43x18nnk4fh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-non-zero-byte-slice" ,rust-non-zero-byte-slice-0.1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssh-mux-client-error" ,rust-openssh-mux-client-error-0.1)
                       ("rust-sendfd" ,rust-sendfd-0.4)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-ssh-format" ,rust-ssh-format-0.14)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-io-utility" ,rust-tokio-io-utility-0.7)
                       ("rust-typed-builder" ,rust-typed-builder-0.20))))
    (home-page "https://github.com/openssh-rust/openssh-mux-client")
    (synopsis "openssh mux client")
    (description "This package provides openssh mux client.")
    (license license:expat)))

(define-public rust-openssh-0.11
  (package
    (name "rust-openssh")
    (version "0.11.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssh" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0gmwg40di9smgia13w61rfjcsqgk6lch6rmfbp2nps4hp8lb22za"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssh-mux-client" ,rust-openssh-mux-client-0.17)
                       ("rust-shell-escape" ,rust-shell-escape-0.1)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/openssh-rust/openssh.git")
    (synopsis "SSH through OpenSSH")
    (description "This package provides SSH through @code{OpenSSH}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-monoio-macros-0.1
  (package
    (name "rust-monoio-macros")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "monoio-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0k08a925wmbw9902iimwxys34lqk25gadwkw6f49wgb1d5g5yshp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/bytedance/monoio")
    (synopsis "Monoio proc macros")
    (description "This package provides Monoio proc macros.")
    (license (list license:expat license:asl2.0))))

(define-public rust-auto-const-array-0.2
  (package
    (name "rust-auto-const-array")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "auto-const-array" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1fylx07l043nwfv611qqmimxbmpymss32jzfa0vf07ksjwcdzxv2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/ihciah/auto-const-array")
    (synopsis "Define a const array without specify length")
    (description
     "This package provides Define a const array without specify length.")
    (license (list license:expat license:asl2.0))))

(define-public rust-monoio-0.2
  (package
    (name "rust-monoio")
    (version "0.2.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "monoio" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0sms53laang38x1059g7qxxiiazw8dsm92rkjngr9cc7vsygil1v"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-auto-const-array" ,rust-auto-const-array-0.2)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-ctrlc" ,rust-ctrlc-3)
                       ("rust-flume" ,rust-flume-0.11)
                       ("rust-fxhash" ,rust-fxhash-0.2)
                       ("rust-io-uring" ,rust-io-uring-0.6)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-mio" ,rust-mio-0.8)
                       ("rust-monoio-macros" ,rust-monoio-macros-0.1)
                       ("rust-nix" ,rust-nix-0.26)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-threadpool" ,rust-threadpool-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-windows-sys" ,rust-windows-sys-0.48))))
    (home-page "https://github.com/bytedance/monoio")
    (synopsis "thread per core runtime based on iouring.")
    (description
     "This package provides a thread per core runtime based on iouring.")
    (license (list license:expat license:asl2.0))))

(define-public rust-typed-builder-0.10
  (package
    (name "rust-typed-builder")
    (version "0.10.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "typed-builder" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "036v5045xsc8akqbqm0npyxw9pvxwqiq9aix7cwpx4vvnqb1g1c9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://github.com/idanarye/rust-typed-builder")
    (synopsis "Compile-time type-checked builder derive")
    (description
     "This package provides Compile-time type-checked builder derive.")
    (license (list license:expat license:asl2.0))))

(define-public rust-rustc-version-runtime-0.3
  (package
    (name "rust-rustc-version-runtime")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rustc_version_runtime" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0787mz3zqkh7fmb88pxhag63y3qxlps58pmdnvq0m0p1pb98rl9d"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-rustc-version" ,rust-rustc-version-0.4)
                       ("rust-rustc-version" ,rust-rustc-version-0.4)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-semver" ,rust-semver-1))))
    (home-page "https://github.com/seppo0010/rustc-version-runtime-rs")
    (synopsis
     "library for querying the version of the rustc compiler used in runtime")
    (description
     "This package provides a library for querying the version of the rustc compiler
                   used in runtime.")
    (license license:expat)))

(define-public rust-reqwest-0.12
  (package
    (name "rust-reqwest")
    (version "0.12.12")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "reqwest" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1nnigi6jcrqdd5k5myc53qdkdnrx8zjgan029q1w5hspf5039rs3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-compression" ,rust-async-compression-0.4)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-cookie" ,rust-cookie-0.18)
                       ("rust-cookie-store" ,rust-cookie-store-0.21)
                       ("rust-encoding-rs" ,rust-encoding-rs-0.8)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-h2" ,rust-h2-0.4)
                       ("rust-h3" ,rust-h3-0.0.6)
                       ("rust-h3-quinn" ,rust-h3-quinn-0.0.7)
                       ("rust-hickory-resolver" ,rust-hickory-resolver-0.24)
                       ("rust-http" ,rust-http-1)
                       ("rust-http-body" ,rust-http-body-1)
                       ("rust-http-body-util" ,rust-http-body-util-0.1)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-hyper-rustls" ,rust-hyper-rustls-0.27)
                       ("rust-hyper-tls" ,rust-hyper-tls-0.6)
                       ("rust-hyper-util" ,rust-hyper-util-0.1)
                       ("rust-ipnet" ,rust-ipnet-2)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-mime-guess" ,rust-mime-guess-2)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-quinn" ,rust-quinn-0.11)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.8)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-2)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-urlencoded" ,rust-serde-urlencoded-0.7)
                       ("rust-slab" ,rust-slab-0.4)
                       ("rust-sync-wrapper" ,rust-sync-wrapper-1)
                       ("rust-system-configuration" ,rust-system-configuration-0.6)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.26)
                       ("rust-tokio-socks" ,rust-tokio-socks-0.5)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-tower" ,rust-tower-0.5)
                       ("rust-tower-service" ,rust-tower-service-0.3)
                       ("rust-url" ,rust-url-2)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-wasm-bindgen-futures" ,rust-wasm-bindgen-futures-0.4)
                       ("rust-wasm-streams" ,rust-wasm-streams-0.4)
                       ("rust-web-sys" ,rust-web-sys-0.3)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26)
                       ("rust-windows-registry" ,rust-windows-registry-0.2))))
    (home-page "https://github.com/seanmonstar/reqwest")
    (synopsis "higher level HTTP client library")
    (description "This package provides higher level HTTP client library.")
    (license (list license:expat license:asl2.0))))

(define-public rust-openssl-probe-0.1
  (package
    (name "rust-openssl-probe")
    (version "0.1.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssl-probe" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0bl52x55laalqb707k009h8kfawliwp992rlsvkzy49n47p2fpnh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/alexcrichton/openssl-probe")
    (synopsis
     "Tool for helping to find SSL certificate locations on the system for OpenSSL")
    (description
     "This package provides Tool for helping to find SSL certificate locations on the system for
                   @code{OpenSSL}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-mongodb-internal-macros-3
  (package
    (name "rust-mongodb-internal-macros")
    (version "3.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "mongodb-internal-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0fs2ssm2zi4hqp7szj89mf22lhjc95wq5l7d4hh9bnqbgnjwc0bx"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-macro-magic" ,rust-macro-magic-0.5)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "")
    (synopsis "Internal macros for the mongodb crate")
    (description
     "This package provides Internal macros for the mongodb crate.")
    (license license:asl2.0)))

(define-public rust-mongocrypt-sys-0.1
  (package
    (name "rust-mongocrypt-sys")
    (version "0.1.4+1.12.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "mongocrypt-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1273kac1n29agfjkcwqx1rl19j7sj9s8g3md181qhpq33pr2v96x"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/mongodb/libmongocrypt-rust")
    (synopsis "FFI bindings to libmongocrypt")
    (description "This package provides FFI bindings to libmongocrypt.")
    (license license:asl2.0)))

(define-public rust-mongocrypt-0.2
  (package
    (name "rust-mongocrypt")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "mongocrypt" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1g2r7fcl3p9rb17c8wdry960biqz92gxinl1jmlmym9v9n6jib2y"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bson" ,rust-bson-2)
                       ("rust-mongocrypt-sys" ,rust-mongocrypt-sys-0.1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/mongodb/libmongocrypt-rust")
    (synopsis "Rust-idiomatic wrapper around mongocrypt-sys")
    (description
     "This package provides Rust-idiomatic wrapper around mongocrypt-sys.")
    (license license:asl2.0)))

(define-public rust-macro-magic-macros-0.5
  (package
    (name "rust-macro-magic-macros")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "macro_magic_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0saq1rbi46lpi2wz4x0s0vgif63wh6jxjzi78nzpd25qckp2iskk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-macro-magic-core" ,rust-macro-magic-core-0.5)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://sam0x17.dev")
    (synopsis "Proc-macro sub-crate for macro_magic")
    (description "This package provides Proc-macro sub-crate for macro_magic.")
    (license license:expat)))

(define-public rust-macro-magic-core-macros-0.5
  (package
    (name "rust-macro-magic-core-macros")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "macro_magic_core_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "021kp0rn686b71wgxh0x2zd6s49cvdrh29nlvfcbvd8m33jbyamh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://sam0x17.dev")
    (synopsis "Support macros for macro_magic_core")
    (description "This package provides Support macros for macro_magic_core.")
    (license license:expat)))

(define-public rust-derive-syn-parse-0.2
  (package
    (name "rust-derive-syn-parse")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "derive-syn-parse" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0qjplkxiia1b8yaghv3q1lm93862l5arlkbs95a0wz1b2gl7qpfn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/sharnoff/derive-syn-parse")
    (synopsis "Derive macro for `syn::parse::Parse`")
    (description "This package provides Derive macro for `syn::parse::Parse`.")
    (license (list license:expat license:asl2.0))))

(define-public rust-macro-magic-core-0.5
  (package
    (name "rust-macro-magic-core")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "macro_magic_core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0l7ikfl7s1cyivsy3kaicfmqznbrrzkwlfirba355ws2gs4dr1qn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-const-random" ,rust-const-random-0.1)
                       ("rust-derive-syn-parse" ,rust-derive-syn-parse-0.2)
                       ("rust-macro-magic-core-macros" ,rust-macro-magic-core-macros-0.5)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://sam0x17.dev")
    (synopsis "Core implementation behind macro_magic")
    (description
     "This package provides Core implementation behind macro_magic.")
    (license license:expat)))

(define-public rust-macro-magic-0.5
  (package
    (name "rust-macro-magic")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "macro_magic" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "07fjfqpl4b2gyd89pwa2rcp55j4nl00cxnakpipx4s0l6pqgjcyc"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-macro-magic-core" ,rust-macro-magic-core-0.5)
                       ("rust-macro-magic-macros" ,rust-macro-magic-macros-0.5)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://sam0x17.dev")
    (synopsis
     "Allows the exporting and importing of the tokens of items across module, file, and crate boundaries")
    (description
     "This package provides Allows the exporting and importing of the tokens of items across module, file,
                   and crate boundaries.")
    (license license:expat)))

(define-public rust-hickory-resolver-0.24
  (package
    (name "rust-hickory-resolver")
    (version "0.24.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hickory-resolver" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1d243gxb2c2nlm73c2vb4yp908z8mi6ixkriglkfb71qkjx2lbha"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hickory-proto" ,rust-hickory-proto-0.24)
                       ("rust-ipconfig" ,rust-ipconfig-0.3)
                       ("rust-lru-cache" ,rust-lru-cache-0.1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-resolv-conf" ,rust-resolv-conf-0.7)
                       ("rust-rustls" ,rust-rustls-0.21)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.6)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-openssl" ,rust-tokio-openssl-0.6)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.24)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.25))))
    (home-page "https://hickory-dns.org/")
    (synopsis
     "Hickory DNS is a safe and secure DNS library. This Resolver library uses the Client library to perform all DNS queries. The Resolver is intended to be a high-level library for any DNS record resolution see Resolver and AsyncResolver for supported resolution types. The Client can be used for other queries.")
    (description
     "This package provides Hickory DNS is a safe and secure DNS library. This Resolver library uses the
                   Client library to perform all DNS queries. The Resolver is intended to be a
                   high-level library for any DNS record resolution see Resolver and
                   @code{AsyncResolver} for supported resolution types. The Client can be used for
                   other queries.")
    (license (list license:expat license:asl2.0))))

(define-public rust-hickory-proto-0.24
  (package
    (name "rust-hickory-proto")
    (version "0.24.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hickory-proto" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1df1gg333sgjicmf8nbsxlhffp18kdfwcvdgaald1fdgp36zsyj4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-data-encoding" ,rust-data-encoding-2)
                       ("rust-enum-as-inner" ,rust-enum-as-inner-0.6)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-h2" ,rust-h2-0.3)
                       ("rust-h3" ,rust-h3-0.0.3)
                       ("rust-h3-quinn" ,rust-h3-quinn-0.0.4)
                       ("rust-http" ,rust-http-0.2)
                       ("rust-idna" ,rust-idna-1)
                       ("rust-ipnet" ,rust-ipnet-2)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-quinn" ,rust-quinn-0.10)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-ring" ,rust-ring-0.16)
                       ("rust-rustls" ,rust-rustls-0.21)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.6)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tinyvec" ,rust-tinyvec-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-openssl" ,rust-tokio-openssl-0.6)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.24)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.25))))
    (home-page "https://hickory-dns.org/")
    (synopsis
     "Hickory DNS is a safe and secure DNS library. This is the foundational DNS protocol library for all Hickory DNS projects.")
    (description
     "This package provides Hickory DNS is a safe and secure DNS library. This is the foundational DNS
                   protocol library for all Hickory DNS projects.")
    (license (list license:expat license:asl2.0))))

(define-public rust-mongodb-3
  (package
    (name "rust-mongodb")
    (version "3.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "mongodb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1y34hdq7q2qwam8224nff14jd8y3qdmb1bvr6kaawi06q4zgpni4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.13)
                       ("rust-bitflags" ,rust-bitflags-1)
                       ("rust-bson" ,rust-bson-2)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-derive-where" ,rust-derive-where-1)
                       ("rust-derive-more" ,rust-derive-more-0.99)
                       ("rust-flate2" ,rust-flate2-1)
                       ("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-executor" ,rust-futures-executor-0.3)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-hickory-proto" ,rust-hickory-proto-0.24)
                       ("rust-hickory-resolver" ,rust-hickory-resolver-0.24)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-macro-magic" ,rust-macro-magic-0.5)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-mongocrypt" ,rust-mongocrypt-0.2)
                       ("rust-mongodb-internal-macros" ,rust-mongodb-internal-macros-3)
                       ("rust-num-cpus" ,rust-num-cpus-1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-openssl-probe" ,rust-openssl-probe-0.1)
                       ("rust-pbkdf2" ,rust-pbkdf2-0.11)
                       ("rust-pem" ,rust-pem-3)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pkcs8" ,rust-pkcs8-0.10)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-rustc-version-runtime" ,rust-rustc-version-runtime-0.3)
                       ("rust-rustls" ,rust-rustls-0.21)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-bytes" ,rust-serde-bytes-0.11)
                       ("rust-serde-with" ,rust-serde-with-3)
                       ("rust-sha-1" ,rust-sha-1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-snap" ,rust-snap-1)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-stringprep" ,rust-stringprep-0.1)
                       ("rust-strsim" ,rust-strsim-0.11)
                       ("rust-take-mut" ,rust-take-mut-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-openssl" ,rust-tokio-openssl-0.6)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.24)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-typed-builder" ,rust-typed-builder-0.10)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.25)
                       ("rust-zstd" ,rust-zstd-0.11))))
    (home-page "https://www.mongodb.com/docs/drivers/rust/")
    (synopsis "The official MongoDB driver for Rust")
    (description
     "This package provides The official @code{MongoDB} driver for Rust.")
    (license license:asl2.0)))

(define-public rust-moka-0.12
  (package
    (name "rust-moka")
    (version "0.12.10")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "moka" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "09h9ww66vxrkizma99n7ib2fm91crkw4msp650j2i94lr911ccm9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-lock" ,rust-async-lock-3)
                       ("rust-crossbeam-channel" ,rust-crossbeam-channel-0.5)
                       ("rust-crossbeam-epoch" ,rust-crossbeam-epoch-0.9)
                       ("rust-crossbeam-utils" ,rust-crossbeam-utils-0.8)
                       ("rust-event-listener" ,rust-event-listener-5)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-loom" ,rust-loom-0.7)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-portable-atomic" ,rust-portable-atomic-1)
                       ("rust-quanta" ,rust-quanta-0.12)
                       ("rust-rustc-version" ,rust-rustc-version-0.4)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-tagptr" ,rust-tagptr-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/moka-rs/moka")
    (synopsis "fast and concurrent cache library inspired by Java Caffeine")
    (description
     "This package provides a fast and concurrent cache library inspired by Java
                   Caffeine.")
    (license (list license:expat license:asl2.0))))

(define-public rust-mime-guess-2
  (package
    (name "rust-mime-guess")
    (version "2.0.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "mime_guess" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "03jmg3yx6j39mg0kayf7w4a886dl3j15y8zs119zw01ccy74zi7p"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-mime" ,rust-mime-0.3)
                       ("rust-unicase" ,rust-unicase-2)
                       ("rust-unicase" ,rust-unicase-2))))
    (home-page "https://github.com/abonander/mime_guess")
    (synopsis
     "simple crate for detection of a file's MIME type by its extension.")
    (description
     "This package provides a simple crate for detection of a file's MIME type by its
                   extension.")
    (license license:expat)))

(define-public rust-metrics-0.24
  (package
    (name "rust-metrics")
    (version "0.24.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "metrics" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1qyrd8c2x35pw2wmwbji8ywq42vb9kdzl0zjkwb6f9rv5c0ynzbs"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-portable-atomic" ,rust-portable-atomic-1))))
    (home-page "https://github.com/metrics-rs/metrics")
    (synopsis "lightweight metrics facade.")
    (description "This package provides a lightweight metrics facade.")
    (license license:expat)))

(define-public rust-hrana-client-proto-0.2
  (package
    (name "rust-hrana-client-proto")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hrana-client-proto" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0cz5ypcyffkv2kccd21pgfmqzrwpd8j4bwk41vb3znl9w90lwszi"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-base64" ,rust-base64-0.21)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/libsql/hrana-client-rs")
    (synopsis "Hrana client protocol for libSQL and sqld")
    (description
     "This package provides Hrana client protocol for @code{libSQL} and sqld.")
    (license license:asl2.0)))

(define-public rust-hdfs-sys-0.3
  (package
    (name "rust-hdfs-sys")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hdfs-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1js9ki2as456whdwk4v51xd74cisjqzljajdnhk1mmd2zg7dbqik"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cc" ,rust-cc-1)
                       ("rust-java-locator" ,rust-java-locator-0.1))))
    (home-page "https://github.com/Xuanwo/hdrs")
    (synopsis "Bindings to HDFS Native C API")
    (description "This package provides Bindings to HDFS Native C API.")
    (license license:asl2.0)))

(define-public rust-hdrs-0.3
  (package
    (name "rust-hdrs")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hdrs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "13c7qz5wwl9gsv3n7kmqazqwamf3br60890zmpychpgy7dljmi7p"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-blocking" ,rust-blocking-1)
                       ("rust-errno" ,rust-errno-0.3)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-hdfs-sys" ,rust-hdfs-sys-0.3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4))))
    (home-page "https://github.com/Xuanwo/hdrs")
    (synopsis "Rust native client to hdfs")
    (description "This package provides Rust native client to hdfs.")
    (license license:asl2.0)))

(define-public rust-autotools-0.2
  (package
    (name "rust-autotools")
    (version "0.2.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "autotools" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1kwmqzdpgmy50dr8pzx0029f5iszrma826ji93fw03qvqhkib57g"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cc" ,rust-cc-1))))
    (home-page "https://github.com/lu-zero/autotools-rs")
    (synopsis
     "build dependency to build native libraries that use configure&make-style build systems")
    (description
     "This package provides a build dependency to build native libraries that use
                   configure&make-style build systems.")
    (license license:expat)))

(define-public rust-protobuf-src-1
  (package
    (name "rust-protobuf-src")
    (version "1.1.0+21.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "protobuf-src" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1hg3w2799fdlrr2wjf7i9g8ybzy0jgxlcdmrhgxwcg7bp998ib67"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-autotools" ,rust-autotools-0.2))))
    (home-page "https://github.com/MaterializeInc/rust-protobuf-native")
    (synopsis "Build system integration for libprotobuf")
    (description
     "This package provides Build system integration for libprotobuf.")
    (license license:asl2.0)))

(define-public rust-g2poly-1
  (package
    (name "rust-g2poly")
    (version "1.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "g2poly" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0b2bj9n34i523h4wrkrklhrlr9ksgnxq5h30rk2zh3ghrihv5n0g"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/WanzenBug/g2p")
    (synopsis "Primitive implementation of polynomials over the field GF(2)")
    (description
     "This package provides Primitive implementation of polynomials over the field GF(2).")
    (license (list license:expat license:asl2.0))))

(define-public rust-g2gen-1
  (package
    (name "rust-g2gen")
    (version "1.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "g2gen" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0z250vm1z6y8z3ds46dkk8vf2hx0jlskqiwjhhxhf7m427wk4gnw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-g2poly" ,rust-g2poly-1)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/WanzenBug/g2p")
    (synopsis
     "macro to create types that implement fast finite field arithmetic.")
    (description
     "This package provides a macro to create types that implement fast finite field
                   arithmetic.")
    (license (list license:expat license:asl2.0))))

(define-public rust-g2p-1
  (package
    (name "rust-g2p")
    (version "1.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "g2p" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "17yjyal4gprhws7r9gdg9sfjjz29q4ln81msd1d3mbyrzrpgm6hs"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-g2gen" ,rust-g2gen-1)
                       ("rust-g2poly" ,rust-g2poly-1))))
    (home-page "https://github.com/WanzenBug/g2p")
    (synopsis
     "crate to create types that implement fast finite field arithmetic.")
    (description
     "This package provides a crate to create types that implement fast finite field
                   arithmetic.")
    (license (list license:expat license:asl2.0))))

(define-public rust-fs-hdfs3-0.1
  (package
    (name "rust-fs-hdfs3")
    (version "0.1.12")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fs-hdfs3" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0p9gl0pb2w4n0f37is2h6bdlwbx33niakn2gzlbqhhkab40faf0g"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.64)
                       ("rust-cc" ,rust-cc-1)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-url" ,rust-url-2))))
    (home-page "https://github.com/datafusion-contrib/fs-hdfs")
    (synopsis "libhdfs binding library and safe Rust APIs")
    (description
     "This package provides libhdfs binding library and safe Rust APIs.")
    (license license:asl2.0)))

(define-public rust-crc-3
  (package
    (name "rust-crc")
    (version "3.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "crc" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0dnn23x68qakzc429s1y9k9y3g8fn5v9jwi63jcz151sngby9rk9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-crc-catalog" ,rust-crc-catalog-2))))
    (home-page "https://github.com/mrhooray/crc-rs.git")
    (synopsis "Rust implementation of CRC with support of various standards")
    (description
     "This package provides Rust implementation of CRC with support of various standards.")
    (license (list license:expat license:asl2.0))))

(define-public rust-hdfs-native-0.10
  (package
    (name "rust-hdfs-native")
    (version "0.10.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hdfs-native" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0g498wz7j23in8j8khfv62yrq1zziv9zcd3dxyvydha3zh6xnwjf"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aes" ,rust-aes-0.8)
                       ("rust-base64" ,rust-base64-0.21)
                       ("rust-bitflags" ,rust-bitflags-2)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-cbc" ,rust-cbc-0.1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-cipher" ,rust-cipher-0.4)
                       ("rust-crc" ,rust-crc-3)
                       ("rust-ctr" ,rust-ctr-0.9)
                       ("rust-des" ,rust-des-0.8)
                       ("rust-dns-lookup" ,rust-dns-lookup-2)
                       ("rust-fs-hdfs3" ,rust-fs-hdfs3-0.1)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-g2p" ,rust-g2p-1)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-libloading" ,rust-libloading-0.8)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-prost" ,rust-prost-0.12)
                       ("rust-prost-build" ,rust-prost-build-0.12)
                       ("rust-prost-types" ,rust-prost-types-0.12)
                       ("rust-protobuf-src" ,rust-protobuf-src-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-roxmltree" ,rust-roxmltree-0.18)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-which" ,rust-which-4)
                       ("rust-whoami" ,rust-whoami-1))))
    (home-page "https://github.com/Kimahriman/hdfs-native")
    (synopsis "Native HDFS client implementation in Rust")
    (description
     "This package provides Native HDFS client implementation in Rust.")
    (license license:asl2.0)))

(define-public rust-spinning-top-0.3
  (package
    (name "rust-spinning-top")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "spinning_top" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "001kjbiz1gg111rsqxc4pq9a1izx7wshkk38f69h1dbgf4fjsvfr"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-lock-api" ,rust-lock-api-0.4))))
    (home-page "https://github.com/rust-osdev/spinning_top")
    (synopsis
     "simple spinlock crate based on the abstractions provided by `lock_api`.")
    (description
     "This package provides a simple spinlock crate based on the abstractions provided
                   by `lock_api`.")
    (license (list license:expat license:asl2.0))))

(define-public rust-prost-types-0.11
  (package
    (name "rust-prost-types")
    (version "0.11.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "prost-types" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "04ryk38sqkp2nf4dgdqdfbgn6zwwvjraw6hqq6d9a6088shj4di1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-prost" ,rust-prost-0.11))))
    (home-page "https://github.com/tokio-rs/prost")
    (synopsis "Prost definitions of Protocol Buffers well known types")
    (description
     "This package provides Prost definitions of Protocol Buffers well known types.")
    (license license:asl2.0)))

(define-public rust-quanta-0.12
  (package
    (name "rust-quanta")
    (version "0.12.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "quanta" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "03kwh0xb7gr461jcjhrxvcj9157k1jyg2gyy0f4579nf4ilgxl9v"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-crossbeam-utils" ,rust-crossbeam-utils-0.8)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-prost-types" ,rust-prost-types-0.11)
                       ("rust-raw-cpuid" ,rust-raw-cpuid-11)
                       ("rust-wasi" ,rust-wasi-0.11)
                       ("rust-web-sys" ,rust-web-sys-0.3)
                       ("rust-winapi" ,rust-winapi-0.3))))
    (home-page "https://github.com/metrics-rs/quanta")
    (synopsis "high-speed timing library")
    (description "This package provides high-speed timing library.")
    (license license:expat)))

(define-public rust-nonzero-ext-0.3
  (package
    (name "rust-nonzero-ext")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "nonzero_ext" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "08fghyinb07xwhbj7vwvlhg45g5cvhvld2min25njidir12rdgrq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/antifuchs/nonzero_ext")
    (synopsis "Extensions and additional traits for non-zero integer types")
    (description
     "This package provides Extensions and additional traits for non-zero integer types.")
    (license license:asl2.0)))

(define-public rust-governor-0.6
  (package
    (name "rust-governor")
    (version "0.6.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "governor" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0yw66yb1rfc7np23n9af9sb8kbhv3jnhvg3an1rsydbbxr1gb9v8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-dashmap" ,rust-dashmap-5)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-futures-timer" ,rust-futures-timer-3)
                       ("rust-no-std-compat" ,rust-no-std-compat-0.4)
                       ("rust-nonzero-ext" ,rust-nonzero-ext-0.3)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-portable-atomic" ,rust-portable-atomic-1)
                       ("rust-quanta" ,rust-quanta-0.12)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-spinning-top" ,rust-spinning-top-0.3))))
    (home-page "https://github.com/boinkor-net/governor")
    (synopsis "rate-limiting implementation in Rust")
    (description
     "This package provides a rate-limiting implementation in Rust.")
    (license license:expat)))

(define-public rust-serde-derive-1
  (package
    (name "rust-serde-derive")
    (version "1.0.217")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "180r3rj5gi5s1m23q66cr5wlfgc5jrs6n1mdmql2njnhk37zg6ss"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://serde.rs")
    (synopsis "Macros 1.1 implementation of #[derive(Serialize, Deserialize)]")
    (description
     "This package provides Macros 1.1 implementation of #[derive(Serialize, Deserialize)].")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-1
  (package
    (name "rust-serde")
    (version "1.0.217")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0w2ck1p1ajmrv1cf51qf7igjn2nc51r0izzc00fzmmhkvxjl5z02"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-derive" ,rust-serde-derive-1))))
    (home-page "https://serde.rs")
    (synopsis "generic serialization/deserialization framework")
    (description
     "This package provides a generic serialization/deserialization framework.")
    (license (list license:expat license:asl2.0))))

(define-public rust-foundationdb-tuple-0.9
  (package
    (name "rust-foundationdb-tuple")
    (version "0.9.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "foundationdb-tuple" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ymhq9a796ffzsc18kcpz1bpg93rh6sc7xwki1qxx4p5zg0k465g"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-memchr" ,rust-memchr-2)
                       ("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/foundationdb-rs/foundationdb-rs")
    (synopsis "Foundationdb tuple pack/unpack implementation in rust")
    (description
     "This package provides Foundationdb tuple pack/unpack implementation in rust.")
    (license (list license:expat license:asl2.0))))

(define-public rust-foundationdb-sys-0.9
  (package
    (name "rust-foundationdb-sys")
    (version "0.9.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "foundationdb-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0r392wgd407gjhmqzbgh9rsbk7dw32xrw6590m4wr38blgdi9biv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.70)
                       ("rust-libc" ,rust-libc-0.2))))
    (home-page "https://github.com/foundationdb-rs/foundationdb-rs")
    (synopsis "Bindings to the C api for FoundationDB")
    (description
     "This package provides Bindings to the C api for @code{FoundationDB}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-try-map-0.3
  (package
    (name "rust-try-map")
    (version "0.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "try_map" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "106mz6cxmgf5m34ww6h45g0ags2j92zc153xy4nbphdmgk82c5pv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/golddranks/try_map")
    (synopsis
     "`try_map` and `flip` methods for `Option`. These allow more ergonomic error handling when mapping functions that return `Result` over `Option`")
    (description
     "This package provides `try_map` and `flip` methods for `Option`. These allow more ergonomic error
                   handling when mapping functions that return `Result` over `Option`.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-foundationdb-macros-0.3
  (package
    (name "rust-foundationdb-macros")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "foundationdb-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0zvg3dxrnkg2l32p9b7qvkdvg4kplncv05gvancdi4js5r0i1rlv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2)
                       ("rust-try-map" ,rust-try-map-0.3))))
    (home-page "https://github.com/foundationdb-rs/foundationdb-rs")
    (synopsis "Macro definitions used to maintain the FoundationDB's crate")
    (description
     "This package provides Macro definitions used to maintain the @code{FoundationDB's} crate.")
    (license (list license:expat license:asl2.0))))

(define-public rust-foundationdb-gen-0.9
  (package
    (name "rust-foundationdb-gen")
    (version "0.9.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "foundationdb-gen" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0n73r8dydl4qcap2jw3hr8xwzy4bzawy4scp17sf2cyzcr48b7gg"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-xml-rs" ,rust-xml-rs-0.8))))
    (home-page "https://github.com/foundationdb-rs/foundationdb-rs")
    (synopsis "Binding generation helper for FoundationDB.")
    (description
     "This package provides Binding generation helper for @code{FoundationDB}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-trait-0.1
  (package
    (name "rust-async-trait")
    (version "0.1.85")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-trait" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0mm0gwad44zs7mna4a0m1z4dhzpmydfj73w4wm23c8xpnhrli4rz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/dtolnay/async-trait")
    (synopsis "Type erasure for async trait methods")
    (description "This package provides Type erasure for async trait methods.")
    (license (list license:expat license:asl2.0))))

(define-public rust-foundationdb-0.9
  (package
    (name "rust-foundationdb")
    (version "0.9.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "foundationdb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1kyc13806hq2vy2n5z6k0p3hc830qb0kqya6lxj2zkxv2bzfyjji"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-recursion" ,rust-async-recursion-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-foundationdb-gen" ,rust-foundationdb-gen-0.9)
                       ("rust-foundationdb-macros" ,rust-foundationdb-macros-0.3)
                       ("rust-foundationdb-sys" ,rust-foundationdb-sys-0.9)
                       ("rust-foundationdb-tuple" ,rust-foundationdb-tuple-0.9)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-bytes" ,rust-serde-bytes-0.11)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-static-assertions" ,rust-static-assertions-1)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/foundationdb-rs/foundationdb-rs")
    (synopsis "High level client bindings for FoundationDB.")
    (description
     "This package provides High level client bindings for @code{FoundationDB}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-rtrb-0.3
  (package
    (name "rust-rtrb")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rtrb" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1fp3rjd8bzx89wdx5g7c42rxqzlyd4x2ds22wh3sh3ly3bm8i0xd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/mgeier/rtrb")
    (synopsis "realtime-safe single-producer single-consumer ring buffer")
    (description
     "This package provides a realtime-safe single-producer single-consumer ring
                   buffer.")
    (license (list license:expat license:asl2.0))))

(define-public rust-minstant-0.1
  (package
    (name "rust-minstant")
    (version "0.1.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "minstant" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1nvq425dd74lqn0an7hx1jakqbl9c97krk5w8r8aqigiab3vbf8z"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-coarsetime" ,rust-coarsetime-0.1)
                       ("rust-ctor" ,rust-ctor-0.1)
                       ("rust-web-time" ,rust-web-time-1))))
    (home-page "https://github.com/tikv/minstant")
    (synopsis
     "drop-in replacement for `std::time::Instant` that measures time with high performance and high accuracy powered by TSC")
    (description
     "This package provides a drop-in replacement for `std::time::Instant` that
                   measures time with high performance and high accuracy powered by TSC.")
    (license license:expat)))

(define-public rust-fastrace-macro-0.7
  (package
    (name "rust-fastrace-macro")
    (version "0.7.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fastrace-macro" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0fwy76ry93sjlz64wr1q14bkcwzfb69zacgjfmxj2mv7jrxa0h9i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro-error2" ,rust-proc-macro-error2-2)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/fast/fastrace")
    (synopsis "Attribute procedural macro for fastrace")
    (description
     "This package provides Attribute procedural macro for fastrace.")
    (license license:asl2.0)))

(define-public rust-fastrace-0.7
  (package
    (name "rust-fastrace")
    (version "0.7.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fastrace" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "069i9pr5vdpiv0ayvwkmz25m9vpxw4cfhidx7j6x1bdnz6xc91sp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-fastrace-macro" ,rust-fastrace-macro-0.7)
                       ("rust-minstant" ,rust-minstant-0.1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rtrb" ,rust-rtrb-0.3))))
    (home-page "https://github.com/fast/fastrace")
    (synopsis "high-performance timeline tracing library for Rust")
    (description
     "This package provides a high-performance timeline tracing library for Rust.")
    (license license:asl2.0)))

(define-public rust-visible-0.0.1
  (package
    (name "rust-visible")
    (version "0.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "visible" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0gp75mm95sabfpxwm6m1lrwviiiicihfa8n6g6yixz60smgh0i50"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://github.com/davidli2010/visible")
    (synopsis "Attributes to override the visibility of items")
    (description
     "This package provides Attributes to override the visibility of items.")
    (license (list license:expat license:asl2.0))))

(define-public rust-linked-hash-set-0.1
  (package
    (name "rust-linked-hash-set")
    (version "0.1.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "linked_hash_set" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1qlj9vzyz8zcascp0z46izwv38y8cjdhxj2z1v44761dw9dmps5s"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-linked-hash-map" ,rust-linked-hash-map-0.5)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/alexheretic/linked-hash-set")
    (synopsis "HashSet with insertion ordering")
    (description
     "This package provides @code{HashSet} with insertion ordering.")
    (license license:asl2.0)))

(define-public rust-hyper-openssl-0.10
  (package
    (name "rust-hyper-openssl")
    (version "0.10.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hyper-openssl" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "06fav767wqs3ywh1z2jpyxxmbgv03lyrl4zc67xamhm2kihlszaj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-http" ,rust-http-1)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-hyper-util" ,rust-hyper-util-0.1)
                       ("rust-linked-hash-set" ,rust-linked-hash-set-0.1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-openssl-sys" ,rust-openssl-sys-0.9)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-tower-layer" ,rust-tower-layer-0.3)
                       ("rust-tower-service" ,rust-tower-service-0.3))))
    (home-page "https://github.com/sfackler/hyper-openssl")
    (synopsis "Hyper TLS support via OpenSSL")
    (description "This package provides Hyper TLS support via @code{OpenSSL}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-etcd-client-0.14
  (package
    (name "rust-etcd-client")
    (version "0.14.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "etcd-client" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1zj7w1jkcxvbpnpradysqbrxbk7rwa3apdvjyhb1nhsrqny5417w"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-http" ,rust-http-1)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-hyper-openssl" ,rust-hyper-openssl-0.10)
                       ("rust-hyper-util" ,rust-hyper-util-0.1)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-prost" ,rust-prost-0.13)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-stream" ,rust-tokio-stream-0.1)
                       ("rust-tonic" ,rust-tonic-0.12)
                       ("rust-tonic-build" ,rust-tonic-build-0.12)
                       ("rust-tower" ,rust-tower-0.4)
                       ("rust-tower-service" ,rust-tower-service-0.3)
                       ("rust-visible" ,rust-visible-0.0.1))))
    (home-page "https://github.com/etcdv3/etcd-client")
    (synopsis "An etcd v3 API client")
    (description "This package provides An etcd v3 API client.")
    (license (list license:expat license:asl2.0))))

(define-public rust-crc32c-0.6
  (package
    (name "rust-crc32c")
    (version "0.6.8")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "crc32c" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0iwyr3jivcnhylczqgk1rkpp9b46r25vi5dj1y7il29dc8hsyirs"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-rustc-version" ,rust-rustc-version-0.4))))
    (home-page "https://github.com/zowens/crc32c")
    (synopsis
     "Safe implementation for hardware accelerated CRC32C instructions with software fallback")
    (description
     "This package provides Safe implementation for hardware accelerated CRC32C instructions with software
                   fallback.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-compio-tls-0.3
  (package
    (name "rust-compio-tls")
    (version "0.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-tls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0z8w16agl7x92nlkkqnhziylbgvv9xkm8dl1rxdr9xzndg1r6cjl"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-io" ,rust-compio-io-0.4)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-rustls" ,rust-rustls-0.23))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "TLS adaptor with compio")
    (description "This package provides TLS adaptor with compio.")
    (license license:expat)))

(define-public rust-compio-signal-0.3
  (package
    (name "rust-compio-signal")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-signal" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1a6vqqgiffaa2pyvwbb2vk9ak8w11zfys5gg9k9vh493vmp4gj0c"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-os-pipe" ,rust-os-pipe-1)
                       ("rust-slab" ,rust-slab-0.4)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Signal handling for compio")
    (description "This package provides Signal handling for compio.")
    (license license:expat)))

(define-public rust-compio-quic-0.1
  (package
    (name "rust-compio-quic")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-quic" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1nqcwvhn11r26rhkj2c70c3h6c3ijxhc7six2rhfp1930g5i16wn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-io" ,rust-compio-io-0.4)
                       ("rust-compio-log" ,rust-compio-log-0.1)
                       ("rust-compio-net" ,rust-compio-net-0.5)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-flume" ,rust-flume-0.11)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-h3" ,rust-h3-0.0.6)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-quinn-proto" ,rust-quinn-proto-0.11)
                       ("rust-rustc-hash" ,rust-rustc-hash-2)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.8)
                       ("rust-rustls-platform-verifier" ,rust-rustls-platform-verifier-0.3)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "QUIC for compio")
    (description "This package provides QUIC for compio.")
    (license license:expat)))

(define-public rust-compio-process-0.2
  (package
    (name "rust-compio-process")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-process" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "163miq385cn34yhpcykirynbzh6xnds3yqh7cgpdjy95n0460yh4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-io" ,rust-compio-io-0.4)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Processes for compio")
    (description "This package provides Processes for compio.")
    (license license:expat)))

(define-public rust-compio-net-0.5
  (package
    (name "rust-compio-net")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-net" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0jbb9hx209w8qk0k1krqa20cpvsi7vl392nzffximb02jnvrnpdp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-io" ,rust-compio-io-0.4)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-either" ,rust-either-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-widestring" ,rust-widestring-1)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Networking IO for compio")
    (description "This package provides Networking IO for compio.")
    (license license:expat)))

(define-public rust-compio-macros-0.1
  (package
    (name "rust-compio-macros")
    (version "0.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0svnjy6hrvljakks5ghwr3kaiai95fhgga3pvrqdqrs9900x4pph"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro-crate" ,rust-proc-macro-crate-3)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Proc macro of compio")
    (description "This package provides Proc macro of compio.")
    (license license:expat)))

(define-public rust-compio-io-0.4
  (package
    (name "rust-compio-io")
    (version "0.4.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-io" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0dbsrzdd00yxnp16x16viidgz6z1c3wasmy188q96sap6s3q146v"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-paste" ,rust-paste-1)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "IO traits for completion based async IO")
    (description
     "This package provides IO traits for completion based async IO.")
    (license license:expat)))

(define-public rust-compio-fs-0.5
  (package
    (name "rust-compio-fs")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-fs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1j3mz31x3k1blw46f310v4p8v463gsksjsnan3jiq7lwpp3lbxin"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-io" ,rust-compio-io-0.4)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-os-pipe" ,rust-os-pipe-1)
                       ("rust-widestring" ,rust-widestring-1)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Filesystem IO for compio")
    (description "This package provides Filesystem IO for compio.")
    (license license:expat)))

(define-public rust-scoped-tls-1
  (package
    (name "rust-scoped-tls")
    (version "1.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "scoped-tls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "15524h04mafihcvfpgxd8f4bgc3k95aclz8grjkg9a0rxcvn9kz1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/alexcrichton/scoped-tls")
    (synopsis
     "Library implementation of the standard library's old `scoped_thread_local!`
                   macro for providing scoped access to thread local storage (TLS) so any type can
                   be stored into TLS.")
    (description
     "This package provides Library implementation of the standard library's old `scoped_thread_local!`
                     macro for providing scoped access to thread local storage (TLS) so any type can
                     be stored into TLS.")
    (license (list license:expat license:asl2.0))))

(define-public rust-compio-runtime-0.5
  (package
    (name "rust-compio-runtime")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-runtime" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0jm75nxi4ys538h4gmckxc5gwivfbgqs5cccj5rxxz8pj1p8abcv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-task" ,rust-async-task-4)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-log" ,rust-compio-log-0.1)
                       ("rust-criterion" ,rust-criterion-0.5)
                       ("rust-crossbeam-queue" ,rust-crossbeam-queue-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-os-pipe" ,rust-os-pipe-1)
                       ("rust-scoped-tls" ,rust-scoped-tls-1)
                       ("rust-slab" ,rust-slab-0.4)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "High-level runtime for compio")
    (description "This package provides High-level runtime for compio.")
    (license license:expat)))

(define-public rust-io-uring-0.7
  (package
    (name "rust-io-uring")
    (version "0.7.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "io-uring" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ipsfh8fc34qxnfac6fl3xqm29137hzpzy4ifrxqjyd2ns5n60db"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bindgen" ,rust-bindgen-0.69)
                       ("rust-bitflags" ,rust-bitflags-2)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-sc" ,rust-sc-0.2))))
    (home-page "https://github.com/tokio-rs/io-uring")
    (synopsis "The low-level `io_uring` userspace interface for Rust")
    (description
     "This package provides The low-level `io_uring` userspace interface for Rust.")
    (license (list license:expat license:asl2.0))))

(define-public rust-compio-log-0.1
  (package
    (name "rust-compio-log")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-log" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0bqk9vpc8ra4afp04f03z4db8r4m234vfsd3imhnp6f12c15ckpw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-tracing" ,rust-tracing-0.1))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Log of compio")
    (description "This package provides Log of compio.")
    (license license:expat)))

(define-public rust-aligned-array-1
  (package
    (name "rust-aligned-array")
    (version "1.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "aligned-array" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0b7xqdjsm7v0i9wkdbdqz80x9xrbqqm29xhkh29m43r9hv894p70"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-generic-array" ,rust-generic-array-0.14)
                       ("rust-subtle" ,rust-subtle-2))))
    (home-page "https://github.com/mobilecoinofficial/aligned-array")
    (synopsis "newtype with alignment of at least `A` bytes")
    (description
     "This package provides a newtype with alignment of at least `A` bytes.")
    (license (list license:expat license:asl2.0))))

(define-public rust-compio-driver-0.5
  (package
    (name "rust-compio-driver")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-driver" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0k564qpf9fjfbsz4c24nk35v8lzl8wm54l1qbs93s86d6zz4kgm6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aligned-array" ,rust-aligned-array-1)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-log" ,rust-compio-log-0.1)
                       ("rust-crossbeam-channel" ,rust-crossbeam-channel-0.5)
                       ("rust-crossbeam-queue" ,rust-crossbeam-queue-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-io-uring" ,rust-io-uring-0.7)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-os-pipe" ,rust-os-pipe-1)
                       ("rust-paste" ,rust-paste-1)
                       ("rust-polling" ,rust-polling-3)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-windows-sys" ,rust-windows-sys-0.52))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Low-level driver for compio")
    (description "This package provides Low-level driver for compio.")
    (license license:expat)))

(define-public rust-compio-dispatcher-0.4
  (package
    (name "rust-compio-dispatcher")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-dispatcher" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0q0xn0ycsqrwvxfwd5yim9ap093j9p45y9yskvkbahp9dqdj7yf6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-flume" ,rust-flume-0.11)
                       ("rust-futures-channel" ,rust-futures-channel-0.3))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Multithreading dispatcher for compio")
    (description "This package provides Multithreading dispatcher for compio.")
    (license license:expat)))

(define-public rust-compio-buf-0.5
  (package
    (name "rust-compio-buf")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio-buf" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "06v1xdxpxmgjnkniifjj3p433mxb1l8j8irwvwqxjzddd8816i6i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-arrayvec" ,rust-arrayvec-0.7)
                       ("rust-bumpalo" ,rust-bumpalo-3)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-smallvec" ,rust-smallvec-1))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Buffer trait for completion based async IO")
    (description
     "This package provides Buffer trait for completion based async IO.")
    (license license:expat)))

(define-public rust-compio-0.12
  (package
    (name "rust-compio")
    (version "0.12.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compio" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "142w36q9i2mcqx3vxlngi24s9k2yan6n32fqdm7370xkn79rb66y"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compio-buf" ,rust-compio-buf-0.5)
                       ("rust-compio-dispatcher" ,rust-compio-dispatcher-0.4)
                       ("rust-compio-driver" ,rust-compio-driver-0.5)
                       ("rust-compio-fs" ,rust-compio-fs-0.5)
                       ("rust-compio-io" ,rust-compio-io-0.4)
                       ("rust-compio-log" ,rust-compio-log-0.1)
                       ("rust-compio-macros" ,rust-compio-macros-0.1)
                       ("rust-compio-net" ,rust-compio-net-0.5)
                       ("rust-compio-process" ,rust-compio-process-0.2)
                       ("rust-compio-quic" ,rust-compio-quic-0.1)
                       ("rust-compio-runtime" ,rust-compio-runtime-0.5)
                       ("rust-compio-signal" ,rust-compio-signal-0.3)
                       ("rust-compio-tls" ,rust-compio-tls-0.3))))
    (home-page "https://github.com/compio-rs/compio")
    (synopsis "Completion based async runtime")
    (description "This package provides Completion based async runtime.")
    (license license:expat)))

(define-public rust-ssri-9
  (package
    (name "rust-ssri")
    (version "9.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ssri" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "10lhj4z53v2mz0dk4wv2njf9zmzhbfdlw347835knsf95cy2nyns"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-digest" ,rust-digest-0.10)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-miette" ,rust-miette-5)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-sha-1" ,rust-sha-1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-xxhash-rust" ,rust-xxhash-rust-0.8))))
    (home-page "https://github.com/zkat/ssri-rs")
    (synopsis "Various utilities for handling Subresource Integrity")
    (description
     "This package provides Various utilities for handling Subresource Integrity.")
    (license license:asl2.0)))

(define-public rust-windows-strings-0.3
  (package
    (name "rust-windows-strings")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows-strings" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "149li59cxj03844fypkd4fgqmxsmvgx0ix62257flhhbjqczk25q"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-windows-targets" ,rust-windows-targets-0.53))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Rust for Windows")
    (description "This package provides Rust for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-x86-64-msvc-0.53
  (package
    (name "rust-windows-x86-64-msvc")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_x86_64_msvc" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "11h4i28hq0zlnjcaqi2xdxr7ibnpa8djfggch9rki1zzb8qi8517"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-x86-64-gnullvm-0.53
  (package
    (name "rust-windows-x86-64-gnullvm")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_x86_64_gnullvm" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0mvc8119xpbi3q2m6mrjcdzl6afx4wffacp13v76g4jrs1fh6vha"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-x86-64-gnu-0.53
  (package
    (name "rust-windows-x86-64-gnu")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_x86_64_gnu" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1flh84xkssn1n6m1riddipydcksp2pdl45vdf70jygx3ksnbam9f"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-i686-msvc-0.53
  (package
    (name "rust-windows-i686-msvc")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_i686_msvc" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0pcvb25fkvqnp91z25qr5x61wyya12lx8p7nsa137cbb82ayw7sq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-i686-gnullvm-0.53
  (package
    (name "rust-windows-i686-gnullvm")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_i686_gnullvm" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "04df1in2k91qyf1wzizvh560bvyzq20yf68k8xa66vdzxnywrrlw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-i686-gnu-0.53
  (package
    (name "rust-windows-i686-gnu")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_i686_gnu" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1hvjc8nv95sx5vdd79fivn8bpm7i517dqyf4yvsqgwrmkmjngp61"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-aarch64-msvc-0.53
  (package
    (name "rust-windows-aarch64-msvc")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_aarch64_msvc" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0v766yqw51pzxxwp203yqy39ijgjamp54hhdbsyqq6x1c8gilrf7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-aarch64-gnullvm-0.53
  (package
    (name "rust-windows-aarch64-gnullvm")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows_aarch64_gnullvm" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0r77pbpbcf8bq4yfwpz2hpq3vns8m0yacpvs2i5cn6fx1pwxbf46"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import lib for Windows")
    (description "This package provides Import lib for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-targets-0.53
  (package
    (name "rust-windows-targets")
    (version "0.53.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows-targets" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "12yakpjizhfpppz1i3zgcwxlbar8axrp9j87fmywpydarvlcgr5i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-windows-aarch64-gnullvm" ,rust-windows-aarch64-gnullvm-0.53)
                       ("rust-windows-aarch64-msvc" ,rust-windows-aarch64-msvc-0.53)
                       ("rust-windows-i686-gnu" ,rust-windows-i686-gnu-0.53)
                       ("rust-windows-i686-gnullvm" ,rust-windows-i686-gnullvm-0.53)
                       ("rust-windows-i686-msvc" ,rust-windows-i686-msvc-0.53)
                       ("rust-windows-x86-64-gnu" ,rust-windows-x86-64-gnu-0.53)
                       ("rust-windows-x86-64-gnullvm" ,rust-windows-x86-64-gnullvm-0.53)
                       ("rust-windows-x86-64-msvc" ,rust-windows-x86-64-msvc-0.53))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Import libs for Windows")
    (description "This package provides Import libs for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-result-0.3
  (package
    (name "rust-windows-result")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows-result" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0d0s3np0793wngliy6mair8id5afkddaa72pq1kl1316h370d0fh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-windows-targets" ,rust-windows-targets-0.53))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Windows error handling")
    (description "This package provides Windows error handling.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-interface-0.59
  (package
    (name "rust-windows-interface")
    (version "0.59.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows-interface" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "00gza9pwqs6k0aygr82wvb0f70ah50kklz7877m825wrdn9zs9nb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "The interface macro for the windows crate")
    (description
     "This package provides The interface macro for the windows crate.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-implement-0.59
  (package
    (name "rust-windows-implement")
    (version "0.59.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows-implement" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ha89vc4v4vabwdjkz46hdsnl2jp7ckpzw88qdca0j9g3q2pnmw3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "The implement macro for the windows crate")
    (description
     "This package provides The implement macro for the windows crate.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-core-0.59
  (package
    (name "rust-windows-core")
    (version "0.59.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1kn1f0bf4rqynczkfgn543i170arbwp04pg1sjq8890isa7f2341"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-windows-implement" ,rust-windows-implement-0.59)
                       ("rust-windows-interface" ,rust-windows-interface-0.59)
                       ("rust-windows-result" ,rust-windows-result-0.3)
                       ("rust-windows-strings" ,rust-windows-strings-0.3)
                       ("rust-windows-targets" ,rust-windows-targets-0.53))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Rust for Windows")
    (description "This package provides Rust for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-windows-0.59
  (package
    (name "rust-windows")
    (version "0.59.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "windows" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "189ji8zy8mmy31k4vs0xrdmskfqvh4km13ifyvklnc4k1bp9m4bz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-windows-core" ,rust-windows-core-0.59)
                       ("rust-windows-targets" ,rust-windows-targets-0.53))))
    (home-page "https://github.com/microsoft/windows-rs")
    (synopsis "Rust for Windows")
    (description "This package provides Rust for Windows.")
    (license (list license:expat license:asl2.0))))

(define-public rust-reflink-copy-0.1
  (package
    (name "rust-reflink-copy")
    (version "0.1.23")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "reflink-copy" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1d5hdrz5y7a6fb1m3nsk3k4v8dh4v22flmh48wvq6ar2shzm7lzv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-rustix" ,rust-rustix-0.38)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-tracing-attributes" ,rust-tracing-attributes-0.1)
                       ("rust-windows" ,rust-windows-0.59))))
    (home-page "https://github.com/cargo-bins/reflink-copy")
    (synopsis "copy-on-write mechanism on supported file systems")
    (description
     "This package provides copy-on-write mechanism on supported file systems.")
    (license (list license:expat license:asl2.0))))

(define-public rust-cacache-13
  (package
    (name "rust-cacache")
    (version "13.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cacache" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "02v7cm5q4ijyf7vrk3kiwa8dsclnczs1qy6ypq5jcbkv3is66l2w"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-std" ,rust-async-std-1)
                       ("rust-digest" ,rust-digest-0.10)
                       ("rust-either" ,rust-either-1)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-memmap2" ,rust-memmap2-0.5)
                       ("rust-miette" ,rust-miette-5)
                       ("rust-reflink-copy" ,rust-reflink-copy-0.1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-ssri" ,rust-ssri-9)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-stream" ,rust-tokio-stream-0.1)
                       ("rust-walkdir" ,rust-walkdir-2))))
    (home-page "https://github.com/zkat/cacache-rs")
    (synopsis
     "Content-addressable, key-value, high-performance, on-disk cache")
    (description
     "This package provides Content-addressable, key-value, high-performance, on-disk cache.")
    (license license:asl2.0)))

(define-public rust-bb8-0.8
  (package
    (name "rust-bb8")
    (version "0.8.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bb8" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1f6d9akrx7pmxcnk82whnqy9jbndzx21i55b8d5w99ahwpxap6nq"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/djc/bb8")
    (synopsis "Full-featured async (tokio-based) connection pool (like r2d2)")
    (description
     "This package provides Full-featured async (tokio-based) connection pool (like r2d2).")
    (license license:expat)))

(define-public rust-weak-table-0.3
  (package
    (name "rust-weak-table")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "weak-table" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ja5zqr1bp5z8wv928y670frnxlj71v6x75g3sg6d6iyaallsgrj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.7))))
    (home-page "https://github.com/tov/weak-table-rs")
    (synopsis "Weak hash maps and sets")
    (description "This package provides Weak hash maps and sets.")
    (license license:expat)))

(define-public rust-flexstr-0.9
  (package
    (name "rust-flexstr")
    (version "0.9.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "flexstr" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0rggqwm8j77rv6pydrx1n4vr1crfjlnmjnna9yjkdlqr8vqswl2d"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-itoa" ,rust-itoa-1)
                       ("rust-ryu" ,rust-ryu-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-static-assertions" ,rust-static-assertions-1)
                       ("rust-ufmt" ,rust-ufmt-0.1)
                       ("rust-ufmt-write" ,rust-ufmt-write-0.1))))
    (home-page "https://github.com/nu11ptr/flexstr")
    (synopsis
     "flexible, simple to use, immutable, clone-efficient `String` replacement for Rust")
    (description
     "This package provides a flexible, simple to use, immutable, clone-efficient
                   `String` replacement for Rust.")
    (license (list license:expat license:asl2.0))))

(define-public rust-wasix-0.12
  (package
    (name "rust-wasix")
    (version "0.12.21")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "wasix" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0v9wb03ddbnas75005l2d63bdqy9mclds00b1qbw385wkgpv9yy1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compiler-builtins" ,rust-compiler-builtins-0.1)
                       ("rust-rustc-std-workspace-alloc" ,rust-rustc-std-workspace-alloc-1)
                       ("rust-rustc-std-workspace-core" ,rust-rustc-std-workspace-core-1)
                       ("rust-wasi" ,rust-wasi-0.11))))
    (home-page "https://github.com/wasix-org/wasix-abi-rust")
    (synopsis "WASIX API bindings for Rust")
    (description "This package provides WASIX API bindings for Rust.")
    (license (list license:asl2.0 license:asl2.0 license:expat))))
 ;YD

(define-public rust-wit-bindgen-rt-0.33
  (package
    (name "rust-wit-bindgen-rt")
    (version "0.33.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "wit-bindgen-rt" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0g4lwfp9x6a2i1hgjn8k14nr4fsnpd5izxhc75zpi2s5cvcg6s1j"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bitflags" ,rust-bitflags-2))))
    (home-page "https://github.com/bytecodealliance/wit-bindgen")
    (synopsis "Runtime support for the `wit-bindgen` crate")
    (description
     "This package provides Runtime support for the `wit-bindgen` crate.")
    (license (list license:asl2.0 license:asl2.0 license:expat))))
 ;yd

(define-public rust-wasi-0.13
  (package
    (name "rust-wasi")
    (version "0.13.3+wasi-0.2.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "wasi" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1lnapbvdcvi3kc749wzqvwrpd483win2kicn1faa4dja38p6v096"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-compiler-builtins" ,rust-compiler-builtins-0.1)
                       ("rust-rustc-std-workspace-alloc" ,rust-rustc-std-workspace-alloc-1)
                       ("rust-rustc-std-workspace-core" ,rust-rustc-std-workspace-core-1)
                       ("rust-wit-bindgen-rt" ,rust-wit-bindgen-rt-0.33))))
    (home-page "https://github.com/bytecodealliance/wasi-rs")
    (synopsis "WASI API bindings for Rust")
    (description "This package provides WASI API bindings for Rust.")
    (license (list license:asl2.0 license:asl2.0 license:expat))))
 ;YD

(define-public rust-coarsetime-0.1
  (package
    (name "rust-coarsetime")
    (version "0.1.35")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "coarsetime" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1qpqnq81p51fmpy6vayg3bqwd14wihfb6xd54scc205n1hivylj2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-wasi" ,rust-wasi-0.13)
                       ("rust-wasix" ,rust-wasix-0.12)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2))))
    (home-page "https://github.com/jedisct1/rust-coarsetime")
    (synopsis "Time and duration crate optimized for speed")
    (description
     "This package provides Time and duration crate optimized for speed.")
    (license license:isc)))

(define-public rust-await-tree-0.2
  (package
    (name "rust-await-tree")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "await-tree" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "13csgzhvglk6amyhqisf2zvi4wrgl0sq9hprqa5a6grqakn7lb8c"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-coarsetime" ,rust-coarsetime-0.1)
                       ("rust-derive-builder" ,rust-derive-builder-0.20)
                       ("rust-flexstr" ,rust-flexstr-0.9)
                       ("rust-indextree" ,rust-indextree-4)
                       ("rust-itertools" ,rust-itertools-0.12)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-weak-table" ,rust-weak-table-0.3))))
    (home-page "https://github.com/risingwavelabs/await-tree")
    (synopsis "Instrument await-tree for actor-based applications")
    (description
     "This package provides Instrument await-tree for actor-based applications.")
    (license license:asl2.0)))

(define-public rust-postgres-protocol-0.6
  (package
    (name "rust-postgres-protocol")
    (version "0.6.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "postgres-protocol" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "08sbm36w68vyrzaaxiv8srrr1w65wi8ycdgf9flfz2y2xfyhxnmc"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-byteorder" ,rust-byteorder-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-fallible-iterator" ,rust-fallible-iterator-0.2)
                       ("rust-getrandom" ,rust-getrandom-0.2)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-stringprep" ,rust-stringprep-0.1))))
    (home-page "https://github.com/sfackler/rust-postgres")
    (synopsis "Low level Postgres protocol APIs")
    (description "This package provides Low level Postgres protocol APIs.")
    (license (list license:expat license:asl2.0))))

(define-public rust-postgres-derive-0.4
  (package
    (name "rust-postgres-derive")
    (version "0.4.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "postgres-derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0pqpwjjswzajgzll4200g8csrs6kkjhyc23p8hnz6piwc2j0ww39"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-heck" ,rust-heck-0.5)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/sfackler/rust-postgres")
    (synopsis "An internal crate used by postgres-types")
    (description
     "This package provides An internal crate used by postgres-types.")
    (license (list license:expat license:asl2.0))))

(define-public rust-bitstring-0.1
  (package
    (name "rust-bitstring")
    (version "0.1.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bitstring" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1k3fkd8q1lr6smlpk1r20wcwzp1v2xqymndny5zfgkq0nq6rr8r2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/stbuehler/rust-bitstring")
    (synopsis "Bitstring traits and implementations")
    (description "This package provides Bitstring traits and implementations.")
    (license license:expat)))

(define-public rust-cidr-0.2
  (package
    (name "rust-cidr")
    (version "0.2.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cidr" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0896d3jxgmpz3avqgg37irn8pjhw8xj54i2wjkr8r5dx8l661pvb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bitstring" ,rust-bitstring-0.1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/stbuehler/rust-cidr")
    (synopsis "IP network and IP host within network types")
    (description
     "This package provides IP network and IP host within network types.")
    (license license:expat)))

(define-public rust-postgres-types-0.2
  (package
    (name "rust-postgres-types")
    (version "0.2.8")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "postgres-types" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0vrkxhpwpymf5wpysjzkjrv9a2jy6f9m2w2pfclk8mqf5lxa4vpn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-array-init" ,rust-array-init-2)
                       ("rust-bit-vec" ,rust-bit-vec-0.6)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-cidr" ,rust-cidr-0.2)
                       ("rust-eui48" ,rust-eui48-1)
                       ("rust-eui48" ,rust-eui48-0.4)
                       ("rust-fallible-iterator" ,rust-fallible-iterator-0.2)
                       ("rust-geo-types" ,rust-geo-types-0.6)
                       ("rust-geo-types" ,rust-geo-types-0.7)
                       ("rust-jiff" ,rust-jiff-0.1)
                       ("rust-postgres-derive" ,rust-postgres-derive-0.4)
                       ("rust-postgres-protocol" ,rust-postgres-protocol-0.6)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-smol-str" ,rust-smol-str-0.1)
                       ("rust-time" ,rust-time-0.2)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-uuid" ,rust-uuid-0.8)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/sfackler/rust-postgres")
    (synopsis "Conversions between Rust and Postgres values")
    (description
     "This package provides Conversions between Rust and Postgres values.")
    (license (list license:expat license:asl2.0))))

(define-public rust-ulid-1
  (package
    (name "rust-ulid")
    (version "1.1.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ulid" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ib09vn5xkxcq2dpyxbflf9xjdawaqggyal16db1rvbhj7vvz57j"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bytes" ,rust-bytes-1)
                       ("rust-postgres-types" ,rust-postgres-types-0.2)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-web-time" ,rust-web-time-1))))
    (home-page "https://github.com/dylanhart/ulid-rs")
    (synopsis
     "a Universally Unique Lexicographically Sortable Identifier implementation")
    (description
     "This package provides a Universally Unique Lexicographically Sortable Identifier implementation.")
    (license license:expat)))

(define-public rust-ryu-js-0.2
  (package
    (name "rust-ryu-js")
    (version "0.2.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "ryu-js" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0zqf0ypy6dl26bz4aigqvrvn6wfqx4iy9mi2i9km6kgdphkgq635"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-no-panic" ,rust-no-panic-0.1))))
    (home-page "https://github.com/boa-dev/ryu-js")
    (synopsis "Fast floating point to string conversion, ECMAScript compliant")
    (description
     "This package provides Fast floating point to string conversion, ECMAScript compliant.")
    (license (list license:asl2.0 license:boost1.0))))

(define-public rust-serde-jcs-0.1
  (package
    (name "rust-serde-jcs")
    (version "0.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_jcs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1a6rx9qmnwq1xsqr6aysmcb839y6fwwq3k4rwbqcb9y1kdjczkna"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ryu-js" ,rust-ryu-js-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/l1h3r/serde_jcs")
    (synopsis "JSON Canonicalization Scheme (JCS) for Serde")
    (description
     "This package provides JSON Canonicalization Scheme (JCS) for Serde.")
    (license (list license:expat license:asl2.0))))

(define-public rust-oxiri-0.2
  (package
    (name "rust-oxiri")
    (version "0.2.11")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "oxiri" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "00m1jqvpgw8x5bqj5wnpxympy12m4wgqg6cgyksikyljf4xfvd2l"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/oxigraph/oxiri")
    (synopsis
     "Simple and fast implementation of IRI validation and relative IRI resolution")
    (description
     "This package provides Simple and fast implementation of IRI validation and relative IRI resolution.")
    (license (list license:expat license:asl2.0))))

(define-public rust-oxilangtag-0.1
  (package
    (name "rust-oxilangtag")
    (version "0.1.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "oxilangtag" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1jwa1z5223hkfldjdwfrxb158w9y918667k9ldzzfsm82xvgiwr3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/oxigraph/oxilangtag")
    (synopsis
     "Simple and fast implementation of language tag normalization and validation")
    (description
     "This package provides Simple and fast implementation of language tag normalization and validation.")
    (license license:expat)))

(define-public rust-rio-turtle-0.8
  (package
    (name "rust-rio-turtle")
    (version "0.8.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rio_turtle" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h3zdl4yx0k6q7bx2s6bc19mpsd74lmfsp6dy2bciiskffvm3wyn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-oxilangtag" ,rust-oxilangtag-0.1)
                       ("rust-oxiri" ,rust-oxiri-0.2)
                       ("rust-rio-api" ,rust-rio-api-0.8))))
    (home-page "https://github.com/oxigraph/rio")
    (synopsis
     "RDF Turtle, Trig, N-Triples and N-Quads parsers and serializers")
    (description
     "This package provides RDF Turtle, Trig, N-Triples and N-Quads parsers and serializers.")
    (license license:asl2.0)))

(define-public rust-rio-api-0.8
  (package
    (name "rust-rio-api")
    (version "0.8.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rio_api" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1bxivlrm09ngwfyhj6353wpmq929gl32v4y5sascn04bvxnwgl31"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/oxigraph/rio")
    (synopsis "Common data structures for RDF formats parsers and serializers")
    (description
     "This package provides Common data structures for RDF formats parsers and serializers.")
    (license license:asl2.0)))

(define-public rust-lol-html-1
  (package
    (name "rust-lol-html")
    (version "1.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "lol_html" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1rfy741z8sn469vh17vk7cps0dqrqjgkf3rdkfnpmsyyqbwryqm4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bitflags" ,rust-bitflags-2)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-cssparser" ,rust-cssparser-0.27)
                       ("rust-encoding-rs" ,rust-encoding-rs-0.8)
                       ("rust-hashbrown" ,rust-hashbrown-0.13)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-lazycell" ,rust-lazycell-1)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-selectors" ,rust-selectors-0.22)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/cloudflare/lol-html")
    (synopsis "Streaming HTML rewriter/parser with CSS selector-based API")
    (description
     "This package provides Streaming HTML rewriter/parser with CSS selector-based API.")
    (license license:bsd-3)))

(define-public rust-kuchikiki-0.8
  (package
    (name "rust-kuchikiki")
    (version "0.8.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "kuchikiki" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1a3d2byx4hzbm23mlkfrgfvmiv9g5g220x8aa5ph95drnxalg7pj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cssparser" ,rust-cssparser-0.27)
                       ("rust-html5ever" ,rust-html5ever-0.26)
                       ("rust-indexmap" ,rust-indexmap-1)
                       ("rust-matches" ,rust-matches-0.1)
                       ("rust-selectors" ,rust-selectors-0.22))))
    (home-page "https://github.com/brave/kuchikiki")
    (synopsis "(å£å©ã) HTML tree manipulation library")
    (description
     "This package provides (å£å©ã) HTML tree manipulation library.")
    (license license:expat)))

(define-public rust-html2md-0.2
  (package
    (name "rust-html2md")
    (version "0.2.15")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "html2md" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1d3ic2pykghg7nr71fn7jdm8ydxz265w5pzv4y4h9ng0ya8rizwc"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-html5ever" ,rust-html5ever-0.27)
                       ("rust-jni" ,rust-jni-0.19)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-markup5ever-rcdom" ,rust-markup5ever-rcdom-0.3)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-regex" ,rust-regex-1))))
    (home-page "https://gitlab.com/Kanedias/html2md")
    (synopsis
     "Library and binary to convert simple html documents into markdown")
    (description
     "This package provides Library and binary to convert simple html documents into markdown.")
    (license license:gpl3+)))

(define-public rust-atomic-lib-0.39
  (package
    (name "rust-atomic-lib")
    (version "0.39.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "atomic_lib" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1k5fklqp8c3kmfi3m88nz7vb9vlgfd5dh76l9ilq8sfvqc7302z0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-bincode" ,rust-bincode-1)
                       ("rust-directories" ,rust-directories-4)
                       ("rust-html2md" ,rust-html2md-0.2)
                       ("rust-kuchikiki" ,rust-kuchikiki-0.8)
                       ("rust-lol-html" ,rust-lol-html-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-ring" ,rust-ring-0.17)
                       ("rust-rio-api" ,rust-rio-api-0.8)
                       ("rust-rio-turtle" ,rust-rio-turtle-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-jcs" ,rust-serde-jcs-0.1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sled" ,rust-sled-0.34)
                       ("rust-toml" ,rust-toml-0.8)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-ulid" ,rust-ulid-1)
                       ("rust-ureq" ,rust-ureq-2)
                       ("rust-url" ,rust-url-2)
                       ("rust-urlencoding" ,rust-urlencoding-2))))
    (home-page "https://github.com/atomicdata-dev/atomic-server")
    (synopsis
     "Library for creating, storing, querying, validating and converting Atomic Data")
    (description
     "This package provides Library for creating, storing, querying, validating and converting Atomic Data.")
    (license license:expat)))

(define-public rust-async-tls-0.13
  (package
    (name "rust-async-tls")
    (version "0.13.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-tls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0plsx2ysd8rbmzfllxib7pkbp3zp7m1yl7gywjh75m49pag3rbmj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-core" ,rust-futures-core-0.3)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-rustls" ,rust-rustls-0.21)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-1)
                       ("rust-rustls-webpki" ,rust-rustls-webpki-0.101)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.22))))
    (home-page "https://github.com/async-std/async-tls")
    (synopsis "Asynchronous TLS/SSL streams using Rustls")
    (description
     "This package provides Asynchronous TLS/SSL streams using Rustls.")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-backtrace-attributes-0.2
  (package
    (name "rust-async-backtrace-attributes")
    (version "0.2.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-backtrace-attributes" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1my3av4hb92cg9p4iv7pa98c0ywjfmsrjw835930dpca8c6vmyxg"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/tokio-rs/async-backtrace")
    (synopsis "Procedural macros for the `async-backtrace` crate")
    (description
     "This package provides Procedural macros for the `async-backtrace` crate.")
    (license license:expat)))

(define-public rust-async-backtrace-0.2
  (package
    (name "rust-async-backtrace")
    (version "0.2.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-backtrace" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "165i3gdc3aasgbajnifx1wkj597dacx1wp0r7yhjfv94b0akkjsd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-backtrace-attributes" ,rust-async-backtrace-attributes-0.2)
                       ("rust-dashmap" ,rust-dashmap-5)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-loom" ,rust-loom-0.5)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-rustc-hash" ,rust-rustc-hash-1)
                       ("rust-static-assertions" ,rust-static-assertions-1))))
    (home-page "https://github.com/tokio-rs/async-backtrace")
    (synopsis "Efficient, logical 'backtraces' of async tasks")
    (description
     "This package provides Efficient, logical backtraces of async tasks.")
    (license license:expat)))

(define-public rust-opendal-0.50
  (package
    (name "rust-opendal")
    (version "0.50.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "opendal" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0i0gpapr2k7pzq2b2qjyx1c4msngsfcp1s6linpww5p1cinbna6b"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-async-backtrace" ,rust-async-backtrace-0.2)
                       ("rust-async-tls" ,rust-async-tls-0.13)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-atomic-lib" ,rust-atomic-lib-0.39)
                       ("rust-await-tree" ,rust-await-tree-0.2)
                       ("rust-backon" ,rust-backon-1)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-bb8" ,rust-bb8-0.8)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-cacache" ,rust-cacache-13)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-compio" ,rust-compio-0.12)
                       ("rust-crc32c" ,rust-crc32c-0.6)
                       ("rust-dashmap" ,rust-dashmap-6)
                       ("rust-dotenvy" ,rust-dotenvy-0.15)
                       ("rust-etcd-client" ,rust-etcd-client-0.14)
                       ("rust-fastrace" ,rust-fastrace-0.7)
                       ("rust-flagset" ,rust-flagset-0.4)
                       ("rust-flume" ,rust-flume-0.11)
                       ("rust-foundationdb" ,rust-foundationdb-0.9)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-getrandom" ,rust-getrandom-0.2)
                       ("rust-governor" ,rust-governor-0.6)
                       ("rust-hdfs-native" ,rust-hdfs-native-0.10)
                       ("rust-hdrs" ,rust-hdrs-0.3)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-hrana-client-proto" ,rust-hrana-client-proto-0.2)
                       ("rust-http" ,rust-http-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-md-5" ,rust-md-5-0.10)
                       ("rust-metrics" ,rust-metrics-0.24)
                       ("rust-mime-guess" ,rust-mime-guess-2)
                       ("rust-mini-moka" ,rust-mini-moka-0.10)
                       ("rust-moka" ,rust-moka-0.12)
                       ("rust-mongodb" ,rust-mongodb-3)
                       ("rust-monoio" ,rust-monoio-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssh" ,rust-openssh-0.11)
                       ("rust-openssh-sftp-client" ,rust-openssh-sftp-client-0.15)
                       ("rust-opentelemetry" ,rust-opentelemetry-0.26)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-persy" ,rust-persy-1)
                       ("rust-probe" ,rust-probe-0.5)
                       ("rust-prometheus" ,rust-prometheus-0.13)
                       ("rust-prometheus-client" ,rust-prometheus-client-0.22)
                       ("rust-prost" ,rust-prost-0.13)
                       ("rust-quick-xml" ,rust-quick-xml-0.36)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-redb" ,rust-redb-2)
                       ("rust-redis" ,rust-redis-0.27)
                       ("rust-reqsign" ,rust-reqsign-0.16)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-rocksdb" ,rust-rocksdb-0.21)
                       ("rust-rust-nebula" ,rust-rust-nebula-0.0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-sled" ,rust-sled-0.34)
                       ("rust-snowflaked" ,rust-snowflaked-1)
                       ("rust-sqlx" ,rust-sqlx-0.8)
                       ("rust-suppaftp" ,rust-suppaftp-6)
                       ("rust-surrealdb" ,rust-surrealdb-2)
                       ("rust-tikv-client" ,rust-tikv-client-0.3)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://opendal.apache.org/")
    (synopsis
     "Apache OpenDALâ¢: Access data freely, painlessly, and efficiently")
    (description
     "This package provides Apache @code{OpenDALâ¢}: Access data freely, painlessly, and efficiently.")
    (license license:asl2.0)))

(define-public rust-derive-setters-0.1
  (package
    (name "rust-derive-setters")
    (version "0.1.6")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "derive_setters" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "03890w7p6zslxl0cbwxddx1sjcsmiypsgyghp1li24sf0lrz13jf"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-darling" ,rust-darling-0.20)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/Lymia/derive_setters")
    (synopsis
     "Rust macro to automatically generates setter methods for a struct's fields")
    (description
     "This package provides Rust macro to automatically generates setter methods for a struct's fields.")
    (license (list license:expat license:asl2.0))))

(define-public rust-backon-1
  (package
    (name "rust-backon")
    (version "1.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "backon" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1mr3xva870l2604n4231iyxhiabakq2h3mlzh3fji3znk3n8jlms"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-fastrand" ,rust-fastrand-2)
                       ("rust-gloo-timers" ,rust-gloo-timers-0.3)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/Xuanwo/backon")
    (synopsis "Make retry like a built-in feature provided by Rust")
    (description
     "This package provides Make retry like a built-in feature provided by Rust.")
    (license license:asl2.0)))

(define-public rust-rustic-backend-0.5
  (package
    (name "rust-rustic-backend")
    (version "0.5.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rustic_backend" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1xgv9jswq458nygrrvzxn46hmlcrvq862wkn6w3s4xbckdpigsan"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aho-corasick" ,rust-aho-corasick-1)
                       ("rust-backon" ,rust-backon-1)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-bytesize" ,rust-bytesize-1)
                       ("rust-clap" ,rust-clap-4)
                       ("rust-conflate" ,rust-conflate-0.3)
                       ("rust-derive-setters" ,rust-derive-setters-0.1)
                       ("rust-displaydoc" ,rust-displaydoc-0.2)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-humantime" ,rust-humantime-2)
                       ("rust-itertools" ,rust-itertools-0.13)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-opendal" ,rust-opendal-0.50)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-reqwest" ,rust-reqwest-0.12)
                       ("rust-rustic-core" ,rust-rustic-core-0.7)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-strum" ,rust-strum-0.26)
                       ("rust-strum-macros" ,rust-strum-macros-0.26)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-typed-path" ,rust-typed-path-0.9)
                       ("rust-url" ,rust-url-2)
                       ("rust-walkdir" ,rust-walkdir-2))))
    (home-page "https://rustic.cli.rs/")
    (synopsis
     "rustic_backend - library for supporting various backends in rustic-rs")
    (description
     "This package provides rustic_backend - library for supporting various backends in rustic-rs.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-jemallocator-global-0.3
  (package
    (name "rust-jemallocator-global")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "jemallocator-global" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "07jqgy641spghfw4h6c5kg5fmmngk3zvpjpngiqbbj35hgg626wr"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-0.1)
                       ("rust-jemallocator" ,rust-jemallocator-0.3))))
    (home-page "https://github.com/gnzlbg/jemallocator")
    (synopsis "Sets `jemalloc` as the `#[global_allocator]`")
    (description
     "This package provides Sets `jemalloc` as the `#[global_allocator]`.")
    (license (list license:expat license:asl2.0))))

(define-public rust-jaq-std-2
  (package
    (name "rust-jaq-std")
    (version "2.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "jaq-std" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "18gv6fx5b4ch4vhwsjlhkcs1fw4bhza21cnhqpmmaxzjz765wdfz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aho-corasick" ,rust-aho-corasick-1)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-hifijson" ,rust-hifijson-0.2)
                       ("rust-jaq-core" ,rust-jaq-core-2)
                       ("rust-libm" ,rust-libm-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-regex-lite" ,rust-regex-lite-0.1)
                       ("rust-urlencoding" ,rust-urlencoding-2))))
    (home-page "https://github.com/01mf02/jaq")
    (synopsis "Standard library for jaq")
    (description "This package provides Standard library for jaq.")
    (license license:expat)))

(define-public rust-hifijson-0.2
  (package
    (name "rust-hifijson")
    (version "0.2.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hifijson" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0hjwcn3hj7bmwqw084lbbvmwx7lnkfyid6b74wd0c30pwcyann4r"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/01mf02/hifijson")
    (synopsis "High-fidelity JSON lexer and parser")
    (description "This package provides High-fidelity JSON lexer and parser.")
    (license license:expat)))

(define-public rust-jaq-json-1
  (package
    (name "rust-jaq-json")
    (version "1.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "jaq-json" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "15nxrslhvwpak7jdvwhp2yh3zfjijf332yy5646ddqk1x7ch7l81"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-foldhash" ,rust-foldhash-0.1)
                       ("rust-hifijson" ,rust-hifijson-0.2)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-jaq-core" ,rust-jaq-core-2)
                       ("rust-jaq-std" ,rust-jaq-std-2)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/01mf02/jaq")
    (synopsis "JSON values for jaq")
    (description "This package provides JSON values for jaq.")
    (license license:expat)))

(define-public rust-jaq-core-2
  (package
    (name "rust-jaq-core")
    (version "2.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "jaq-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "166f9d6zq3lqy3x8fqrd6vrp5vvzw3z5rn70m3943ga16v4mvd5m"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-dyn-clone" ,rust-dyn-clone-1)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-typed-arena" ,rust-typed-arena-2))))
    (home-page "https://github.com/01mf02/jaq")
    (synopsis "Interpreter for the jaq language")
    (description "This package provides Interpreter for the jaq language.")
    (license license:expat)))

(define-public rust-human-panic-2
  (package
    (name "rust-human-panic")
    (version "2.0.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "human-panic" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1xzi9gj73s8x79kjffhdmjg14320xaxjhv1s0i02f215ldk4mf40"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anstream" ,rust-anstream-0.6)
                       ("rust-anstyle" ,rust-anstyle-1)
                       ("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-os-info" ,rust-os-info-3)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-toml" ,rust-toml-0.8)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/rust-cli/human-panic")
    (synopsis "Panic messages for humans")
    (description "This package provides Panic messages for humans.")
    (license (list license:expat license:asl2.0))))

(define-public rust-gethostname-0.5
  (package
    (name "rust-gethostname")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "gethostname" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0c0y7mc8bpsjkvvykqcic9cynskvm82iz4fn4335pmhqd2m5adnw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-rustix" ,rust-rustix-0.38)
                       ("rust-windows-targets" ,rust-windows-targets-0.52))))
    (home-page "https://github.com/swsnr/gethostname.rs")
    (synopsis "gethostname for all platforms")
    (description "This package provides gethostname for all platforms.")
    (license license:asl2.0)))

(define-public rust-page-size-0.5
  (package
    (name "rust-page-size")
    (version "0.5.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "page_size" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0qdm2b6h63bwxy8s6jccd1v30f6dysbq9ylfs0cdikwhs75n6xhv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-spin" ,rust-spin-0.9)
                       ("rust-winapi" ,rust-winapi-0.3))))
    (home-page "https://github.com/Elzair/page_size_rs")
    (synopsis
     "Provides an easy, fast, cross-platform way to retrieve the memory page size")
    (description
     "This package provides an easy, fast, cross-platform way to retrieve the memory
                   page size.")
    (license (list license:expat license:asl2.0))))

(define-public rust-fuser-0.13
  (package
    (name "rust-fuser")
    (version "0.13.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fuser" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "16qny3f5snpjzvv33x7wfvs42nf5qjzsdcnz6vmchhh6cj20ydr1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-page-size" ,rust-page-size-0.5)
                       ("rust-pkg-config" ,rust-pkg-config-0.3)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-zerocopy" ,rust-zerocopy-0.6))))
    (home-page "https://github.com/cberner/fuser")
    (synopsis "Filesystem in Userspace (FUSE) for Rust")
    (description
     "This package provides Filesystem in Userspace (FUSE) for Rust.")
    (license license:expat)))

(define-public rust-fuse-mt-0.6
  (package
    (name "rust-fuse-mt")
    (version "0.6.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fuse_mt" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0j296nfz2bs3f6kc4r1w4f8q279727pxz34w3nirnbnk9kfbi670"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-fuser" ,rust-fuser-0.13)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-threadpool" ,rust-threadpool-1))))
    (home-page "https://github.com/wfraser/fuse-mt")
    (synopsis
     "higher-level FUSE filesystem library with multi-threading and inode->path translation.")
    (description
     "This package provides a higher-level FUSE filesystem library with
                   multi-threading and inode->path translation.")
    (license (list license:expat license:asl2.0))))

(define-public rust-derive-more-impl-1
  (package
    (name "rust-derive-more-impl")
    (version "1.0.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "derive_more-impl" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "08mxyd456ygk68v5nfn4dyisn82k647w9ri2jl19dqpvmnp30wyb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-convert-case" ,rust-convert-case-0.6)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-rustc-version" ,rust-rustc-version-0.4)
                       ("rust-syn" ,rust-syn-2)
                       ("rust-unicode-xid" ,rust-unicode-xid-0.2))))
    (home-page "https://github.com/JelteF/derive_more")
    (synopsis "Internal implementation of `derive_more` crate")
    (description
     "This package provides Internal implementation of `derive_more` crate.")
    (license license:expat)))

(define-public rust-derive-more-1
  (package
    (name "rust-derive-more")
    (version "1.0.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "derive_more" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "01cd8pskdjg10dvfchi6b8a9pa1ja1ic0kbn45dl8jdyrfwrk6sa"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-derive-more-impl" ,rust-derive-more-impl-1)
                       ("rust-rustc-version" ,rust-rustc-version-0.4))))
    (home-page "https://github.com/JelteF/derive_more")
    (synopsis "Adds #[derive(x)] macros for more traits")
    (description
     "This package provides Adds #[derive(x)] macros for more traits.")
    (license license:expat)))

(define-public rust-dav-server-0.7
  (package
    (name "rust-dav-server")
    (version "0.7.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dav-server" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1sfdz5rgl7nn1rsy4gls0hzp32dlnky0ay0b1k93m909r9ry7a93"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-actix-web" ,rust-actix-web-4)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-futures-channel" ,rust-futures-channel-0.3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-headers" ,rust-headers-0.4)
                       ("rust-htmlescape" ,rust-htmlescape-0.3)
                       ("rust-http" ,rust-http-1)
                       ("rust-http-body" ,rust-http-body-1)
                       ("rust-http-body-util" ,rust-http-body-util-0.1)
                       ("rust-hyper" ,rust-hyper-1)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-lru" ,rust-lru-0.12)
                       ("rust-mime-guess" ,rust-mime-guess-2)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pin-project" ,rust-pin-project-1)
                       ("rust-pin-utils" ,rust-pin-utils-0.1)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-warp" ,rust-warp-0.3)
                       ("rust-xml-rs" ,rust-xml-rs-0.8)
                       ("rust-xmltree" ,rust-xmltree-0.10))))
    (home-page "https://github.com/messense/dav-server-rs")
    (synopsis "Rust WebDAV server library. A fork of the webdav-handler crate")
    (description
     "This package provides Rust @code{WebDAV} server library. A fork of the webdav-handler crate.")
    (license license:asl2.0)))

(define-public rust-dateparser-0.2
  (package
    (name "rust-dateparser")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dateparser" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0f22d7c6is9w5pi496zsp1k95vmdv65p6bm0v3nfb6p0xqglbvy2"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-regex" ,rust-regex-1))))
    (home-page "https://github.com/waltzofpearls/dateparser")
    (synopsis "Parse dates in string formats that are commonly used")
    (description
     "This package provides Parse dates in string formats that are commonly used.")
    (license license:expat)))

(define-public rust-proc-macro-error-attr2-2
  (package
    (name "rust-proc-macro-error-attr2")
    (version "2.0.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "proc-macro-error-attr2" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ifzi763l7swl258d8ar4wbpxj4c9c2im7zy89avm6xv6vgl5pln"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1))))
    (home-page "https://github.com/GnomedDev/proc-macro-error-2")
    (synopsis "Attribute macro for the proc-macro-error2 crate")
    (description
     "This package provides Attribute macro for the proc-macro-error2 crate.")
    (license (list license:expat license:asl2.0))))

(define-public rust-proc-macro-error2-2
  (package
    (name "rust-proc-macro-error2")
    (version "2.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "proc-macro-error2" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "00lq21vgh7mvyx51nwxwf822w2fpww1x0z8z0q47p8705g2hbv0i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro-error-attr2" ,rust-proc-macro-error-attr2-2)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/GnomedDev/proc-macro-error-2")
    (synopsis "Almost drop-in replacement to panics in proc-macros")
    (description
     "This package provides Almost drop-in replacement to panics in proc-macros.")
    (license (list license:expat license:asl2.0))))

(define-public rust-conflate-derive-0.2
  (package
    (name "rust-conflate-derive")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "conflate_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1fd4m6vyj2y2k0l99p7pm2a2rsn4n25c58lafxmclmk667jsr5ck"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro-error2" ,rust-proc-macro-error2-2)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/rustic-rs/conflate")
    (synopsis "Derive macro for the conflate::Merge trait")
    (description
     "This package provides Derive macro for the conflate::Merge trait.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-conflate-0.3
  (package
    (name "rust-conflate")
    (version "0.3.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "conflate" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1v6xqr0qyppbn9ka6r24id6yw8840p7vjbi8nk5bjgpjih5ff489"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-conflate-derive" ,rust-conflate-derive-0.2)
                       ("rust-num-traits" ,rust-num-traits-0.2))))
    (home-page "https://github.com/rustic-rs/conflate")
    (synopsis "Merge multiple values into one")
    (description "This package provides Merge multiple values into one.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-tokio-retry-0.3
  (package
    (name "rust-tokio-retry")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tokio-retry" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0kr1hnm5dmb9gfkby88yg2xj8g6x4i4gipva0c8ca3xyxhvfnmvz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-pin-project" ,rust-pin-project-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/srijs/rust-tokio-retry")
    (synopsis "Extensible, asynchronous retry behaviours for futures/tokio")
    (description
     "This package provides Extensible, asynchronous retry behaviours for futures/tokio.")
    (license license:expat)))

(define-public rust-futures-rustls-0.25
  (package
    (name "rust-futures-rustls")
    (version "0.25.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "futures-rustls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0km0dhsc6ji1ix9d52h2w5spinlj9smpxr5k5r4w1v0gkx4s5n68"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-rustls" ,rust-rustls-0.22)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1))))
    (home-page "https://github.com/quininer/futures-rustls")
    (synopsis "Asynchronous TLS/SSL streams for futures using Rustls")
    (description
     "This package provides Asynchronous TLS/SSL streams for futures using Rustls.")
    (license (list license:expat license:asl2.0))))

(define-public rust-crc16-0.4
  (package
    (name "rust-crc16")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "crc16" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1zzwb5iv51wnh96532cxkk4aa8ys47rhzrjy98wqcys25ks8k01k"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/blackbeam/rust-crc16")
    (synopsis "CRC16 implementation")
    (description "This package provides a CRC16 implementation.")
    (license license:expat)))

(define-public rust-async-native-tls-0.4
  (package
    (name "rust-async-native-tls")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-native-tls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1zhkka5azpr03wg2bswabmwcwcqbdia17h2d17hk4wk47kn4qzfm"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-url" ,rust-url-2))))
    (home-page "https://docs.rs/crate/async-native-tls/")
    (synopsis "Native TLS using futures")
    (description "This package provides Native TLS using futures.")
    (license (list license:expat license:asl2.0))))

(define-public rust-redis-0.25
  (package
    (name "rust-redis")
    (version "0.25.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "redis" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1v5vp150f62f3y6jhjy2z12g3hxk09nnrs597c7zc4bmbjasdmz0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-arc-swap" ,rust-arc-swap-1)
                       ("rust-async-native-tls" ,rust-async-native-tls-0.4)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-bytes" ,rust-bytes-1)
                       ("rust-combine" ,rust-combine-4)
                       ("rust-crc16" ,rust-crc16-0.4)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-futures-rustls" ,rust-futures-rustls-0.25)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-r2d2" ,rust-r2d2-0.8)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rust-decimal" ,rust-rust-decimal-1)
                       ("rust-rustls" ,rust-rustls-0.22)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.7)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-2)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-ryu" ,rust-ryu-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha1-smol" ,rust-sha1-smol-1)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-retry" ,rust-tokio-retry-0.3)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.25)
                       ("rust-tokio-util" ,rust-tokio-util-0.7)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26))))
    (home-page "https://github.com/redis-rs/redis-rs")
    (synopsis "Redis driver for Rust")
    (description "This package provides Redis driver for Rust.")
    (license license:bsd-3)))

(define-public rust-cached-proc-macro-types-0.1
  (package
    (name "rust-cached-proc-macro-types")
    (version "0.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cached_proc_macro_types" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1h3gw61v1inay4g3b8pirxlz18m81k63dw2q18zj9fnmidmkds5d"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/jaemk/cached")
    (synopsis
     "Generic cache implementations and simplified function memoization")
    (description
     "This package provides Generic cache implementations and simplified function memoization.")
    (license license:expat)))

(define-public rust-cached-proc-macro-0.23
  (package
    (name "rust-cached-proc-macro")
    (version "0.23.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cached_proc_macro" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1ajxgl0w9vm55dk47qb0cq1akzncrwqcy78y37idq41dxm2s2hig"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-darling" ,rust-darling-0.20)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/jaemk/cached")
    (synopsis
     "Generic cache implementations and simplified function memoization")
    (description
     "This package provides Generic cache implementations and simplified function memoization.")
    (license license:expat)))

(define-public rust-cached-0.54
  (package
    (name "rust-cached")
    (version "0.54.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cached" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1biwqcfkb7s4a3nk7mwfpv8hxl8d6ixzjdnpdyjyis9g99n8064p"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-cached-proc-macro" ,rust-cached-proc-macro-0.23)
                       ("rust-cached-proc-macro-types" ,rust-cached-proc-macro-types-0.1)
                       ("rust-directories" ,rust-directories-5)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-r2d2" ,rust-r2d2-0.8)
                       ("rust-redis" ,rust-redis-0.25)
                       ("rust-rmp-serde" ,rust-rmp-serde-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sled" ,rust-sled-0.34)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-web-time" ,rust-web-time-1))))
    (home-page "https://github.com/jaemk/cached")
    (synopsis
     "Generic cache implementations and simplified function memoization")
    (description
     "This package provides Generic cache implementations and simplified function memoization.")
    (license license:expat)))

(define-public rust-abscissa-derive-0.8
  (package
    (name "rust-abscissa-derive")
    (version "0.8.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "abscissa_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1qkzz20v71y26id2sfcdfc3jhgzf4gihf6g07x1xmx1f3mi19n88"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ident-case" ,rust-ident-case-1)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-1)
                       ("rust-synstructure" ,rust-synstructure-0.12))))
    (home-page "https://github.com/iqlusioninc/abscissa")
    (synopsis
     "Custom derive support for the abscissa application microframework")
    (description
     "This package provides Custom derive support for the abscissa application microframework.")
    (license license:asl2.0)))

(define-public rust-abscissa-core-0.8
  (package
    (name "rust-abscissa-core")
    (version "0.8.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "abscissa_core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0fvpm79dnwh1lj5kpw1bs3sfs8drcwbvbic6vrmjsh34v1x1i0rh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-abscissa-derive" ,rust-abscissa-derive-0.8)
                       ("rust-arc-swap" ,rust-arc-swap-1)
                       ("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-canonical-path" ,rust-canonical-path-2)
                       ("rust-clap" ,rust-clap-4)
                       ("rust-color-eyre" ,rust-color-eyre-0.6)
                       ("rust-fs-err" ,rust-fs-err-2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-secrecy" ,rust-secrecy-0.10)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-termcolor" ,rust-termcolor-1)
                       ("rust-toml" ,rust-toml-0.8)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-tracing-log" ,rust-tracing-log-0.2)
                       ("rust-tracing-subscriber" ,rust-tracing-subscriber-0.3)
                       ("rust-wait-timeout" ,rust-wait-timeout-0.2))))
    (home-page "https://github.com/iqlusioninc/abscissa/")
    (synopsis
     "Application microframework with support for command-line option parsing,
                   configuration, error handling, logging, and terminal interactions.
                   This crate contains the framework's core functionality.")
    (description
     "This package provides Application microframework with support for command-line option parsing,
                     configuration, error handling, logging, and terminal interactions. This crate
                     contains the framework's core functionality.")
    (license license:asl2.0)))

(define-public rust-form-urlencoded-1
  (package
    (name "rust-form-urlencoded")
    (version "1.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "form_urlencoded" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0milh8x7nl4f450s3ddhg57a3flcv6yq8hlkyk6fyr3mcb128dp1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-percent-encoding" ,rust-percent-encoding-2))))
    (home-page "https://github.com/servo/rust-url")
    (synopsis
     "Parser and serializer for the application/x-www-form-urlencoded syntax, as used by HTML forms")
    (description
     "This package provides Parser and serializer for the application/x-www-form-urlencoded syntax, as used
by HTML forms.")
    (license (list license:expat license:asl2.0))))

(define-public rust-yubico-rs-0.12
  (package
    (name "rust-yubico-rs")
    (version "0.12.0")
    (source
     ;;
     (origin
       (method git-fetch)
       (uri (git-reference
             (url "https://github.com/BlackDex/yubico-rs.git")
             (commit "00df14")))
       (file-name (git-file-name name version))
       (sha256
        (base32 "0fv3ybppxkzxcz0gnckz9bpf15avsbf90fwwyk14bf5j24rrklb1"))))

    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs

       (("rust-base64" ,rust-base64-0.22)
        ("rust-form-urlencoded" ,rust-form-urlencoded-1)
        ("rust-futures" ,rust-futures-0.3)
        ("rust-reqwest" ,rust-reqwest-0.12))
       ;; #:cargo-build-flags '("--features" "rt-multi-thread")
       ))
    (inputs (list pkg-config openssl))
    (home-page "")
    (synopsis "TODO")
    (description "TODO")
    (license license:gpl3)))

(define-public rust-yubico-0.11
  (package
    (name "rust-yubico")
    (version "0.11.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "yubico" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1yymc14rl9axqyqrfk0s5fgcac4rlqaa3qsasyi2j101qk97agqp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-base64" ,rust-base64-0.13)
                       ("rust-form-urlencoded" ,rust-form-urlencoded-1)
                       ("rust-futures" ,rust-futures-0.3)
                       ("rust-hmac" ,rust-hmac-0.12)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-reqwest" ,rust-reqwest-0.11)
                       ("rust-sha1" ,rust-sha1-0.10)
                       ("rust-threadpool" ,rust-threadpool-1))
       #:cargo-development-inputs (("rust-futures" ,rust-futures-0.3)
                                   ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/wisespace-io/yubico-rs")
    (synopsis "Yubikey client API library")
    (description "This package provides Yubikey client API library.")
    (license (list license:expat license:asl2.0))))

(define-public rust-dashmap-6
  (package
    (name "rust-dashmap")
    (version "6.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "dashmap" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1kvnw859xvrqyd1lk89na6797yvl5bri4wi9j0viz2a4j54wqhah"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-arbitrary" ,rust-arbitrary-1)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-crossbeam-utils" ,rust-crossbeam-utils-0.8)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-lock-api" ,rust-lock-api-0.4)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-parking-lot-core" ,rust-parking-lot-core-0.9)
                       ("rust-rayon" ,rust-rayon-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-typesize" ,rust-typesize-0.1))))
    (home-page "https://github.com/xacrimon/dashmap")
    (synopsis "Blazing fast concurrent HashMap for Rust")
    (description
     "This package provides Blazing fast concurrent @code{HashMap} for Rust.")
    (license license:expat)))

(define-public rust-diesel-2
  (package
    (name "rust-diesel")
    (version "2.2.7")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "diesel" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1mcnarp9w9yxd3zr81y3n7gq8q1p01035yh4b0qxqhw8p8iiy004"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-bigdecimal" ,rust-bigdecimal-0.4)
                       ("rust-bitflags" ,rust-bitflags-2)
                       ("rust-byteorder" ,rust-byteorder-1)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-diesel-derives" ,rust-diesel-derives-2)
                       ("rust-ipnet" ,rust-ipnet-2)
                       ("rust-ipnetwork" ,rust-ipnetwork-0.20)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-libsqlite3-sys" ,rust-libsqlite3-sys-0.30)
                       ("rust-mysqlclient-src" ,rust-mysqlclient-src-0.1)
                       ("rust-mysqlclient-sys" ,rust-mysqlclient-sys-0.2)
                       ("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-num-integer" ,rust-num-integer-0.1)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-pq-src" ,rust-pq-src-0.3)
                       ("rust-pq-sys" ,rust-pq-sys-0.4)
                       ("rust-quickcheck" ,rust-quickcheck-1)
                       ("rust-r2d2" ,rust-r2d2-0.8)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-time" ,rust-time-0.3)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1))
       #:cargo-development-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                                   ("rust-dotenvy" ,rust-dotenvy-0.15)
                                   ("rust-ipnetwork" ,rust-ipnetwork-0.20)
                                   ("rust-quickcheck" ,rust-quickcheck-1)
                                   ("rust-tempfile" ,rust-tempfile-3))))
    (home-page "https://diesel.rs")
    (synopsis
     "safe, extensible ORM and Query Builder for PostgreSQL, SQLite, and MySQL")
    (description
     "This package provides a safe, extensible ORM and Query Builder for
@code{PostgreSQL}, SQLite, and @code{MySQL}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-diesel-logger-0.4
  (package
    (name "rust-diesel-logger")
    (version "0.4.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "diesel_logger" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "15dgmrqgywvl1jw0nlnx90g9f0jzyqj92rpflqicyxdnzwzq6x40"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-diesel" ,rust-diesel-2)
                       ("rust-log" ,rust-log-0.4))))
    (home-page "https://github.com/shssoichiro/diesel-logger")
    (synopsis "Times and logs queries executed by diesel")
    (description
     "This package provides Times and logs queries executed by diesel.")
    (license license:expat)))

(define-public rust-migrations-macros-2
  (package
    (name "rust-migrations-macros")
    (version "2.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "migrations_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1z9p2ag0fnnh0m7z8qfncwyjc0pgschca7vzlixb6v0pfb663cgz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-migrations-internals" ,rust-migrations-internals-2)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1))))
    (home-page "https://diesel.rs")
    (synopsis "Codegeneration macros for diesels embedded migrations")
    (description
     "This package provides Codegeneration macros for diesels embedded migrations.")
    (license (list license:expat license:asl2.0))))

(define-public rust-migrations-internals-2
  (package
    (name "rust-migrations-internals")
    (version "2.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "migrations_internals" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1zw0lf2lw3wlmyb0kv68cnr3ya2n80svpavf0jcqfbz8a6c060gx"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1)
                       ("rust-toml" ,rust-toml-0.8))))
    (home-page "https://diesel.rs")
    (synopsis "Internal implementation of diesels migration mechanism")
    (description
     "This package provides Internal implementation of diesels migration mechanism.")
    (license (list license:expat license:asl2.0))))

(define-public rust-diesel-migrations-2
  (package
    (name "rust-diesel-migrations")
    (version "2.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "diesel_migrations" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1xn12ny9m1ci74iqpvhcfyhapr6wj56k3wxz07q32hmd9dqcwwwa"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-diesel" ,rust-diesel-2)
                       ("rust-migrations-internals" ,rust-migrations-internals-2)
                       ("rust-migrations-macros" ,rust-migrations-macros-2))
       #:cargo-development-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                                   ("rust-dotenvy" ,rust-dotenvy-0.15)
                                   ("rust-tempfile" ,rust-tempfile-3))))
    (home-page "https://diesel.rs")
    (synopsis "Migration management for diesel")
    (description "This package provides Migration management for diesel.")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-assert-0.8
  (package
    (name "rust-serde-assert")
    (version "0.8.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_assert" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0m1aqpq070wygfcza5d97s1qiv89n1k2l0sxdmsqb7581fmind7p"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/Anders429/serde_assert")
    (synopsis
     "Testing library for serde Serialize and Deserialize implementations")
    (description
     "This package provides Testing library for serde Serialize and Deserialize implementations.")
    (license (list license:expat license:asl2.0))))

(define-public rust-email-address-0.2
  (package
    (name "rust-email-address")
    (version "0.2.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "email_address" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0jf4v3npa524c7npy7w3jl0a6gng26f51a4bgzs3jqna12dz2yg0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-serde" ,rust-serde-1))
       #:cargo-development-inputs (("rust-claims" ,rust-claims-0.7)
                                   ("rust-serde-assert" ,rust-serde-assert-0.8))))
    (home-page "https://github.com/johnstonskj/rust-email_address.git")
    (synopsis
     "Rust crate providing an implementation of an RFC-compliant `EmailAddress` newtype.")
    (description
     "This package provides a Rust crate providing an implementation of an
RFC-compliant `@code{EmailAddress`} newtype.")
    (license license:expat)))

(define-public rust-fern-0.7
  (package
    (name "rust-fern")
    (version "0.7.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "fern" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0a9v59vcq2fgd6bwgbfl7q6b0zzgxn85y6g384z728wvf1gih5j3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-chrono" ,rust-chrono-0.4)
                       ("rust-colored" ,rust-colored-2)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-reopen" ,rust-reopen-0.3)
                       ("rust-reopen" ,rust-reopen-1)
                       ("rust-syslog" ,rust-syslog-3)
                       ("rust-syslog" ,rust-syslog-4)
                       ("rust-syslog" ,rust-syslog-6)
                       ("rust-syslog" ,rust-syslog-7))
       #:cargo-development-inputs (("rust-clap" ,rust-clap-2)
                                   ("rust-humantime" ,rust-humantime-2)
                                   ("rust-tempfile" ,rust-tempfile-3))))
    (home-page "https://github.com/daboross/fern")
    (synopsis "Simple, efficient logging")
    (description "This package provides Simple, efficient logging.")
    (license license:expat)))

(define-public rust-tynm-0.1
  (package
    (name "rust-tynm")
    (version "0.1.10")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tynm" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1vc12w4b1imk2gbbiy9cpk785v6g14s8ayiyzq9qwiyid5gd0c5x"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-nom" ,rust-nom-7)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/azriel91/tynm")
    (synopsis "Returns type names in shorter form")
    (description "This package provides Returns type names in shorter form.")
    (license (list license:expat license:asl2.0))))

(define-public rust-all-asserts-2
  (package
    (name "rust-all-asserts")
    (version "2.3.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "all_asserts" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1skvzvl6n5y3szpmdxg6dr8qbcc3wgkjlbym5xq9dz7r8riy2k2i"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/ohsayan/all_asserts")
    (synopsis
     "crate for multiple types of asserts that don't exist in the standard library")
    (description
     "This package provides a crate for multiple types of asserts that don't exist in
the standard library.")
    (license license:asl2.0)))

(define-public rust-governor-0.8
  (package
    (name "rust-governor")
    (version "0.8.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "governor" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1l19nipyqazwnx33g70csqnh1jigr7nrdn3aayhyc0ffg62wfbc4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-dashmap" ,rust-dashmap-6)
                       ("rust-futures-sink" ,rust-futures-sink-0.3)
                       ("rust-futures-timer" ,rust-futures-timer-3)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-no-std-compat" ,rust-no-std-compat-0.4)
                       ("rust-nonzero-ext" ,rust-nonzero-ext-0.3)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-portable-atomic" ,rust-portable-atomic-1)
                       ("rust-quanta" ,rust-quanta-0.12)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-spinning-top" ,rust-spinning-top-0.3))
       #:cargo-development-inputs (("rust-all-asserts" ,rust-all-asserts-2)
                                   ("rust-criterion" ,rust-criterion-0.5)
                                   ("rust-crossbeam" ,rust-crossbeam-0.8)
                                   ("rust-futures-executor" ,rust-futures-executor-0.3)
                                   ("rust-libc" ,rust-libc-0.2)
                                   ("rust-proptest" ,rust-proptest-1)
                                   ("rust-tynm" ,rust-tynm-0.1))))
    (home-page "https://github.com/boinkor-net/governor")
    (synopsis "rate-limiting implementation in Rust")
    (description
     "This package provides a rate-limiting implementation in Rust.")
    (license license:expat)))

(define-public rust-lasso-0.7
  (package
    (name "rust-lasso")
    (version "0.7.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "lasso" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1yz92fy2zv6wslfwwf3j7lw1wxja8d91rrcwgfzv751l1ajys53f"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-abomonation" ,rust-abomonation-0.7)
                       ("rust-ahash" ,rust-ahash-0.8)
                       ("rust-dashmap" ,rust-dashmap-6)
                       ("rust-deepsize" ,rust-deepsize-0.2)
                       ("rust-hashbrown" ,rust-hashbrown-0.14)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/Kixiron/lasso")
    (synopsis
     "multithreaded and single threaded string interner that allows strings to be cached with a
minimal memory footprint, associating them with a unique key that can be used to retrieve them at any time.")
    (description
     "This package provides a multithreaded and single threaded string interner that
allows strings to be cached with a minimal memory footprint, associating them
with a unique key that can be used to retrieve them at any time.")
    (license (list license:expat license:asl2.0))))

(define-public rust-codemap-0.1
  (package
    (name "rust-codemap")
    (version "0.1.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "codemap" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "091azkslwkcijj3lp9ymb084y9a0wm4fkil7m613ja68r2snkrxr"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/kevinmehall/codemap")
    (synopsis
     "data structure for efficiently storing source code position and span information
(e.g. in a compiler AST), and mapping it back to file/line/column locations for error
reporting and suggestions.")
    (description
     "This package provides a data structure for efficiently storing source code
position and span information (e.g. in a compiler AST), and mapping it back to
file/line/column locations for error reporting and suggestions.")
    (license (list license:expat license:asl2.0))))

(define-public rust-grass-compiler-0.13
  (package
    (name "rust-grass-compiler")
    (version "0.13.4")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "grass_compiler" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1xngzb4h04fkdhyagrwcqanrl7arghj3v5sl84cfab12y3vkv7id"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-codemap" ,rust-codemap-0.1)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-lasso" ,rust-lasso-0.7)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-phf" ,rust-phf-0.11)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2))))
    (home-page "https://github.com/connorskees/grass")
    (synopsis "Internal implementation of the grass compiler")
    (description
     "This package provides Internal implementation of the grass compiler.")
    (license license:expat)))

(define-public rust-equator-macro-0.2
  (package
    (name "rust-equator-macro")
    (version "0.2.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "equator-macro" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1k0n5q7d6wn9g3fva9z7hr4pr3z494dsb1zja5ima8h3diwpkxiv"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/sarah-ek/equator/")
    (synopsis "Composable assertion library")
    (description "This package provides Composable assertion library.")
    (license license:expat)))

(define-public rust-equator-0.2
  (package
    (name "rust-equator")
    (version "0.2.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "equator" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1sk1swwd76rn091gi1m26s10z11dgynb4jfcly228782b8xsapf3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-equator-macro" ,rust-equator-macro-0.2))))
    (home-page "https://github.com/sarah-ek/equator/")
    (synopsis "Composable assertion library")
    (description "This package provides Composable assertion library.")
    (license license:expat)))

(define-public rust-aligned-vec-0.6
  (package
    (name "rust-aligned-vec")
    (version "0.6.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "aligned-vec" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0ammhfzm15iyg6rd21019ivlaqixrcr1psvhpn02a1dgbqb6c2by"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-equator" ,rust-equator-0.2)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/sarah-ek/aligned-vec/")
    (synopsis "Aligned vector and box containers")
    (description "This package provides Aligned vector and box containers.")
    (license license:expat)))

(define-public rust-pprof-0.14
  (package
    (name "rust-pprof")
    (version "0.14.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "pprof" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1l6nb1zmym8m99vhr6y2blff4af9x555m7nwby0l9fmyk242zgpb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-aligned-vec" ,rust-aligned-vec-0.6)
                       ("rust-backtrace" ,rust-backtrace-0.3)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-criterion" ,rust-criterion-0.5)
                       ("rust-findshlibs" ,rust-findshlibs-0.10)
                       ("rust-inferno" ,rust-inferno-0.11)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-nix" ,rust-nix-0.26)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-parking-lot" ,rust-parking-lot-0.12)
                       ("rust-prost" ,rust-prost-0.12)
                       ("rust-prost-build" ,rust-prost-build-0.12)
                       ("rust-prost-derive" ,rust-prost-derive-0.12)
                       ("rust-protobuf" ,rust-protobuf-2)
                       ("rust-protobuf-codegen-pure" ,rust-protobuf-codegen-pure-2)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-smallvec" ,rust-smallvec-1)
                       ("rust-symbolic-demangle" ,rust-symbolic-demangle-12)
                       ("rust-tempfile" ,rust-tempfile-3)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/tikv/pprof-rs")
    (synopsis "An internal perf tools for rust programs")
    (description
     "This package provides An internal perf tools for rust programs.")
    (license license:asl2.0)))

(define-public rust-num-modular-0.6
  (package
    (name "rust-num-modular")
    (version "0.6.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "num-modular" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0zv4miws3q1i93a0bd9wgc4njrr5j5786kr99hzxi9vgycdjdfqp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-num-integer" ,rust-num-integer-0.1)
                       ("rust-num-traits" ,rust-num-traits-0.2))))
    (home-page "https://github.com/cmpute/num-modular")
    (synopsis
     "Implementation of efficient integer division and modular arithmetic operations with generic number types.
Supports various backends including num-bigint, etc..")
    (description
     "This package provides Implementation of efficient integer division and modular arithmetic operations
with generic number types.  Supports various backends including num-bigint,
etc..")
    (license license:asl2.0)))

(define-public rust-num-order-1
  (package
    (name "rust-num-order")
    (version "1.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "num-order" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1dhvdncf91ljxh9sawnfxcbiqj1gnag08lyias0cy3y4jxmmjysk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-num-bigint" ,rust-num-bigint-0.4)
                       ("rust-num-complex" ,rust-num-complex-0.4)
                       ("rust-num-modular" ,rust-num-modular-0.6)
                       ("rust-num-rational" ,rust-num-rational-0.4)
                       ("rust-num-traits" ,rust-num-traits-0.2))))
    (home-page "https://github.com/cmpute/num-order")
    (synopsis
     "Numerically consistent `Eq`, `Ord` and `Hash` implementations for various `num` types (`u32`, `f64`, `num_bigint::BigInt`, etc.)")
    (description
     "This package provides Numerically consistent `Eq`, `Ord` and `Hash` implementations for various `num`
types (`u32`, `f64`, `num_bigint::@code{BigInt`}, etc.).")
    (license license:asl2.0)))

(define-public rust-handlebars-6
  (package
    (name "rust-handlebars")
    (version "6.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "handlebars" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0z5sdkxarw9kfkvgmmz0fdkq32i17hp2zrr8vmq1lk5wv9yp8lnp"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-derive-builder" ,rust-derive-builder-0.20)
                       ("rust-heck" ,rust-heck-0.5)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-num-order" ,rust-num-order-1)
                       ("rust-pest" ,rust-pest-2)
                       ("rust-pest-derive" ,rust-pest-derive-2)
                       ("rust-rhai" ,rust-rhai-1)
                       ("rust-rust-embed" ,rust-rust-embed-8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-thiserror" ,rust-thiserror-2)
                       ("rust-walkdir" ,rust-walkdir-2))
       #:cargo-development-inputs (("rust-criterion" ,rust-criterion-0.5)
                                   ("rust-env-logger" ,rust-env-logger-0.11)
                                   ("rust-pprof" ,rust-pprof-0.14)
                                   ("rust-serde-derive" ,rust-serde-derive-1)
                                   ("rust-tempfile" ,rust-tempfile-3)
                                   ("rust-time" ,rust-time-0.3)
                                   ("rust-tiny-http" ,rust-tiny-http-0.12))))
    (home-page "https://github.com/sunng87/handlebars-rust")
    (synopsis "Handlebars templating implemented in Rust")
    (description
     "This package provides Handlebars templating implemented in Rust.")
    (license license:expat)))

(define-public rust-scraper-0.20
  (package
    (name "rust-scraper")
    (version "0.20.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "scraper" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1w7am40xb12s6klrv1l58n6i35xdcp344bi6x1xw07zy3frn015r"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-ahash" ,rust-ahash-0.8)
                       ("rust-cssparser" ,rust-cssparser-0.31)
                       ("rust-ego-tree" ,rust-ego-tree-0.6)
                       ("rust-getopts" ,rust-getopts-0.2)
                       ("rust-html5ever" ,rust-html5ever-0.27)
                       ("rust-indexmap" ,rust-indexmap-2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-selectors" ,rust-selectors-0.25)
                       ("rust-tendril" ,rust-tendril-0.4))))
    (home-page "https://github.com/causal-agent/scraper")
    (synopsis "HTML parsing and querying with CSS selectors")
    (description
     "This package provides HTML parsing and querying with CSS selectors.")
    (license license:isc)))

(define-public rust-html5gum-0.7
  (package
    (name "rust-html5gum")
    (version "0.7.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "html5gum" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0wpzigh6g3hmshqybi3sm33n5r8vnn3aj796ayvn266n6rgqp4dk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-html5ever" ,rust-html5ever-0.27)
                       ("rust-jetscii" ,rust-jetscii-0.5)
                       ("rust-markup5ever-rcdom" ,rust-markup5ever-rcdom-0.3))
       #:cargo-development-inputs (("rust-argh" ,rust-argh-0.1)
                                   ("rust-glob" ,rust-glob-0.3)
                                   ("rust-libtest-mimic" ,rust-libtest-mimic-0.8)
                                   ("rust-pretty-assertions" ,rust-pretty-assertions-1)
                                   ("rust-scraper" ,rust-scraper-0.20)
                                   ("rust-serde" ,rust-serde-1)
                                   ("rust-serde-bytes" ,rust-serde-bytes-0.11)
                                   ("rust-serde-json" ,rust-serde-json-1)
                                   ("rust-test-generator" ,rust-test-generator-0.3))))
    (home-page "https://github.com/untitaker/html5gum")
    (synopsis "WHATWG-compliant HTML5 tokenizer and tag soup parser.")
    (description
     "This package provides a WHATWG-compliant HTML5 tokenizer and tag soup parser.")
    (license license:expat)))

(define-public rust-cron-0.12
  (package
    (name "rust-cron")
    (version "0.12.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "cron" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "01qc1cnhibxh55pwv3mwaxvfgbjpgk1lfl7an5m4ljvv0xrkx33g"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-chrono" ,rust-chrono-0.4)
                       ("rust-nom" ,rust-nom-7)
                       ("rust-once-cell" ,rust-once-cell-1))))
    (home-page "https://github.com/zslayton/cron")
    (synopsis "cron expression parser and schedule explorer.")
    (description
     "This package provides a cron expression parser and schedule explorer.")
    (license (list license:expat license:asl2.0))))

(define-public rust-job-scheduler-ng-2
  (package
    (name "rust-job-scheduler-ng")
    (version "2.0.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "job_scheduler_ng" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0siw182x6b8cka89d65a7v6hixpqryyrwxc7s2b2jgijgwh55hl7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-chrono" ,rust-chrono-0.4)
                       ("rust-cron" ,rust-cron-0.12)
                       ("rust-uuid" ,rust-uuid-1))
       #:cargo-development-inputs (("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/BlackDex/job_scheduler")
    (synopsis
     "simple cron-like job scheduling library for Rust (Updated since 2022).")
    (description
     "This package provides a simple cron-like job scheduling library for Rust
(Updated since 2022).")
    (license (list license:expat license:asl2.0))))

(define-public rust-jsonwebtoken-9
  (package
    (name "rust-jsonwebtoken")
    (version "9.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "jsonwebtoken" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1plx2qf8mpg96bpsa1aalfsf4jvgwcnl6i37x7masysk91xcr1ss"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-pem" ,rust-pem-3)
                       ("rust-ring" ,rust-ring-0.17)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-simple-asn1" ,rust-simple-asn1-0.6))
       #:cargo-development-inputs (("rust-criterion" ,rust-criterion-0.4)
                                   ("rust-time" ,rust-time-0.3)
                                   ("rust-wasm-bindgen-test" ,rust-wasm-bindgen-test-0.3))))
    (home-page "https://github.com/Keats/jsonwebtoken")
    (synopsis "Create and decode JWTs in a strongly typed way")
    (description
     "This package provides Create and decode JWTs in a strongly typed way.")
    (license license:expat)))

(define-public rust-route-recognizer-0.2
  (package
    (name "rust-route-recognizer")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "route-recognizer" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "17mmnyzg7yr5x84n28y6bll1qn21g11k61p6sgg2fjf0xdshcxsn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/rustasync/route-recognizer")
    (synopsis
     "Recognizes URL patterns with support for dynamic and wildcard segments")
    (description
     "This package provides Recognizes URL patterns with support for dynamic and wildcard segments.")
    (license license:expat)))

(define-public rust-async-sse-4
  (package
    (name "rust-async-sse")
    (version "4.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-sse" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "046yba03pl4n4z7r4ls3xn442xmsd6w5j36d8lid53vbk41s1fsk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-channel" ,rust-async-channel-1)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-http-types" ,rust-http-types-2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.1))))
    (home-page "https://github.com/http-rs/async-sse")
    (synopsis "Async Server Sent Event parser and encoder")
    (description
     "This package provides Async Server Sent Event parser and encoder.")
    (license (list license:expat license:asl2.0))))

(define-public rust-hmac-0.8
  (package
    (name "rust-hmac")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hmac" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h48wc7iysh4xd6ci4prh8bb7nszijrh9w3blaaq8a6cilk8hs0j"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-crypto-mac" ,rust-crypto-mac-0.8)
                       ("rust-digest" ,rust-digest-0.9))))
    (home-page "https://github.com/RustCrypto/MACs")
    (synopsis
     "Generic implementation of Hash-based Message Authentication Code (HMAC)")
    (description
     "This package provides Generic implementation of Hash-based Message Authentication Code (HMAC).")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-session-2
  (package
    (name "rust-async-session")
    (version "2.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-session" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "07v3rk133bsbvy9dgfzwsl5i07il3kb6zcn1bh8cv4nhxsi24l1l"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.12)
                       ("rust-bincode" ,rust-bincode-1)
                       ("rust-blake3" ,rust-blake3-0.3)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-hmac" ,rust-hmac-0.8)
                       ("rust-kv-log-macro" ,rust-kv-log-macro-1)
                       ("rust-rand" ,rust-rand-0.7)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha2" ,rust-sha2-0.9))))
    (home-page "https://github.com/http-rs/async-session")
    (synopsis "Async session support with pluggable middleware")
    (description
     "This package provides Async session support with pluggable middleware.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tide-0.16
  (package
    (name "rust-tide")
    (version "0.16.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tide" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1q6yl5wkmy8csbg6024mxvw5m1zai5sgaiwhad5p7k6j1lzmfnf4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-h1" ,rust-async-h1-2)
                       ("rust-async-session" ,rust-async-session-2)
                       ("rust-async-sse" ,rust-async-sse-4)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-femme" ,rust-femme-2)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-http-client" ,rust-http-client-6)
                       ("rust-http-types" ,rust-http-types-2)
                       ("rust-kv-log-macro" ,rust-kv-log-macro-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-route-recognizer" ,rust-route-recognizer-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/http-rs/tide")
    (synopsis
     "minimal and pragmatic Rust web application framework built for rapid development")
    (description
     "This package provides a minimal and pragmatic Rust web application framework
built for rapid development.")
    (license (list license:expat license:asl2.0))))

(define-public rust-maud-macros-0.26
  (package
    (name "rust-maud-macros")
    (version "0.26.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "maud_macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "062f4w3367x1la8j6wkvv5ga9hxmsdw5kz0idfps1391xhw34igs"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-proc-macro-error" ,rust-proc-macro-error-1)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://maud.lambda.xyz/")
    (synopsis "Internal crate. Please use 'maud' instead")
    (description
     "This package provides Internal crate.  Please use maud instead.")
    (license (list license:expat license:asl2.0))))

(define-public rust-maud-0.26
  (package
    (name "rust-maud")
    (version "0.26.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "maud" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1amw5r3w4v9z2grr2cf90aca9x1244gv18gzvp6qjhkb05sqnlfz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-actix-web" ,rust-actix-web-4)
                       ("rust-axum-core" ,rust-axum-core-0.4)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-http" ,rust-http-1)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-maud-macros" ,rust-maud-macros-0.26)
                       ("rust-rocket" ,rust-rocket-0.5)
                       ("rust-tide" ,rust-tide-0.16)
                       ("rust-warp" ,rust-warp-0.3))))
    (home-page "https://maud.lambda.xyz/")
    (synopsis "Compile-time HTML templates")
    (description "This package provides Compile-time HTML templates.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tokio-boring-4
  (package
    (name "rust-tokio-boring")
    (version "4.13.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tokio-boring" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "031smp6wj2k0rdh15hjyf44azx7k1b8h3sagn3kxwq639yc8yyz3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-boring" ,rust-boring-4)
                       ("rust-boring-sys" ,rust-boring-sys-4)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-tokio" ,rust-tokio-1))))
    (home-page "https://github.com/cloudflare/boring")
    (synopsis "An implementation of SSL streams for Tokio backed by BoringSSL")
    (description
     "This package provides An implementation of SSL streams for Tokio backed by @code{BoringSSL}.")
    (license (list license:expat license:asl2.0))))

(define-public rust-email-address-0.2
  (package
    (name "rust-email-address")
    (version "0.2.9")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "email_address" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0jf4v3npa524c7npy7w3jl0a6gng26f51a4bgzs3jqna12dz2yg0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/johnstonskj/rust-email_address.git")
    (synopsis
     "Rust crate providing an implementation of an RFC-compliant `EmailAddress` newtype.")
    (description
     "This package provides a Rust crate providing an implementation of an
RFC-compliant `@code{EmailAddress`} newtype.")
    (license license:expat)))

(define-public rust-email-encoding-0.3
  (package
    (name "rust-email-encoding")
    (version "0.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "email-encoding" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1k4xkmdm8j8vdaq9c3nx6qx14jzjdgab5yb5n9v48cdbpd5qjgga"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.22)
                       ("rust-memchr" ,rust-memchr-2))))
    (home-page "https://github.com/lettre/email-encoding")
    (synopsis "Low level email encoding RFCs implementations")
    (description
     "This package provides Low level email encoding RFCs implementations.")
    (license (list license:expat license:asl2.0))))

(define-public rust-boring-sys-4
  (package
    (name "rust-boring-sys")
    (version "4.13.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "boring-sys" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0y9d6khflim1wp41vxy1m1p26a0b7kjdzcfg8kr48cjgj8awrazb"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-autocfg" ,rust-autocfg-1)
                       ("rust-bindgen" ,rust-bindgen-0.70)
                       ("rust-cmake" ,rust-cmake-0.1)
                       ("rust-fs-extra" ,rust-fs-extra-1)
                       ("rust-fslock" ,rust-fslock-0.2))))
    (home-page "https://github.com/cloudflare/boring")
    (synopsis "FFI bindings to BoringSSL")
    (description "This package provides FFI bindings to @code{BoringSSL}.")
    (license license:expat)))

(define-public rust-boring-4
  (package
    (name "rust-boring")
    (version "4.13.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "boring" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "13lsfanr3jibf7xsc7mgyfjgknx947vay10nvqjkg89v7h1aqnhz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bitflags" ,rust-bitflags-2)
                       ("rust-boring-sys" ,rust-boring-sys-4)
                       ("rust-foreign-types" ,rust-foreign-types-0.5)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-once-cell" ,rust-once-cell-1)
                       ("rust-openssl-macros" ,rust-openssl-macros-0.1))))
    (home-page "https://github.com/cloudflare/boring")
    (synopsis "BoringSSL bindings")
    (description "This package provides @code{BoringSSL} bindings.")
    (license license:asl2.0)))

(define-public rust-lettre-0.11
  (package
    (name "rust-lettre")
    (version "0.11.12")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "lettre" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1y33iwk21dg7iccacc6cb87dz9xi291ij0kn8wcmk90hk14f30p8"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.22)
                       ("rust-boring" ,rust-boring-4)
                       ("rust-chumsky" ,rust-chumsky-0.9)
                       ("rust-ed25519-dalek" ,rust-ed25519-dalek-2)
                       ("rust-email-encoding" ,rust-email-encoding-0.3)
                       ("rust-email-address" ,rust-email-address-0.2)
                       ("rust-fastrand" ,rust-fastrand-2)
                       ("rust-futures-io" ,rust-futures-io-0.3)
                       ("rust-futures-rustls" ,rust-futures-rustls-0.26)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-hostname" ,rust-hostname-0.4)
                       ("rust-httpdate" ,rust-httpdate-1)
                       ("rust-idna" ,rust-idna-1)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-native-tls" ,rust-native-tls-0.2)
                       ("rust-nom" ,rust-nom-7)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-quoted-printable" ,rust-quoted-printable-0.5)
                       ("rust-rsa" ,rust-rsa-0.9)
                       ("rust-rustls" ,rust-rustls-0.23)
                       ("rust-rustls-native-certs" ,rust-rustls-native-certs-0.8)
                       ("rust-rustls-pemfile" ,rust-rustls-pemfile-2)
                       ("rust-rustls-pki-types" ,rust-rustls-pki-types-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha2" ,rust-sha2-0.10)
                       ("rust-socket2" ,rust-socket2-0.5)
                       ("rust-tokio" ,rust-tokio-1)
                       ("rust-tokio-boring" ,rust-tokio-boring-4)
                       ("rust-tokio-native-tls" ,rust-tokio-native-tls-0.3)
                       ("rust-tokio-rustls" ,rust-tokio-rustls-0.26)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webpki-roots" ,rust-webpki-roots-0.26))
       #:cargo-development-inputs (("rust-async-std" ,rust-async-std-1)
                                   ("rust-criterion" ,rust-criterion-0.5)
                                   ("rust-glob" ,rust-glob-0.3)
                                   ("rust-maud" ,rust-maud-0.26)
                                   ("rust-pretty-assertions" ,rust-pretty-assertions-1)
                                   ("rust-serde-json" ,rust-serde-json-1)
                                   ("rust-tokio" ,rust-tokio-1)
                                   ("rust-tracing" ,rust-tracing-0.1)
                                   ("rust-tracing-subscriber" ,rust-tracing-subscriber-0.3)
                                   ("rust-walkdir" ,rust-walkdir-2))))
    (home-page "https://lettre.rs")
    (synopsis "Email client")
    (description "This package provides Email client.")
    (license license:expat)))

(define-public rust-rocket-ws-0.1
  (package
    (name "rust-rocket-ws")
    (version "0.1.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rocket_ws" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0bkqm2rwr5ps0wfzma2bpg9nqm9w70hryd3w2w0vfdy9d1v8gw95"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-rocket" ,rust-rocket-0.5)
                       ("rust-tokio-tungstenite" ,rust-tokio-tungstenite-0.21))))
    (home-page "https://rocket.rs")
    (synopsis "WebSocket support for Rocket")
    (description "This package provides @code{WebSocket} support for Rocket.")
    (license (list license:expat license:asl2.0))))

(define-public rust-rpassword-7
  (package
    (name "rust-rpassword")
    (version "7.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rpassword" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0gvy3lcpph9vv1rl0cjfn72ylvmgbw2vklmj6w0iv4cpr3ijniw0"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-libc" ,rust-libc-0.2)
                       ("rust-rtoolbox" ,rust-rtoolbox-0.0.1)
                       ("rust-windows-sys" ,rust-windows-sys-0.48))))
    (home-page "https://github.com/conradkleinespel/rpassword")
    (synopsis "Read passwords in console applications")
    (description
     "This package provides Read passwords in console applications.")
    (license license:asl2.0)))

(define-public rust-rstest-reuse-0.7
  (package
    (name "rust-rstest-reuse")
    (version "0.7.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "rstest_reuse" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "057y4v1rh9br58n2m3xqvm8xyx8k96jpgibgls3sah78f93gpa5k"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-quote" ,rust-quote-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-syn" ,rust-syn-2))))
    (home-page "https://github.com/la10736/rstest")
    (synopsis "Reuse rstest attributes: create a set of tests and apply it 
to every scenario you want to test.")
    (description
     "This package provides Reuse rstest attributes: create a set of tests and apply it to every scenario
you want to test.")
    (license (list license:expat license:asl2.0))))

(define-public rust-time-macros-0.2
  (package
    (name "rust-time-macros")
    (version "0.2.19")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "time-macros" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1pl558z26pp342l5y91n6dxb60xwhar975wk6jc4npiygq0ycd18"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-num-conv" ,rust-num-conv-0.1)
                       ("rust-time-core" ,rust-time-core-0.1))))
    (home-page "https://github.com/time-rs/time")
    (synopsis
     "Procedural macros for the time crate.
    This crate is an implementation detail and should not be relied upon directly.")
    (description
     "This package provides Procedural macros for the time crate.  This crate is an implementation detail
and should not be relied upon directly.")
    (license (list license:expat license:asl2.0))))

(define-public rust-time-0.3
  (package
    (name "rust-time")
    (version "0.3.37")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "time" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "08bvydyc14plkwhchzia5bcdbmm0mk5fzilsdpjx06w6hf48drrm"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-deranged" ,rust-deranged-0.3)
                       ("rust-itoa" ,rust-itoa-1)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-num-conv" ,rust-num-conv-0.1)
                       ("rust-num-threads" ,rust-num-threads-0.1)
                       ("rust-powerfmt" ,rust-powerfmt-0.2)
                       ("rust-quickcheck" ,rust-quickcheck-1)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-time-core" ,rust-time-core-0.1)
                       ("rust-time-macros" ,rust-time-macros-0.2))
       #:cargo-development-inputs (("rust-criterion" ,rust-criterion-0.5)
                                   ("rust-num-conv" ,rust-num-conv-0.1)
                                   ("rust-quickcheck-macros" ,rust-quickcheck-macros-1)
                                   ("rust-rand" ,rust-rand-0.8)
                                   ("rust-rstest" ,rust-rstest-0.23)
                                   ("rust-rstest-reuse" ,rust-rstest-reuse-0.7)
                                   ("rust-serde" ,rust-serde-1)
                                   ("rust-serde-json" ,rust-serde-json-1)
                                   ("rust-serde-test" ,rust-serde-test-1)
                                   ("rust-time-macros" ,rust-time-macros-0.2)
                                   ("rust-trybuild" ,rust-trybuild-1))))
    (home-page "https://time-rs.github.io")
    (synopsis
     "Date and time library. Fully interoperable with the standard library. Mostly compatible with #![no_std]")
    (description
     "This package provides Date and time library.  Fully interoperable with the standard library.  Mostly
compatible with #![no_std].")
    (license (list license:expat license:asl2.0))))

(define-public rust-serde-wasm-bindgen-0.6
  (package
    (name "rust-serde-wasm-bindgen")
    (version "0.6.5")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde-wasm-bindgen" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0sz1l4v8059hiizf5z7r2spm6ws6sqcrs4qgqwww3p7dy1ly20l3"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2))))
    (home-page "https://github.com/RReverser/serde-wasm-bindgen")
    (synopsis "Native Serde adapter for wasm-bindgen")
    (description
     "This package provides Native Serde adapter for wasm-bindgen.")
    (license license:expat)))

(define-public rust-webauthn-rs-proto-0.5
  (package
    (name "rust-webauthn-rs-proto")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "webauthn-rs-proto" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "17x68hvhf3hq44q0ksl8ykyz8y6maj5cwwf9my1ppp77f1zkdq8l"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-base64urlsafedata" ,rust-base64urlsafedata-0.5)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-wasm-bindgen" ,rust-serde-wasm-bindgen-0.6)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-url" ,rust-url-2)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-web-sys" ,rust-web-sys-0.3))))
    (home-page "https://github.com/kanidm/webauthn-rs")
    (synopsis "Webauthn Specification Bindings")
    (description "This package provides Webauthn Specification Bindings.")
    (license license:mpl2.0)))

(define-public rust-webauthn-attestation-ca-0.5
  (package
    (name "rust-webauthn-attestation-ca")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "webauthn-attestation-ca" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "168b7addpqfcyhnd7qrr2ndxd3cabzj6mrd8wh03pfgcb647xrr9"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64urlsafedata" ,rust-base64urlsafedata-0.5)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/kanidm/webauthn-rs")
    (synopsis "Webauthn Attestation CA Descriptions")
    (description "This package provides Webauthn Attestation CA Descriptions.")
    (license license:mpl2.0)))

(define-public rust-serde-cbor-2-0.12
  (package
    (name "rust-serde-cbor-2")
    (version "0.12.0-dev")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "serde_cbor_2" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0mfxl2b08f5w1xyq7740kf4vvyqnsqrg804vpvfiw7z097s7avdl"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-half" ,rust-half-1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/kanidm/cbor")
    (synopsis "CBOR support for serde")
    (description "This package provides CBOR support for serde.")
    (license (list license:expat license:asl2.0))))

(define-public rust-openssl-kdf-0.4
  (package
    (name "rust-openssl-kdf")
    (version "0.4.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "openssl-kdf" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1x61pfsji1phgf0z8wpbwnkjqmqgyxk03c1xakccc4fmvrs4pnpy"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-foreign-types" ,rust-foreign-types-0.3)
                       ("rust-libc" ,rust-libc-0.2)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-openssl-sys" ,rust-openssl-sys-0.9)
                       ("rust-pkg-config" ,rust-pkg-config-0.3)
                       ("rust-thiserror" ,rust-thiserror-1))))
    (home-page "https://github.com/puiterwijk/rust-openssl-kdf/")
    (synopsis "OpenSSL KDF function abstraction")
    (description
     "This package provides @code{OpenSSL} KDF function abstraction.")
    (license license:expat)))

(define-public rust-malloced-1
  (package
    (name "rust-malloced")
    (version "1.3.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "malloced" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1v00ain5cv4p9v7vn4hxnrdx83hcmv3nxbgfcaf50f8bkqpvpzkd"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/nvzqz/malloced")
    (synopsis "malloc-ed box pointer type.")
    (description "This package provides a malloc-ed box pointer type.")
    (license (list license:expat license:asl2.0))))

(define-public rust-bitfield-0.13
  (package
    (name "rust-bitfield")
    (version "0.13.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "bitfield" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "06g7jb5r2b856vnhx76081fg90jvmy61kjqcfjysgmd5hclvvbs6"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/dzamlo/rust-bitfield")
    (synopsis "This crate provides macros to generate bitfield-like struct")
    (description
     "This crate provides macros to generate bitfield-like struct.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tss-esapi-8
  (package
    (name "rust-tss-esapi")
    (version "8.0.0-alpha")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tss-esapi" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0c97bavk96x50wwhqi2ypjcmad6b636hgr6klginv131c6j1f5iw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-bitfield" ,rust-bitfield-0.13)
                       ("rust-cfg-if" ,rust-cfg-if-1)
                       ("rust-enumflags2" ,rust-enumflags2-0.7)
                       ("rust-hostname-validator" ,rust-hostname-validator-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-malloced" ,rust-malloced-1)
                       ("rust-num-derive" ,rust-num-derive-0.3)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-oid" ,rust-oid-0.2)
                       ("rust-paste" ,rust-paste-1)
                       ("rust-picky-asn1" ,rust-picky-asn1-0.8)
                       ("rust-picky-asn1-x509" ,rust-picky-asn1-x509-0.12)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-semver" ,rust-semver-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-strum" ,rust-strum-0.25)
                       ("rust-strum-macros" ,rust-strum-macros-0.25)
                       ("rust-tss-esapi-sys" ,rust-tss-esapi-sys-0.5)
                       ("rust-zeroize" ,rust-zeroize-1))))
    (home-page "https://github.com/parallaxsecond/rust-tss-esapi")
    (synopsis "Rust-native wrapper around TSS 2.0 Enhanced System API")
    (description
     "This package provides Rust-native wrapper around TSS 2.0 Enhanced System API.")
    (license license:asl2.0)))

(define-public rust-kanidm-hsm-crypto-0.2
  (package
    (name "rust-kanidm-hsm-crypto")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "kanidm-hsm-crypto" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0pmgbz3mrranlq3fn3ssf5xvsrymawq7lrsc4x7xm8ydhs7fvcqh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-argon2" ,rust-argon2-0.5)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-tss-esapi" ,rust-tss-esapi-8)
                       ("rust-tss-esapi-sys" ,rust-tss-esapi-sys-0.5)
                       ("rust-zeroize" ,rust-zeroize-1))))
    (home-page "https://github.com/kanidm/hsm-crypto/")
    (synopsis "library for easily interacting with a HSM or TPM")
    (description
     "This package provides a library for easily interacting with a HSM or TPM.")
    (license license:mpl2.0)))

(define-public rust-compact-jwt-0.4
  (package
    (name "rust-compact-jwt")
    (version "0.4.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "compact_jwt" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1fhzibhy0jmf8xg0qi2wvrwmiqfspz8032j60w5qsvj48mjapfqj"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-base64urlsafedata" ,rust-base64urlsafedata-0.5)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-kanidm-hsm-crypto" ,rust-kanidm-hsm-crypto-0.2)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-openssl-kdf" ,rust-openssl-kdf-0.4)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1))))
    (home-page "https://github.com/kanidm/compact-jwt")
    (synopsis "Minimal implementation of JWT for OIDC and other applications")
    (description
     "This package provides Minimal implementation of JWT for OIDC and other applications.")
    (license license:mpl2.0)))

(define-public rust-webauthn-rs-core-0.5
  (package
    (name "rust-webauthn-rs-core")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "webauthn-rs-core" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "03dg9sdnr4xjccqa2cazcwwh9fpy2x9yhj3c9lqgwgcgxl3qzx1f"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-base64urlsafedata" ,rust-base64urlsafedata-0.5)
                       ("rust-compact-jwt" ,rust-compact-jwt-0.4)
                       ("rust-der-parser" ,rust-der-parser-9)
                       ("rust-hex" ,rust-hex-0.4)
                       ("rust-nom" ,rust-nom-7)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-rand-chacha" ,rust-rand-chacha-0.3)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-cbor-2" ,rust-serde-cbor-2-0.12)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webauthn-attestation-ca" ,rust-webauthn-attestation-ca-0.5)
                       ("rust-webauthn-rs-proto" ,rust-webauthn-rs-proto-0.5)
                       ("rust-x509-parser" ,rust-x509-parser-0.16))))
    (home-page "https://github.com/kanidm/webauthn-rs")
    (synopsis "Webauthn Cryptographic Operation Handling")
    (description
     "This package provides Webauthn Cryptographic Operation Handling.")
    (license license:mpl2.0)))

(define-public rust-base64urlsafedata-0.5
  (package
    (name "rust-base64urlsafedata")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "base64urlsafedata" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0v75z84033z70j1n7dkfxqj87zswy2bj2nxdhmcxbgkzrqwavw3j"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-base64" ,rust-base64-0.21)
                       ("rust-paste" ,rust-paste-1)
                       ("rust-serde" ,rust-serde-1))))
    (home-page "https://github.com/kanidm/webauthn-rs")
    (synopsis "Base 64 Url Safe wrapper for Serde")
    (description "This package provides Base 64 Url Safe wrapper for Serde.")
    (license license:mpl2.0)))

(define-public rust-webauthn-rs-0.5
  (package
    (name "rust-webauthn-rs")
    (version "0.5.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "webauthn-rs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0mh8d3ajn7y2i3a9wfhwn6wj5067bspnlfk68ch24vynw1z38i4b"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-base64urlsafedata" ,rust-base64urlsafedata-0.5)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-uuid" ,rust-uuid-1)
                       ("rust-webauthn-rs-core" ,rust-webauthn-rs-core-0.5))))
    (home-page "https://github.com/kanidm/webauthn-rs")
    (synopsis "Webauthn Framework for Rust Web Servers")
    (description
     "This package provides Webauthn Framework for Rust Web Servers.")
    (license license:mpl2.0)))

(define-public rust-async-rustls-0.2
  (package
    (name "rust-async-rustls")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-rustls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0y7kad5byac4mqyqkbrw26qjxrd7qvhajlcjdlnkwkssplxg71lw"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-futures-lite" ,rust-futures-lite-1)
                       ("rust-rustls" ,rust-rustls-0.19)
                       ("rust-webpki" ,rust-webpki-0.21))))
    (home-page "https://github.com/smol-rs/async-rustls")
    (synopsis "Asynchronous TLS/SSL streams using Rustls")
    (description
     "This package provides Asynchronous TLS/SSL streams using Rustls.")
    (license (list license:asl2.0 license:expat))))

(define-public rust-tide-rustls-0.3
  (package
    (name "rust-tide-rustls")
    (version "0.3.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tide-rustls" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1dz6zmvg13y2y0nbh0lw3bvvjidkm17rsx5fjjkhp10inrlbb1bs"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-dup" ,rust-async-dup-1)
                       ("rust-async-h1" ,rust-async-h1-2)
                       ("rust-async-rustls" ,rust-async-rustls-0.2)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-rustls" ,rust-rustls-0.19)
                       ("rust-tide" ,rust-tide-0.16))))
    (home-page "https://github.com/jbr/tide-rustls")
    (synopsis "tide tls listener based on async-rustls and rustls")
    (description
     "This package provides tide tls listener based on async-rustls and rustls.")
    (license (list license:expat license:asl2.0))))

(define-public rust-route-recognizer-0.2
  (package
    (name "rust-route-recognizer")
    (version "0.2.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "route-recognizer" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "17mmnyzg7yr5x84n28y6bll1qn21g11k61p6sgg2fjf0xdshcxsn"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/rustasync/route-recognizer")
    (synopsis
     "Recognizes URL patterns with support for dynamic and wildcard segments")
    (description
     "This package provides Recognizes URL patterns with support for dynamic and wildcard segments.")
    (license license:expat)))

(define-public rust-async-sse-4
  (package
    (name "rust-async-sse")
    (version "4.1.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-sse" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "046yba03pl4n4z7r4ls3xn442xmsd6w5j36d8lid53vbk41s1fsk"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-channel" ,rust-async-channel-1)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-http-types" ,rust-http-types-2)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-memchr" ,rust-memchr-2)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.1))))
    (home-page "https://github.com/http-rs/async-sse")
    (synopsis "Async Server Sent Event parser and encoder")
    (description
     "This package provides Async Server Sent Event parser and encoder.")
    (license (list license:expat license:asl2.0))))

(define-public rust-hmac-0.8
  (package
    (name "rust-hmac")
    (version "0.8.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "hmac" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h48wc7iysh4xd6ci4prh8bb7nszijrh9w3blaaq8a6cilk8hs0j"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-crypto-mac" ,rust-crypto-mac-0.8)
                       ("rust-digest" ,rust-digest-0.9))))
    (home-page "https://github.com/RustCrypto/MACs")
    (synopsis
     "Generic implementation of Hash-based Message Authentication Code (HMAC)")
    (description
     "This package provides Generic implementation of Hash-based Message Authentication Code (HMAC).")
    (license (list license:expat license:asl2.0))))

(define-public rust-async-session-2
  (package
    (name "rust-async-session")
    (version "2.0.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "async-session" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "07v3rk133bsbvy9dgfzwsl5i07il3kb6zcn1bh8cv4nhxsi24l1l"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-anyhow" ,rust-anyhow-1)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-base64" ,rust-base64-0.12)
                       ("rust-bincode" ,rust-bincode-1)
                       ("rust-blake3" ,rust-blake3-0.3)
                       ("rust-chrono" ,rust-chrono-0.4)
                       ("rust-hmac" ,rust-hmac-0.8)
                       ("rust-kv-log-macro" ,rust-kv-log-macro-1)
                       ("rust-rand" ,rust-rand-0.7)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-sha2" ,rust-sha2-0.9))))
    (home-page "https://github.com/http-rs/async-session")
    (synopsis "Async session support with pluggable middleware")
    (description
     "This package provides Async session support with pluggable middleware.")
    (license (list license:expat license:asl2.0))))

(define-public rust-tide-0.16
  (package
    (name "rust-tide")
    (version "0.16.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "tide" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1q6yl5wkmy8csbg6024mxvw5m1zai5sgaiwhad5p7k6j1lzmfnf4"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-async-h1" ,rust-async-h1-2)
                       ("rust-async-session" ,rust-async-session-2)
                       ("rust-async-sse" ,rust-async-sse-4)
                       ("rust-async-std" ,rust-async-std-1)
                       ("rust-async-trait" ,rust-async-trait-0.1)
                       ("rust-femme" ,rust-femme-2)
                       ("rust-futures-util" ,rust-futures-util-0.3)
                       ("rust-http-client" ,rust-http-client-6)
                       ("rust-http-types" ,rust-http-types-2)
                       ("rust-kv-log-macro" ,rust-kv-log-macro-1)
                       ("rust-log" ,rust-log-0.4)
                       ("rust-pin-project-lite" ,rust-pin-project-lite-0.2)
                       ("rust-route-recognizer" ,rust-route-recognizer-0.2)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1))))
    (home-page "https://github.com/http-rs/tide")
    (synopsis
     "minimal and pragmatic Rust web application framework built for rapid development")
    (description
     "This package provides a minimal and pragmatic Rust web application framework
built for rapid development.")
    (license (list license:expat license:asl2.0))))

(define-public rust-askama-tide-0.14
  (package
    (name "rust-askama-tide")
    (version "0.14.0")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "askama_tide" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0h37dp6g4s3pbj784lgh98v99dzgybxwm1hk1szc9in993impga5"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-askama" ,rust-askama-0.11)
                       ("rust-tide" ,rust-tide-0.16))))
    (home-page "https://github.com/djc/askama")
    (synopsis "Tide integration for Askama templates")
    (description
     "This package provides Tide integration for Askama templates.")
    (license (list license:expat license:asl2.0))))

(define-public rust-comrak-0.12
  (package
    (name "rust-comrak")
    (version "0.12.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "comrak" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0x2f1qz64i3ni7sk87whc3bvp27ps1wxn0ia47qlvsrk39p4fg7z"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-clap" ,rust-clap-2)
                       ("rust-entities" ,rust-entities-1)
                       ("rust-lazy-static" ,rust-lazy-static-1)
                       ("rust-pest" ,rust-pest-2)
                       ("rust-pest-derive" ,rust-pest-derive-2)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-shell-words" ,rust-shell-words-1)
                       ("rust-syntect" ,rust-syntect-4)
                       ("rust-twoway" ,rust-twoway-0.2)
                       ("rust-typed-arena" ,rust-typed-arena-1)
                       ("rust-unicode-categories" ,rust-unicode-categories-0.1)
                       ("rust-xdg" ,rust-xdg-2))))
    (home-page "https://github.com/kivikakk/comrak")
    (synopsis
     "100% CommonMark-compatible GitHub Flavored Markdown parser and formatter")
    (description
     "This package provides a 100% @code{CommonMark-compatible} @code{GitHub} Flavored
Markdown parser and formatter.")
    (license license:bsd-2)))

(define-public rust-askama-escape-0.10
  (package
    (name "rust-askama-escape")
    (version "0.10.3")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "askama_escape" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0hg3rz0cma5f6385z7qmqw3jbir76jndwd5s7dqfk92v9gil75v1"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t))
    (home-page "https://github.com/djc/askama")
    (synopsis "Optimized HTML escaping code, extracted from Askama")
    (description
     "This package provides Optimized HTML escaping code, extracted from Askama.")
    (license (list license:expat license:asl2.0))))

(define-public rust-askama-shared-0.12
  (package
    (name "rust-askama-shared")
    (version "0.12.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "askama_shared" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1l4fycmw65zyvfabf672sj2pc0ilfcj0y6a0csygq1wa26a2nwmz"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-askama-escape" ,rust-askama-escape-0.10)
                       ("rust-comrak" ,rust-comrak-0.12)
                       ("rust-humansize" ,rust-humansize-1)
                       ("rust-mime" ,rust-mime-0.3)
                       ("rust-mime-guess" ,rust-mime-guess-2)
                       ("rust-nom" ,rust-nom-7)
                       ("rust-num-traits" ,rust-num-traits-0.2)
                       ("rust-percent-encoding" ,rust-percent-encoding-2)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-quote" ,rust-quote-1)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-serde-yaml" ,rust-serde-yaml-0.8)
                       ("rust-syn" ,rust-syn-1)
                       ("rust-toml" ,rust-toml-0.5))))
    (home-page "https://github.com/djc/askama")
    (synopsis "Shared code for Askama")
    (description "This package provides Shared code for Askama.")
    (license (list license:expat license:asl2.0))))

(define-public rust-askama-derive-0.11
  (package
    (name "rust-askama-derive")
    (version "0.11.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "askama_derive" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0wbb5l1x1bx8x8vvz4ayw196l9y64mi3vrmxm7pn8wmlx3k8ggw7"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-askama-shared" ,rust-askama-shared-0.12)
                       ("rust-proc-macro2" ,rust-proc-macro2-1)
                       ("rust-syn" ,rust-syn-1))))
    (home-page "https://github.com/djc/askama")
    (synopsis "Procedural macro package for Askama")
    (description "This package provides Procedural macro package for Askama.")
    (license (list license:expat license:asl2.0))))

(define-public rust-askama-0.11
  (package
    (name "rust-askama")
    (version "0.11.1")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "askama" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "0f81mzccdadryzaf2dbad1araq4nadp9mssyvdvv31hj6w7z367v"))))
    (build-system cargo-build-system)
    (arguments
     `(#:skip-build? #t
       #:cargo-inputs (("rust-askama-derive" ,rust-askama-derive-0.11)
                       ("rust-askama-escape" ,rust-askama-escape-0.10)
                       ("rust-askama-shared" ,rust-askama-shared-0.12))))
    (home-page "https://github.com/djc/askama")
    (synopsis "Type-safe, compiled Jinja-like templates for Rust")
    (description
     "This package provides Type-safe, compiled Jinja-like templates for Rust.")
    (license (list license:expat license:asl2.0))))

(define-public rust-webauthn-rs-0.3
  (package
    (name "rust-webauthn-rs")
    (version "0.3.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "webauthn-rs" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "1hbfz6krpv88ph3wlwnzn6h6sldh8fj3xizmfrc5jcjbrgn6dclh"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-base64" ,rust-base64-0.13)
                       ("rust-js-sys" ,rust-js-sys-0.3)
                       ("rust-nom" ,rust-nom-7)
                       ("rust-openssl" ,rust-openssl-0.10)
                       ("rust-rand" ,rust-rand-0.8)
                       ("rust-serde" ,rust-serde-1)
                       ("rust-serde-cbor" ,rust-serde-cbor-0.11)
                       ("rust-serde-derive" ,rust-serde-derive-1)
                       ("rust-serde-json" ,rust-serde-json-1)
                       ("rust-thiserror" ,rust-thiserror-1)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-url" ,rust-url-2)
                       ("rust-wasm-bindgen" ,rust-wasm-bindgen-0.2)
                       ("rust-web-sys" ,rust-web-sys-0.3))
       #:cargo-development-inputs (("rust-askama" ,rust-askama-0.11)
                                   ("rust-askama-tide" ,rust-askama-tide-0.14)
                                   ("rust-async-std" ,rust-async-std-1)
                                   ("rust-lru" ,rust-lru-0.7)
                                   ("rust-openssl" ,rust-openssl-0.10)
                                   ("rust-rustls" ,rust-rustls-0.19)
                                   ("rust-structopt" ,rust-structopt-0.3)
                                   ("rust-tide" ,rust-tide-0.16)
                                   ("rust-tide-rustls" ,rust-tide-rustls-0.3)
                                   ("rust-tracing-subscriber" ,rust-tracing-subscriber-0.3))))
    (home-page "https://github.com/kanidm/webauthn-rs")
    (synopsis "Webauthn Framework for Rust Web Servers")
    (description
     "This package provides Webauthn Framework for Rust Web Servers.")
    (license license:mpl2.0)))

(define-public rust-which-7
  (package
    (name "rust-which")
    (version "7.0.2")
    (source
     (origin
       (method url-fetch)
       (uri (crate-uri "which" version))
       (file-name (string-append name "-" version ".tar.gz"))
       (sha256
        (base32 "10qjdz8cld2ljd62kk3yaqhn7b96dj4bmy02vjmb6wphw5hwhx17"))))
    (build-system cargo-build-system)
    (arguments
     `(#:cargo-inputs (("rust-either" ,rust-either-1)
                       ("rust-env-home" ,rust-env-home-0.1)
                       ("rust-regex" ,rust-regex-1)
                       ("rust-rustix" ,rust-rustix-0.38)
                       ("rust-tracing" ,rust-tracing-0.1)
                       ("rust-winsafe" ,rust-winsafe-0.0.19))
       #:cargo-development-inputs (("rust-tempfile" ,rust-tempfile-3))))
    (home-page "https://github.com/harryfei/which-rs.git")
    (synopsis
     "Rust equivalent of Unix command \"which\". Locate installed executable in cross platforms.")
    (description
     "This package provides a Rust equivalent of Unix command \"which\".  Locate
installed executable in cross platforms.")
    (license license:expat)))

